#*******************************************************************************
# Copyright 2008, 2011 Hochschule Offenburg
# Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
# Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
# Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
#
# This file is part of magmaOffenburg.
#
# magmaOffenburg is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# magmaOffenburg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
#*******************************************************************************
#!/bin/bash
###########################################
# Starts an optimization run
#
# example bash ./runOptimization.sh OptimizeWalkOfNaoType2 &
###########################################

if [ $# -ne 1 ]; then
        echo "Usage: $0 <textual description of run>"
        exit 1
fi

CLSPTH=kdoLib.jar:commons-math3-3.3.jar:geneticLearning.jar

###########################################
# Problem
# [WalkFunctionProblem|WalkProblem|TurnProblem|BackWalkProblem|SideWalkProblem|WalkBenchmarkProblem|WalkAreaProblem
# |KickFastProblem|KickEvaluationProblem]
PROBLEM=WalkProblem

###########################################
# Strategy
# [Measurement|FullSearch|VNS|TabuSearch|SimulatedAnnealing
# |HillClimbing|RandomWalk|HCRandomOperator|HCRandomRestart|Genetic]
STRATEGY=TabuSearch

###########################################
# Average out Strategy
# serial - all tries to measure one utility are sequential (ignores THREADS)
# parallel - tries are run in THREADS parallel threads
AVGSTRATEGY=parallel

###########################################
# Average out runs
# number of runs to measure one single utility
AVGRUNS=20

###########################################
# Average out Threads
# if parallel, the number of parallel threads
THREADS=20

###########################################
# Robot model used
# [Nao|Nao1|Nao2|Sweaty]
ROBOT=Nao

java -cp $CLSPTH magma.learning.view.GeneticMainConsole $PROBLEM $STRATEGY $AVGSTRATEGY $AVGRUNS $THREADS $ROBOT $1 1>lausConsole.txt 2>klausConsoleError.txt

