#*******************************************************************************
# Copyright 2008, 2011 Hochschule Offenburg
# Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
# Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
# Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
#
# This file is part of magmaOffenburg.
#
# magmaOffenburg is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# magmaOffenburg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
#*******************************************************************************
#!/bin/bash
###########################################
# Starts a complete RoboCup game on this localhost.
# example: ./startGameHeadless.sh team1 team2 team1.jar team2.jar 1 3100 3200 trainer1
#
# team1 and team2 are the paths to the team's folders.
# Make sure that ./startCommon.sh specifies the players that you want to have started.
# Also make sure that it contains the different jar files.
###########################################

if [ $# -ne 8 ]; then
        echo "Usage: $0 <team1 name> <team1 jar> <team 2 name> <team2 jar> <number of players per team> <agentport> <trainerport> <trainer name>"
        exit 1
fi

SERVER_IP=127.0.0.1
TEAM1_NAME=$1
TEAM1_JAR=$2
TEAM2_NAME=$3
TEAM2_JAR=$4
NUM_OF_PLAYERS=$5
AGENT_PORT=$6
TRAINER_PORT=$7
TRAINER_NAME=$8

echo "start server..."
rcssserver3d --agent-port $AGENT_PORT --server-port $TRAINER_PORT &
SERVERPID=$!
sleep 2

echo "start first team..."
./startCommon.sh $SERVER_IP $AGENT_PORT $TEAM1_NAME $TEAM1_JAR $NUM_OF_PLAYERS

echo "start second team..."
./startCommon.sh $SERVER_IP $AGENT_PORT $TEAM2_NAME $TEAM2_JAR $NUM_OF_PLAYERS

echo "start trainer..." $TRAINER_NAME
./startTrainer.sh $SERVER_IP $TRAINER_PORT $SERVERPID $TRAINER_NAME

echo "kill server if still there..."
kill -9 $SERVERPID

