#!/bin/bash
#*******************************************************************************
# Copyright 2008, 2011 Hochschule Offenburg
# Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
# Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
# Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
#
# This file is part of magmaOffenburg.
#
# magmaOffenburg is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# magmaOffenburg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
#*******************************************************************************
###########################################
# Starts a series of games synchronously.
# Assumes startGameHeadless.sh is in same folder
# The actual games run is a multiple of the number of parallel games
#
# example: bash startGameSeries.sh 12 4 team1 team1.jar team2 team2.jar 1 3100 3200 trainer1 &
###########################################

if [ $# -ne 10 ]; then
        echo "Usage: $0 <Number of Games> <Number of Parallel Games> <team1 name> <team1 jar> <team 2 name> <team2 jar> <num of players per team> <agentport> <trainerport> <trainer name>"
        exit 1
fi

NUMBER_OF_GAMES=$1
NUMBER_OF_PARALLEL_GAMES=$2
TEAM1_NAME=$3
TEAM1_JAR=$4
TEAM2_NAME=$5
TEAM2_JAR=$6
NUM_OF_PLAYERS=$7
AGENT_PORT=$8
TRAINER_PORT=$9
TRAINER_NAME=${10}

GAMES="`seq 1 $NUMBER_OF_GAMES`"

echo "Running $NUMBER_OF_GAMES games $TEAM1_JAR vs $TEAM2_JAR using score" 1>log/$TRAINER_NAME.log 

for ((i = 0 ; i < ${NUMBER_OF_GAMES}; )) do
	for ((j = ${NUMBER_OF_PARALLEL_GAMES} ; j > 0; j--)) do
		APORT=$(expr $AGENT_PORT + $j \* 10)
		TPORT=$(expr $TRAINER_PORT + $j \* 10)
		#LOGFILE=outerr$APORT.log
		LOGFILE=outerr.log
		if [ $j -eq 1 ] ; then
			sleep $(expr 3 \* $NUM_OF_PLAYERS)
			./startGameHeadless.sh $TEAM1_NAME$j $TEAM1_JAR $TEAM2_NAME$j $TEAM2_JAR $NUM_OF_PLAYERS $APORT $TPORT $TRAINER_NAME 1>log/$LOGFILE 2>&1
		else
			# only difference is the tailing &
			./startGameHeadless.sh $TEAM1_NAME$j $TEAM1_JAR $TEAM2_NAME$j $TEAM2_JAR $NUM_OF_PLAYERS $APORT $TPORT $TRAINER_NAME 1>log/$LOGFILE 2>&1 &
			sleep $(expr 2 \* $NUM_OF_PLAYERS)
		fi		
		let i+=1
	done
	
	# clean up, nothing should be running from us (usually they should not find something)
	COUNT_SERVER=`ps -ef | grep -c rcssserver3d` 
	if [ $COUNT_SERVER -gt 1 ] ; then killall -9 rcssserver3d; fi
	COUNT_JAVA=`ps -ef | grep -c java` 
	if [ $COUNT_JAVA -gt 1 ] ; then killall java; fi
	
done
