#!/bin/bash
#*******************************************************************************
# Copyright 2008, 2011 Hochschule Offenburg
# Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
# Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
# Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
#
# This file is part of magmaOffenburg.
#
# magmaOffenburg is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# magmaOffenburg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
#*******************************************************************************
###########################################
# Starts a series of games synchronously.
# Assumes startGameHeadless.sh is in same folder
# The actual games run is a multiple of the number of parallel games
#
# example: bash startTrainerGameSeries.sh 12 team1 team1.jar team2 team2.jar 1 3100 3200 trainer1 &
###########################################

if [ $# -ne 9 ]; then
        echo "Usage: $0 <Number of Games> <team1 name> <team1 jar> <team 2 name> <team2 jar> <num of players per team> <agentport> <trainerport> <trainer name>"
        exit 1
fi

NUMBER_OF_GAMES=$1
TEAM1_NAME=$2
TEAM1_JAR=$3
TEAM2_NAME=$4
TEAM2_JAR=$5
NUM_OF_PLAYERS=$6
AGENT_PORT=$7
TRAINER_PORT=$8
TRAINER_NAME=$9

GAMES="`seq 1 $NUMBER_OF_GAMES`"

if [ $AGENT_PORT -eq 3100 ] ; then
	# if port is not 3100 we only append to the trainer logfile
	echo "Running $NUMBER_OF_GAMES games $TEAM1_JAR vs $TEAM2_JAR using score" 1>log/$TRAINER_NAME.log 
fi

for ((i = 0 ; i < ${NUMBER_OF_GAMES}; )) do
		APORT=3100
		TPORT=3200
		LOGFILE=outerr.log
		./startTrainerGame.sh $TEAM1_NAME$j $TEAM1_JAR $TEAM2_NAME$j $TEAM2_JAR $NUM_OF_PLAYERS $AGENT_PORT $TRAINER_PORT $TRAINER_NAME 1>log/$LOGFILE 2>&1
	let i+=1
done
	
	# clean up, nothing should be running from us (usually they should not find something)
	COUNT_SERVER=`ps -ef | grep -c rcssserver3d` 
	if [ $COUNT_SERVER -gt 1 ] ; then killall -9 rcssserver3d; fi
	COUNT_JAVA=`ps -ef | grep -c java` 
	if [ $COUNT_JAVA -gt 1 ] ; then killall java; fi
	
done
