/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent;

import magma.agent.meta.server.IHomePosition;
import magma.agent.meta.server.impl.RelativeHomePosition;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * Interface for all constants that should be globally accessible and are
 * specific to our team
 * @author Klaus Dorer
 */
@SuppressWarnings("all")
public interface IMagmaConstants
{
	boolean USE_FUTURE_BODY_MODEL = true;

	/** the default name of the own team */
	String DEFAULT_TEAMNAME = "magmaOffenburg";

	/** the default id of the own team */
	byte DEFAULT_TEAMID = 0;

	/** the number of players that play at most in one team */
	int NUMBER_OF_PLAYERS_PER_TEAM = 11;

	/** constant used to identify the id of a player that is not known */
	int UNKNOWN_PLAYER_NUMBER = -1;

	/** constant used to identify the team name of a player that is not known */
	String UNKNOWN_PLAYER_TEAMNAME = "";

	IHomePosition[] homePositionsOwnKickoff = { new RelativeHomePosition( // default
			new float[] { 0, 0 }, new Vector3D(-0.17, -0.05, 0.0)), // default
			new RelativeHomePosition( // Player 1: GOALKEEPER
					new float[] { -1, 0 }, new Vector3D(0.5, 1.5, 0)), //
			new RelativeHomePosition( // Player 2: LEFT DEFENDER
					new float[] { -0.76f, 0.129f }, Vector3D.ZERO), //
			new RelativeHomePosition( // Player 3: MIDDLE DEFENDER (BG)
					new float[] { -0.33f, 0 }, Vector3D.ZERO), //
			new RelativeHomePosition( // Player 4: RIGHT DEFENDER
					new float[] { -0.76f, -0.129f }, Vector3D.ZERO), //
			new RelativeHomePosition( // Player 5
					new float[] { -0.35f, 0.13f }, Vector3D.ZERO), //
			new RelativeHomePosition( // Player 6
					new float[] { -0.13f, 0.13f }, Vector3D.ZERO), //
			new RelativeHomePosition( // Player 7
					new float[] { -0.35f, -0.2f }, Vector3D.ZERO), //
			new RelativeHomePosition( // Player 8: kick off player
					// new float[] { 0, 0 }, new Vector3D(-0.17, -0.03, 0)), //
					new float[] { 0, 0 }, new Vector3D(-0.17, 0.09, -45)), //
			new RelativeHomePosition( // Player 9: third row
					new float[] { 0, 0 }, new Vector3D(-0.17, 1.2, 0)), //
			new RelativeHomePosition( // Player 10: blocker left
					new float[] { 0, 0 }, new Vector3D(-1.5, -4, 0)), //
			new RelativeHomePosition( // Player 11: blocker right
					new float[] { -0.15f, -0.20f }, Vector3D.ZERO), //
	};

	// This formation should block the most kick-offs of other teams which
	// focuses on their kickoff.
	IHomePosition[] homePositionsOtherKickoff = { new RelativeHomePosition( // default
			new float[] { 0, 0 }, new Vector3D(-0.17, -0.05, 0.0)), // default
			new RelativeHomePosition( // Player 1 (goalie)
					new float[] { -1, 0 }, new Vector3D(0.5, 2.5, 0)), //
			new RelativeHomePosition( // Player 2: first row
					new float[] { -0.8f, -0.1f }, Vector3D.ZERO), //
			new RelativeHomePosition( // Player 3: first row
					new float[] { -0.8f, 0.1f }, Vector3D.ZERO), //
			new RelativeHomePosition( // Player 4: first row
					new float[] { -0.53f, 0.05f }, Vector3D.ZERO), //
			new RelativeHomePosition( // Player 5: second row
					new float[] { -0.55f, -0.15f }, Vector3D.ZERO), //
			new RelativeHomePosition( // Player 6: third row
					new float[] { -0.55f, 0.15f }, Vector3D.ZERO), //
			new RelativeHomePosition( // Player 7: second row
					new float[] { -0.3f, -0.05f }, Vector3D.ZERO), //
			new RelativeHomePosition( // Player 8: kick off player
					new float[] { -0.3f, -0.2f }, Vector3D.ZERO), //
			new RelativeHomePosition( // Player 9: third row
					new float[] { -0.3f, 0.2f }, Vector3D.ZERO), //
			new RelativeHomePosition( // Player 10: blocker left
					new float[] { -0.05f, 0.3f }, Vector3D.ZERO), //
			new RelativeHomePosition( // Player 11: blocker right
					new float[] { -0.15f, 0.0f }, Vector3D.ZERO), //
	};

	//
	//
	// IHomePosition[] homePositionsOtherKickoff = { new RelativeHomePosition( //
	// default
	// new float[] { 0, 0 }, new Vector3D(-1.5, 0, 0)), // default
	// new RelativeHomePosition( // Player 1 (goalie)
	// new float[] { -1, 0 }, new Vector3D(0.5, 2.5, 0)), //
	// new RelativeHomePosition( // Player 2
	// new float[] { -0.66f, 0.25f }, Vector3D.ZERO), //
	// new RelativeHomePosition( // Player 3
	// new float[] { -0.62f, 0 }, Vector3D.ZERO), //
	// new RelativeHomePosition( // Player 4
	// new float[] { -0.66f, -0.25f }, Vector3D.ZERO), //
	// new RelativeHomePosition( // Player 5
	// new float[] { -0.38f, 0.29f }, Vector3D.ZERO), //
	// new RelativeHomePosition( // Player 6
	// new float[] { -0.28f, 0 }, Vector3D.ZERO), //
	// new RelativeHomePosition( // Player 7
	// new float[] { -0.38f, -0.29f }, Vector3D.ZERO), //
	// new RelativeHomePosition( // Player 8
	// new float[] { -0.19f, 0.1f }, Vector3D.ZERO), //
	// new RelativeHomePosition( // Player 9
	// new float[] { -0.19f, -0.1f }, Vector3D.ZERO), //
	// new RelativeHomePosition( // Player 10
	// new float[] { -0.25f, 0.20f }, Vector3D.ZERO), //
	// new RelativeHomePosition( // Player 11
	// new float[] { -0.25f, -0.20f }, Vector3D.ZERO), //
	// };
	//
	double DISTANCE_PENALTY_LYING = 3;

	double BEAM_AWAY_DISTANCE = 0.8;

	float TIMEDELAY_LAYING = 4;
}
