/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.action;

import magma.agent.meta.agent.IAgentMetaModel;

/**
 * Interface to all actions an agent can perform on the server
 */
public interface IAction
{
	/**
	 * Sets the values of the passed effector as required by the specific
	 * effector
	 * @param name name of the effector as specified in
	 * @param values the number of float values required by the specific effector
	 */
	void setEffectorValues(String name, float... values);

	/**
	 * Beams the player to specified position with specified direction
	 * @param x x coordinate on the field
	 * @param y y coordinate on the field
	 * @param rotation direction the player is facing
	 */
	void sendBeamString(float x, float y, float rotation);

	/**
	 * shouts out a message to other players
	 * @param message the message to send (max 8 bytes)
	 */
	void sayMessage(String message);

	/**
	 * Sends a motor command to the server. Includes commands to all universals
	 * and hinge joints. The speed of each joint has to be set before by
	 * setHingeEffectorSpeed()
	 * 
	 */
	void sendMotorMessage();

	/**
	 * For initialization to be called after object creation
	 * @param metaModel the robot meta model
	 */
	void init(IAgentMetaModel metaModel);

	/**
	 * @param motorGain the maximal gain (stiffness) motors can have
	 */
	void setMaxGain(float motorGain);

	/**
	 * Retrieve the motorGain the maximal gain (stiffness) motors can have
	 */
	float getMaxGain();
}