/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.action.impl;

/**
 * Implementation of the SimSpark "UniversalJount" effector, used to move robot
 * joints
 * 
 * @author Klaus Dorer
 */
public class CompositeEffector extends Effector
{
	private HingeEffector[] effectors;

	/**
	 * Instantiates a new UniversalEffector and initializes all fields to zero
	 * 
	 * @param name Effector name
	 */
	public CompositeEffector(String name, HingeEffector[] effectors)
	{
		super(name);

		this.effectors = effectors;
	}

	/**
	 * Set axis movement speeds
	 * 
	 * @param ax1 Axis 1 speed
	 * @param ax2 Axis 2 speed
	 */
	@Override
	public void setEffectorValues(float maxGain, float... values)
	{
		for (int i = 0; i < effectors.length; i++) {
			int position = i * 3;
			effectors[i].setEffectorValues(maxGain, values[position],
					values[position + 1], values[position + 2]);
		}
	}

	@Override
	public void resetAfterAction()
	{
		for (int i = 0; i < effectors.length; i++) {
			effectors[i].resetAfterAction();
		}
	}

	public float getSpeed(int i)
	{
		return effectors[i].getSpeed();
	}

	/**
	 * @return the ax1
	 */
	public float getDesiredAngle(int i)
	{
		return effectors[i].getDesiredAngle();
	}

	/**
	 * @return the effectors
	 */
	public HingeEffector getEffector(int i)
	{
		return effectors[i];
	}

	public int size()
	{
		return effectors.length;
	}
}
