/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.action.impl;

/**
 * Implementation of the SimSpark "HingeJoint" effector, used to move robot
 * joints
 * 
 * @author Klaus Dorer
 */
public class HingeEffector extends Effector
{
	/** the speed of the effector in degrees per cycle */
	private float speed; // zero no change of the angle

	private float last_speed; // zero no change of the angle

	/** the desired angle of the effector in degrees */
	private float desiredAngle;

	private float gain;

	/**
	 * Instantiates a new HingeJoint effector and initializes all fields to zero
	 * 
	 * @param name Hinge Joint name
	 */
	public HingeEffector(String name)
	{
		super(name);

		speed = 0.0f;
		desiredAngle = 0.0f;
		last_speed = 0.0f;
		gain = 0.0f;
	}

	/**
	 * Set axis speed
	 * 
	 * @param speed New speed
	 */
	@Override
	public void setEffectorValues(float maxGain, float... values)
	{
		this.speed = values[0];
		this.desiredAngle = values[1];
		this.gain = values[2];
		if (gain > maxGain) {
			gain = maxGain;
		}
	}

	public boolean hasChanged()
	{
		return speed != last_speed;
	}

	@Override
	public void resetAfterAction()
	{
		if (speed != last_speed) {
			last_speed = speed;
		}
		speed = 0.0f;
	}

	/**
	 * @return
	 */
	public float getSpeed()
	{
		return speed;
	}

	/**
	 * @return the desired angular speed of this effector
	 */
	public double getSpeedRadians()
	{
		if (speed != last_speed) {
			last_speed = speed;
			speed = 0.0f;
			return Math.toRadians(last_speed);
		}
		speed = 0.0f;
		return 0.0f;
	}

	/**
	 * @return the desired angular position of this effector in degrees
	 */
	public float getDesiredAngle()
	{
		return desiredAngle;
	}

	/**
	 * @return
	 */
	public float getGain()
	{
		return gain;
	}
}
