/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 */

package magma.agent.action.impl;

import java.util.Map;

import magma.agent.action.IEffector;
import magma.agent.action.IServerMessageEncoder;

/**
 * Encapsulation of the protocol to simspark server
 * @author kdorer
 */
public class ServerMessageEncoder implements IServerMessageEncoder
{
	@Override
	public byte[] encodeMessage(Map<String, IEffector> effectors)
	{
		StringBuilder builder = new StringBuilder(400);
		for (IEffector effector : effectors.values()) {

			if (effector instanceof HingeEffector) {
				HingeEffector hinge = (HingeEffector) effector;
				encodeHinge(builder, hinge);

			} else if (effector instanceof CompositeEffector) {
				CompositeEffector eff = (CompositeEffector) effector;
				for (int i = 0; i < eff.size(); i++) {
					encodeHinge(builder, eff.getEffector(i));
				}

			} else if (effector instanceof UniversalEffector) {
				builder.append("(").append(effector.getName());
				UniversalEffector universal = (UniversalEffector) effector;
				builder.append(" ").append(truncate(universal.getSpeed1()));
				builder.append(" ").append(truncate(universal.getSpeed2()))
						.append(")");

			} else if (effector instanceof BeamEffector) {
				float[] beam = ((BeamEffector) effector).getBeam();
				builder.append("(beam ").append(beam[0]).append(" ")
						.append(beam[1]).append(" ").append(beam[2]).append(")");

			} else if (effector instanceof SayEffector) {
				String message = ((SayEffector) effector).getMessage();
				if (message.length() > 0) {
					builder.append("(say \"").append(message).append("\")");
				}
			}
		}

		builder.append("(syn)");

		return builder.toString().getBytes();
	}

	/**
	 * @param builder
	 * @param hinge
	 */
	public void encodeHinge(StringBuilder builder, HingeEffector hinge)
	{
		if (hinge.hasChanged()) {
			builder.append("(").append(hinge.getName());
			builder.append(" ").append(truncate(hinge.getSpeed())).append(")");
		}
	}

	/**
	 * Truncates to three digits
	 * @param speed2 the value to truncate
	 * @return truncated float
	 */
	private float truncate(float value)
	{
		int i = (int) (value * 1000.0);
		return i / 1000.0f;
	}
}
