/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.action.impl;

/**
 * Implementation of the SimSpark "UniversalJount" effector, used to move robot
 * joints
 * 
 * @author Klaus Dorer
 */
public class UniversalEffector extends Effector
{
	private HingeEffector effector1;

	private HingeEffector effector2;

	/**
	 * Instantiates a new UniversalEffector and initializes all fields to zero
	 * 
	 * @param name Effector name
	 */
	public UniversalEffector(String name, HingeEffector effector1,
			HingeEffector effector2)
	{
		super(name);

		this.effector1 = effector1;
		this.effector2 = effector2;
	}

	/**
	 * Set axis movement speeds
	 * 
	 * @param ax1 Axis 1 speed
	 * @param ax2 Axis 2 speed
	 */
	@Override
	public void setEffectorValues(float maxGain, float... values)
	{
		effector1.setEffectorValues(maxGain, values[0], values[1], values[2]);
		effector2.setEffectorValues(maxGain, values[3], values[4], values[5]);
	}

	@Override
	public void resetAfterAction()
	{
		effector1.resetAfterAction();
		effector2.resetAfterAction();
	}

	public float getSpeed1()
	{
		return effector1.getSpeed();
	}

	public float getSpeed2()
	{
		return effector2.getSpeed();
	}

	/**
	 * @return the ax1
	 */
	public float getDesiredAngle1()
	{
		return effector1.getDesiredAngle();
	}

	/**
	 * @return the ax2
	 */
	public float getDesiredAngle2()
	{
		return effector2.getDesiredAngle();
	}

	/**
	 * @return the effector1
	 */
	public HingeEffector getEffector1()
	{
		return effector1;
	}

	/**
	 * @return the effector2
	 */
	public HingeEffector getEffector2()
	{
		return effector2;
	}
}
