/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.agentmodel;

/**
 * SimSpark "UniversalJoint" sensor interface.
 * 
 * @author Stefan Glaser, Klaus Dorer
 */
public interface ICompositeJoint extends IJoint
{
	/**
	 * @param index index of the joint to work on
	 * @return the minimal angle that can be reached by joint (in degrees)
	 */
	float getMinAxis(int index);

	/**
	 * @param index index of the joint to work on
	 * @return the maximal angle that can be reached by joint (in degrees)
	 */
	float getMaxAxis(int index);

	/**
	 * Retrieve joint axis[index] angle
	 * 
	 * @param index index of the joint to work on
	 * @return first angle of the joint
	 */
	float getAxis(int index);

	/**
	 * Let the joint perform a movement along axis with the given speed in the
	 * current cycle.
	 * 
	 * @param index index of the joint to work on
	 * @param speed to move the joint axis (in deg/cycle)
	 */
	void performAxisSpeed(int index, float speed);

	/**
	 * Let the joint perform a movement along axis in direction of the given
	 * target position (at maximum speed)
	 * 
	 * @param index index of the joint to work on
	 * @param position - target position of axis1 movement
	 */
	void performAxisPosition(int index, float position);

	/**
	 * Let the hinge joint perform a movement along axis in direction of the
	 * given target position with the given speed as maximum speed
	 * 
	 * @param index index of the joint to work on
	 * @param position - target position of axis movement
	 * @param maxSpeed - maximum allowed speed for movement (in deg/cycle)
	 */
	void performAxisPosition(int index, float position, float maxSpeed);

	/**
	 * Returns the next axis speed to the joint.<br>
	 * This method is called by the coordinator, during reflecting the future
	 * actions out of the agent model.
	 * 
	 * @param index index of the joint to work on
	 * @return next axis1 speed to perform (in deg/cycle)
	 */
	float getNextAxisSpeed(int index);
}