/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.agentmodel;

import org.apache.commons.math3.geometry.euclidean.threed.Rotation;
import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * SimSpark "GyroRate" sensor interface. Provides read-only access only.<br>
 * The GyroRate Sensor represents the orientation change of an body in the
 * 3-dimensional space, respective to the global (an other) coordinate system.
 * This orientation change is represented as quaternion in a {@link Rotation}
 * object. The perceived representation is Euler-angles given in the
 * gyro-vector.
 * 
 * <p>
 * <strong>Note:</strong> Relative to the Nao-robot (center of it's torso), the
 * x-axis points to the right arm, while the y-axis is pointing forward and the
 * z-axis go's straight up through it's head.<br>
 * </p>
 * 
 * @author Stefan Glaser, Srinivasa Ragavan
 */
public interface IGyroRate extends ISensor
{
	/**
	 * Retrieve gyro values <br>
	 * where &lt;x, y, z&gt; is a vector containing the angle-change around the
	 * corresponding axis of the previous cycle in degrees per second <br>
	 * 
	 * @return The change in orientation of the body with respect to the global
	 *         coordinate system of the previous cycle
	 */
	Vector3D getGyro();

	/**
	 * Retrieve the current change in orientation
	 * 
	 * @return The current change in orientation
	 */
	Rotation getOrientationChange();
}