/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.agentmodel;

/**
 * SimSpark "HingeJoint" sensor interface.
 * 
 * @author Stefan Glaser, Klaus Dorer
 */
public interface IHingeJoint extends IHingeJointR
{
	/**
	 * Let the hinge joint perform a movement with the given speed in the current
	 * cycle.
	 * 
	 * @param speed to move the joint axis (in deg/cycle)
	 * @return the speed with which we adjust
	 */
	void performAxisSpeed(float speed);

	/**
	 * Let the hinge joint perform a movement in direction of the given target
	 * position (at maximum speed)
	 * 
	 * @param position - target position of movement
	 * @return the speed with which we adjust
	 */
	float performAxisPosition(double position);

	/**
	 * Let the hinge joint perform a movement in direction of the given target
	 * position with the given speed as maximum speed
	 * 
	 * @param position - target position of movement
	 * @param maxSpeed - maximum allowed speed for movement (in deg/cycle)
	 */
	float performAxisPosition(double position, float maxSpeed);

	/**
	 * Adjusts the desired speed of this joint to reach current position + delta
	 * @param delta the delta angle (deg) to add to the current position
	 */
	void adjustAxisPosition(double delta);

	/**
	 * @return the motor related to this joint
	 */
	IMotor getMotor();
}