/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.agentmodel;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * SimSpark "HingeJoint" sensor read only interface.
 * 
 * @author Stefan Glaser, Klaus Dorer
 */
public interface IHingeJointR extends IJoint
{
	/**
	 * @return the minimal angle that can be reached by the joint (in degrees)
	 */
	float getMin();

	/**
	 * @return the maximal angle that can be reached by the joint (in degrees)
	 */
	float getMax();

	/**
	 * Retrieve the current axis position angle of the joint.
	 * 
	 * @return current angle of the joint (in degrees)
	 */
	float getAxis();

	/**
	 * Returns the next axis speed to the joint.<br>
	 * This method is called by the coordinator, during reflecting the future
	 * actions out of the agent model.
	 * 
	 * @return next axis speed to perform (in deg/cycle)
	 */
	float getNextAxisSpeed();

	/**
	 * @return the maximum speed this joint can go (in degree per cycle)
	 */
	float getMaxSpeed();

	Vector3D getJointAxis();

	/**
	 * @return the acceleration in deg/cycle//cycle
	 */
	public float getAcceleration();
}