/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.agentmodel;

import java.io.Serializable;
import java.util.List;
import java.util.Map;

import org.apache.commons.math3.geometry.euclidean.threed.Rotation;

/**
 * @author Stefan Glaser
 * 
 */
public interface IJoint extends ISensor, Serializable
{
	/**
	 * Called to perform a movement towards the initial position of the joint.
	 */
	void performInitialPosition();

	/**
	 * Called to reset all currently set movements of the joint and perform no
	 * movement at all (zero axis speed).
	 */
	void resetMovement();

	/**
	 * Retrieve the rotation matrix, related to the current axis positions of the
	 * joint.
	 * 
	 * @return the rotation matrix of the joint
	 */
	Rotation getRotation();

	/**
	 * Informs the action component to create action commands from this joint.
	 * @param actions a map of effector name, values pairs
	 */
	void generateJointAction(Map<String, float[]> actions);

	/**
	 * Upates the speed values of this joint by copying them from the passed
	 * joint
	 * @param joint the joint used as source
	 */
	void updateJointPositionFromJoint(IJoint joint);

	/**
	 * @return a list of joints that are sub joints. Joints that do not have
	 *         subjoints would return themselfes.
	 */
	List<IJoint> getAllSubJoints();
}
