/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 * 
 * This file is part of magmaOffenburg.
 * 
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg.  If not, see <http://www.gnu.org/licenses/>.
 ********************************************************************************/
package magma.agent.agentmodel.ik;

import magma.agent.agentmodel.IBodyPart;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

public interface IAgentIKSolver
{
	/**
	 * Solve the IK for a specific body part and the given target pose.<br>
	 * The resulting angles to the joints of the limb represented by the
	 * targetBody are expected to be set along the given body part chain. The
	 * solver is also responsible to not overdrive the joints and limit the
	 * change angles according to the max speeds and angles of the corresponding
	 * joints.
	 * 
	 * @param targetBody the target body part (representing the limb to
	 *        manipulate)
	 * @param targetPosition the target position
	 * @param targetAngles the target angles (may be null if not of interest)
	 * @return success
	 */
	public boolean solve(IBodyPart targetBody, Vector3D targetPosition,
			Vector3D targetAngles);
}
