/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 * 
 * This file is part of magmaOffenburg.
 * 
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg.  If not, see <http://www.gnu.org/licenses/>.
 ********************************************************************************/
package magma.agent.agentmodel.ik.impl;

import magma.agent.agentmodel.IBodyPart;
import magma.agent.agentmodel.IHingeJoint;
import magma.agent.agentmodel.ik.IAgentIKSolver;
import magma.util.FuzzyCompare;
import magma.util.geometry.InverseKinematics;
import magma.util.geometry.Pose3D;

import org.apache.commons.math3.geometry.euclidean.threed.CardanEulerSingularityException;
import org.apache.commons.math3.geometry.euclidean.threed.RotationOrder;
import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

public class JacobianTransposeAgentIKSolver implements IAgentIKSolver
{
	private final int iterations;

	private final double deLimit;

	private final double deTargetRange;

	public JacobianTransposeAgentIKSolver()
	{
		this(20, 0.001, 0.001);
	}

	public JacobianTransposeAgentIKSolver(int iterations, double deLimit,
			double deTargetRange)
	{
		this.iterations = iterations;
		this.deLimit = deLimit;
		this.deTargetRange = deTargetRange;
	}

	@Override
	public boolean solve(IBodyPart targetBody, Vector3D targetPosition,
			Vector3D targetAngles)
	{
		Vector3D currentPos;
		// TODO: this should be the enddefector of this bodypart
		Vector3D localEndEffectorPos = Vector3D.ZERO;

		double[][] jacobian;
		double[] dTheta;

		// Do some iterations
		for (int i = 0; i < iterations; i++) {
			// Transform local end effector position to the root-body system
			Pose3D pose = targetBody.getPose(localEndEffectorPos);
			currentPos = pose.getPosition();

			// Angles HACK
			double[] eulerAngles;
			try {
				eulerAngles = pose.getOrientation().getAngles(RotationOrder.YXZ);
			} catch (CardanEulerSingularityException e) {
				eulerAngles = new double[] { 0, 0, 0 };
				e.printStackTrace();
			}

			Vector3D currentAngles = new Vector3D(eulerAngles[2], eulerAngles[1],
					eulerAngles[0]);
			// Angles HACK

			// compute next dTheta
			jacobian = targetBody.getJacobian(localEndEffectorPos, targetAngles);
			dTheta = InverseKinematics.jacobianTranspose(targetPosition,
					currentPos, targetAngles, currentAngles, jacobian, deLimit);

			// If we reached the target position, stop the loop
			if (FuzzyCompare.eq(targetPosition, currentPos, deTargetRange)) {
				// System.out.println("reached");
				return true;
			}

			IBodyPart parentPart = targetBody;

			int j = dTheta.length - 1;
			while (parentPart.getJoint() != null) {

				((IHingeJoint) parentPart.getJoint()).adjustAxisPosition(Math
						.toDegrees(dTheta[j--]));
				parentPart = parentPart.getParent();
			}
		}

		return true;
	}
}
