/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.agentmodel.impl;

import magma.agent.agentmodel.IAccelerometer;
import magma.agent.agentmodel.ISensor;
import magma.agent.perception.IAccelerometerPerceptor;
import magma.agent.perception.IPerception;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * Implementation of the SimSpark accelerometer sensor
 * 
 * @author Ingo Schindler
 */
class Accelerometer extends Sensor implements IAccelerometer
{
	private static final long serialVersionUID = 1109699252658600557L;

	private Vector3D acceleration;

	/**
	 * Instantiates a new Accelerometer sensor
	 * 
	 * @param name Sensor Name
	 */
	public Accelerometer(String name, String perceptorName)
	{
		super(name, perceptorName);
		acceleration = Vector3D.ZERO;
	}

	/**
	 * Copy constructor
	 * @param source the object to copy from
	 */
	private Accelerometer(Accelerometer source)
	{
		super(source.name, source.perceptorName);
		acceleration = source.acceleration;
	}

	@Override
	public Vector3D getAcceleration()
	{
		return acceleration;
	}

	@Override
	public String getName()
	{
		return name;
	}

	/**
	 * Set 3-dimensional accelerations
	 * 
	 * @param value Accelerations
	 */
	void setAcceleration(Vector3D value)
	{
		double x = Double.isNaN(value.getX()) ? 0 : value.getX();
		double y = Double.isNaN(value.getY()) ? 0 : value.getY();
		double z = Double.isNaN(value.getZ()) ? 0 : value.getZ();

		acceleration = new Vector3D(x, y, z);
	}

	/**
	 * Updates this accelerometer from perception
	 * @param perception the result from server message parsing
	 */
	@Override
	public void updateFromPerception(IPerception perception)
	{
		IAccelerometerPerceptor perceptor = perception
				.getAccelerationPerceptor(getPerceptorName());
		if (perceptor != null) {
			setAcceleration(perceptor.getAcceleration());
		}
	}

	@Override
	public ISensor copy()
	{
		return new Accelerometer(this);
	}
}
