/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.agentmodel.impl;

import java.util.logging.Level;
import java.util.logging.Logger;

import magma.agent.agentmodel.ICompass;
import magma.agent.agentmodel.ISensor;
import magma.agent.perception.ICompassPerceptor;
import magma.agent.perception.IPerception;
import magma.util.geometry.Angle;

/**
 * Sweaty" sensor implementation.
 * 
 * @author David Zimmermann
 */
public class Compass extends Sensor implements ICompass
{
	private static final long serialVersionUID = 6859542740368696037L;

	/** handle for logging */
	private static final Logger logger = Logger.getLogger("");

	/** angular change to previous angle */
	private Angle angleToNorth;

	private Angle deviationAngle;

	/**
	 * Instantiates a new GyroRate sensor and initializes all values to their
	 * default
	 * 
	 * @param name sensor name
	 */
	public Compass(String name, String perceptorName)
	{
		super(name, perceptorName);
		angleToNorth = Angle.ZERO;
		deviationAngle = Angle.ZERO;
	}

	/**
	 * Copy constructor
	 * @param source the object to copy from
	 */
	public Compass(Compass source)
	{
		super(source.name, source.perceptorName);
		angleToNorth = source.angleToNorth;
		deviationAngle = source.deviationAngle;
	}

	@Override
	public Angle getAngle()
	{
		return angleToNorth.subtract(deviationAngle);
	}

	/**
	 * Set anlge values
	 * 
	 * @param Angle values
	 */
	@Override
	public void setAngle(Angle angle)
	{
		this.angleToNorth = angle;

		logger.log(Level.FINER, "compass update: {0}", angle);
	}

	/**
	 * Updates this Compass from perception
	 * @param perception the result from server message parsing
	 */
	@Override
	public void updateFromPerception(IPerception perception)
	{
		ICompassPerceptor perceptor = perception
				.getCompassPerceptor(getPerceptorName());
		if (perceptor != null) {
			setAngle(perceptor.getAngle());
		}
	}

	@Override
	public ISensor copy()
	{
		return new Compass(this);
	}

	@Override
	public void reset()
	{
		deviationAngle = angleToNorth;
	}
}
