/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.basic;

import magma.agent.behavior.IBeam;
import magma.agent.thoughtmodel.IThoughtModel;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * This Behavior is to beam the agent somewhere to the field
 * 
 * @author Ingo Schindler
 */
public class BeamBehavior extends Behavior implements IBeam
{
	/**  */
	private static final long serialVersionUID = 1L;

	/** x part of the field coordinate to beam to */
	private float x;

	/** y part of the field coordinate to beam to */
	private float y;

	/** rotation of the player 0 is to right */
	private float rotation;

	private final float z;

	/**
	 * Default constructor
	 * @param name identifier for this behavior
	 * @param thoughtModel Reference to the thought model object
	 */
	public BeamBehavior(String name, IThoughtModel thoughtModel, float beamHigh)
	{
		super(name, thoughtModel);
		z = beamHigh;
	}

	@Override
	public void perform()
	{
		agentModel.beamToPosition(new Vector3D(x, y, rotation));
		worldModel.getThisPlayer().setGlobalPosition(new Vector3D(x, y, z),
				worldModel.getGlobalTime());
	}

	@Override
	public void setPos(float x, float y, float rotation)
	{
		this.x = x;
		this.y = y;
		this.rotation = rotation;
	}

	/**
	 * Retrieve target beaming position
	 * 
	 * @return Data array. Element 0 is the target x coordinate, element 1 the
	 *         target y coordinate, element 2 the target rotation
	 */
	public float[] getPos()
	{
		float[] ret = { x, y, rotation };

		return ret;
	}
}
