/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.basic;

import magma.agent.behavior.IBehavior;
import magma.agent.thoughtmodel.IThoughtModel;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * This Behavior is to beam the agent somewhere to the field
 * 
 * @author Ingo Schindler
 */
public class BeamHomeBehavior extends BeamBehavior
{
	/**  */
	private static final long serialVersionUID = 1L;

	/**
	 * Default constructor
	 * @param name identifier for this behavior
	 * @param thoughtModel Reference to the thought model object
	 */
	public BeamHomeBehavior(String name, IThoughtModel thoughtModel,
			float beamHeigh)
	{
		super(name, thoughtModel, beamHeigh);
	}

	@Override
	public void perform()
	{
		// the position is based on if we play left to right or right to left
		Vector3D position = worldModel.getHomePosition();

		// the z component is the rotation of the player
		setPos((float) position.getX(), (float) position.getY(),
				(float) position.getZ());

		super.perform();

		// Perform initial pose
		agentModel.getFutureBodyModel().performInitialPose();
	}

	@Override
	public IBehavior switchFrom(IBehavior actualBehavior)
	{
		// the beam behavior has the highest decision priority, therefore either
		// leave or abort the actual behavior
		if (actualBehavior.isFinished()) {
			actualBehavior.onLeavingBehavior(this);
		} else {
			actualBehavior.abort();
		}

		return this;
	}
}
