/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.basic;

import magma.agent.IMagmaConstants;
import magma.agent.thoughtmodel.IThoughtModel;
import magma.agent.worldmodel.IVisibleObject;
import magma.agent.worldmodel.InformationSource;
import magma.util.SayCoder;

/**
 * Used for communication with the server
 * 
 * @author Klaus Dorer
 */
public class SayPositionsBehavior extends Behavior
{
	/**  */
	private static final long serialVersionUID = 1L;

	/**
	 * Constructor
	 * 
	 * @param thoughtModel Reference to the thought model object
	 */
	public SayPositionsBehavior(String name, IThoughtModel thoughtModel)
	{
		super(name, thoughtModel);
	}

	@Override
	public void perform()
	{
		int count = (int) (worldModel.getGlobalTime() * 100.f);
		// we may only say when it is our turn and only every 3 cycles and one
		// cycle is 20 ms
		if (count % 2 > 0) {
			// avoids a problem that server's global time sometimes is 30ms more
			count--;
		}
		int turn = ((count / 6) % IMagmaConstants.NUMBER_OF_PLAYERS_PER_TEAM) + 1;
		int ourID = worldModel.getThisPlayer().getID();
		if (turn != ourID || count % 6 != 0) {
			return;
		}

		performs++;

		String message = SayCoder.encodeID(ourID);
		message += SayCoder.encodePosition(worldModel.getThisPlayer()
				.getPosition());

		// communicate ball position
		if (worldModel.getBall().getAge(worldModel.getGlobalTime()) < 0.1
				&& worldModel.getBall().getInformationSource() == InformationSource.VISION) {
			// only say if ball has been seen recently
			message += SayCoder.encodePosition(worldModel.getBall().getPosition());
		} else {
			message += SayCoder.encodeInvalidPosition();
		}

		// communicate opponent position (same id)
		IVisibleObject player = worldModel.getVisiblePlayer(ourID, false);
		if (player != null && player.getAge(worldModel.getGlobalTime()) < 0.1
				&& player.getInformationSource() == InformationSource.VISION) {
			message += SayCoder.encodePosition(player.getPosition());
		} else {
			message += SayCoder.encodeInvalidPosition();
		}

		// communicate opponent position (next id)
		IVisibleObject player2 = worldModel.getVisiblePlayer(
				((ourID + 5) % IMagmaConstants.NUMBER_OF_PLAYERS_PER_TEAM) + 1,
				false);
		if (player2 != null && player2.getAge(worldModel.getGlobalTime()) < 0.1
				&& player2.getInformationSource() == InformationSource.VISION) {
			message += SayCoder.encodePosition(player2.getPosition());
		} else {
			message += SayCoder.encodeInvalidPosition();
		}

		message += SayCoder.encodeName(worldModel.getThisPlayer().getTeamname());

		agentModel.sayMessage(message);
	}

}
