/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.complex;

import java.util.Map;
import java.util.logging.Level;

import magma.agent.behavior.IBehavior;
import magma.agent.behavior.IBehaviorConstants;
import magma.agent.thoughtmodel.IThoughtModel;
import magma.util.geometry.Pose2D;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * @author Pret
 * 
 */
public class GoalieStrikePositioning extends SingleComplexBehavior
{
	/**  */
	private static final long serialVersionUID = 1L;

	/**
	 * Constructor
	 * 
	 * @param thoughtModel Reference to the thought model object
	 * @param behaviors List of applicable behaviors
	 */
	public GoalieStrikePositioning(IThoughtModel thoughtModel,
			Map<String, IBehavior> behaviors)
	{
		super(IBehaviorConstants.GOALIE_STRIKE_POSITIONING, thoughtModel,
				behaviors);
	}

	@Override
	public IBehavior decideNextBasicBehavior()
	{
		Vector3D ball = worldModel.getBall().getPosition();

		float fieldHalfLength = worldModel.fieldHalfLength();
		double xOffsetFromGoal = 0.2;

		double newX = -fieldHalfLength + xOffsetFromGoal;
		double newY = worldModel.goalHalfWith() / 2;

		if (ball.getY() < 0) {
			newY = -newY;
		}

		Pose2D result = new Pose2D(newX, newY);

		RunToPosition runToPosition = (RunToPosition) behaviors
				.get(IBehaviorConstants.RUN_TO_POSITION);

		runToPosition.setPosition(result, 0, 0, 90, false);

		logger.log(Level.FINE,
				"goaliePositioning position(x,y) ({0},{1}), angle: {2}",
				new Object[] { result.getX(), result.getY(),
						result.getAngle().degrees() });

		return runToPosition;
	}
}
