/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package magma.agent.behavior.complex;

import java.awt.geom.Line2D;
import java.util.Map;

import magma.agent.behavior.IBehavior;
import magma.agent.behavior.IBehaviorConstants;
import magma.agent.thoughtmodel.IThoughtModel;
import magma.util.geometry.Angle;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * Class in which the Goalie decides in which side to keep
 * @author Rajit Shahi
 * 
 */
public class Keep extends SingleComplexBehavior
{

	/**  */
	private static final long serialVersionUID = 1L;

	/** the height of the player */
	private final float playerHeight;

	private IBehavior keepLeftBehavior;

	private IBehavior keepRightBehavior;

	/** the number of cycles we predict ball position into future */
	private final int goalPredictionTime;

	/**
	 * Constructor
	 * 
	 * @param thoughtModel Reference to the thought model object
	 * @param behaviors A list of behaviors
	 * @param keepLeftBehaviorName The name of the keep-left behavior
	 * @param keepRightBehaviorName The name of the keep-right behavior
	 */
	public Keep(IThoughtModel thoughtModel, Map<String, IBehavior> behaviors,
			float playerHeight, int goalPredictionTime,
			IBehavior keepLeftBehavior, IBehavior keepRightBehavior)
	{
		super(IBehaviorConstants.KEEP, thoughtModel, behaviors);
		this.goalPredictionTime = goalPredictionTime;
		this.keepLeftBehavior = keepLeftBehavior;
		this.keepRightBehavior = keepRightBehavior;
		this.playerHeight = playerHeight * 1.2f;
	}

	@Override
	public IBehavior decideNextBasicBehavior()
	{
		Vector3D[] futureBallPositions = worldModel.getBall().getFuturePositions(
				goalPredictionTime);
		Vector3D futureBallPosition = futureBallPositions[futureBallPositions.length - 1];
		Vector3D ballPosition = worldModel.getBall().getPosition();

		Line2D ballLine = new Line2D.Double(futureBallPosition.getX(),
				futureBallPosition.getY(), ballPosition.getX(), ballPosition.getY());

		Vector3D playerPosition = worldModel.getThisPlayer().getPosition();
		Angle playerAngle = worldModel.getThisPlayer().getHorizontalAngle();

		Vector3D left = new Vector3D(playerAngle.add(Math.PI / 2).radians(), 0);
		if (left.getNorm() > 0.001) {
			left = left.normalize().scalarMultiply(playerHeight)
					.add(playerPosition);
		}
		Line2D playerDiameterLeft = new Line2D.Double(playerPosition.getX(),
				playerPosition.getY(), left.getX(), left.getY());

		if (playerDiameterLeft.intersectsLine(ballLine)) {
			System.out.println("Keep left");
			return keepLeftBehavior;
		}

		System.out.println("Keep right");
		return keepRightBehavior;
	}
}
