/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.complex;

import java.util.Map;

import magma.agent.behavior.IBehavior;
import magma.agent.behavior.IBehaviorConstants;
import magma.agent.thoughtmodel.IThoughtModel;
import magma.agent.worldmodel.IMoveableObject;
import magma.util.geometry.Angle;
import magma.util.geometry.Pose2D;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * Behavior to run to the ball
 * 
 * @author Klaus Dorer
 */
public class MoveWithBall extends SingleComplexBehavior
{
	/**  */
	private static final long serialVersionUID = 1L;

	/**
	 * Default constructor
	 * 
	 * @param thoughtModel Reference to the thought model object
	 * @param behaviors List of applicable behaviors
	 */
	public MoveWithBall(IThoughtModel thoughtModel,
			Map<String, IBehavior> behaviors)
	{
		super(IBehaviorConstants.MOVE_WITH_BALL, thoughtModel, behaviors);
	}

	@Override
	public IBehavior decideNextBasicBehavior()
	{
		Pose2D pose = thoughtModel.getRole().getTargetPosition();
		Angle direction = pose.getAngle();
		Vector3D newPosition = pose.getPosition();

		// avoid to position too close to the ball
		IMoveableObject ball = worldModel.getBall();
		if (ball.getDistanceToXY(newPosition) < 1.3) {
			double dir = worldModel.getThisPlayer().getDirectionTo(ball).radians();
			newPosition = ball.getPosition().add(-1.3, new Vector3D(dir, 0));
		}

		RunToPosition runToPosition = (RunToPosition) behaviors
				.get(IBehaviorConstants.RUN_TO_POSITION);
		Pose2D newPose = new Pose2D(newPosition, direction);
		runToPosition.setPosition(newPose, 0, 0, 90, true);

		return runToPosition;
	}
}
