/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 * 
 * This file is part of magmaOffenburg.
 * 
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg.  If not, see <http://www.gnu.org/licenses/>.
 ********************************************************************************/
package magma.agent.behavior.complex;

import java.util.Map;

import magma.agent.behavior.IBehavior;
import magma.agent.behavior.IBehaviorConstants;
import magma.agent.thoughtmodel.IThoughtModel;

/**
 * Behavior that performs remote commands.
 * 
 * @author Stefan Glaser
 */
public class RemoteCommandBehavior extends SingleComplexBehavior
{
	/**  */
	private static final long serialVersionUID = 1L;

	enum RemoteCommands {
		FORWARD("forward"), //
		STOP("stop"), //
		LEFT("left"), //
		RIGHT("right"), //
		WAVE("wave");

		private String name;

		private RemoteCommands(String name)
		{
			this.name = name;
		}

		static RemoteCommands byName(String name)
		{
			for (RemoteCommands c : RemoteCommands.values()) {
				if (c.name.equals(name)) {
					return c;
				}
			}

			return null;
		}
	}

	private RemoteCommands currentCommand;

	/**
	 * Constructor
	 * 
	 * @param thoughtModel Reference to the thought model object
	 * @param behaviors A list of behaviors
	 * @param keepLeftBehaviorName The name of the keep-left behavior
	 * @param keepRightBehaviorName The name of the keep-right behavior
	 */
	public RemoteCommandBehavior(IThoughtModel thoughtModel,
			Map<String, IBehavior> behaviors)
	{
		super(IBehaviorConstants.REMOTE_COMMAND, thoughtModel, behaviors,
				behaviors.get(IBehaviorConstants.NONE));

		currentCommand = RemoteCommands.STOP;
	}

	@Override
	public IBehavior decideNextBasicBehavior()
	{
		RemoteCommands newCommand = RemoteCommands.byName(thoughtModel
				.getRemoteCommand());

		if (newCommand != null) {
			if (newCommand != currentCommand
					&& currentCommand == RemoteCommands.FORWARD) {
				// Ensure stop walking
				newCommand = RemoteCommands.STOP;
			}
			currentCommand = newCommand;

			switch (currentCommand) {
			case FORWARD:
				return behaviors.get(IBehaviorConstants.STARTWALK);
			case LEFT:
				return behaviors.get("A_Goalie_Left_30cm");
			case RIGHT:
				return behaviors.get("A_Goalie_Right_30cm");
			case WAVE:
				return behaviors.get(IBehaviorConstants.MOVE_ZERO);
			case STOP:
			default:
				return behaviors.get(IBehaviorConstants.STOPWALK);
			}
		} else {
			System.out.println("Unknown command: "
					+ thoughtModel.getRemoteCommand());
		}

		return behaviors.get(IBehaviorConstants.NONE);
	}
}
