/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package magma.agent.behavior.complex;

import java.util.Map;

import magma.agent.behavior.IBehavior;
import magma.agent.behavior.IBehaviorConstants;
import magma.agent.thoughtmodel.IThoughtModel;

/**
 * Class in which the Goalie decides in which side to keep
 * @author Rajit Shahi
 * 
 */
public class RemoteControllBehavior extends SingleComplexBehavior
{

	/**  */
	private static final long serialVersionUID = 1L;

	/**
	 * Constructor
	 * 
	 * @param thoughtModel Reference to the thought model object
	 * @param behaviors A list of behaviors
	 * @param keepLeftBehaviorName The name of the keep-left behavior
	 * @param keepRightBehaviorName The name of the keep-right behavior
	 */
	public RemoteControllBehavior(IThoughtModel thoughtModel,
			Map<String, IBehavior> behaviors)
	{
		super(IBehaviorConstants.REMOTE_CONTROLL, thoughtModel, behaviors);
	}

	@Override
	public IBehavior decideNextBasicBehavior()
	{
		String command = thoughtModel.getRemoteCommand();

		IBehavior behavior = behaviors.get(command);
		if (behavior == null) {
			// System.out.println("Unknown behavior: " + command);
			behavior = behaviors.get(IBehaviorConstants.MOVE_ZERO);
		}
		return behavior;
	}
}
