/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.complex;

import java.util.Map;
import java.util.logging.Level;

import magma.agent.behavior.IBehavior;
import magma.agent.behavior.IBehaviorConstants;
import magma.agent.behavior.IKick;
import magma.agent.thoughtmodel.IThoughtModel;

/**
 * Implements a behavior which knows how to shoot a ball in direction of the
 * opponent goal
 * 
 * @author Klaus Dorer, Ingo Schindler
 */
public class ShootToGoal extends SingleComplexBehavior
{
	/**  */
	private static final long serialVersionUID = 1L;

	/**
	 * Constructor
	 * 
	 * @param thoughtModel Reference to the thought model object
	 * @param behaviors List of applicable behaviors
	 */
	public ShootToGoal(IThoughtModel thoughtModel,
			Map<String, IBehavior> behaviors)
	{
		super(IBehaviorConstants.SHOOT_TO_GOAL, thoughtModel, behaviors);
	}

	@Override
	public IBehavior decideNextBasicBehavior()
	{
		// Angle goalAngle1 = thisPlayer.getBodyDirectionTo(worldModel
		// .getOtherGoalPosition());
		// double goalAngle = goalAngle1.degrees();

		IKick shoot = (IKick) behaviors.get(IBehaviorConstants.SHOOT_STRAIGHT);
		// shoot.setStrength(shootSpeedFactor);

		// if (thisPlayer.isInsidePolygonXY(ballPos,
		// shoot.getKickableRectangle())) {
		shoot.setIntendedKickDirection(thoughtModel.getPreferredKickDirection());
		if (shoot.isBallKickable() > 0) {
			return shoot;
			// if (thisPlayer.isInsidePolygonXY(ballPos,
			// agentModel.getBothLegKickRectangle())) {
			// // ball is kickable by both feet
			// // if (goalAngle < 0) {
			// // // the goal is to the right, kicking with left leg in this
			// // // area usually lets the ball drift right of the straight line
			// // // from robot through ball is of the left side of the goal center
			// // return behaviors.get(IBehaviorConstants.SHOOT_LEFT);
			// // }
			// //
			// // return behaviors.get(IBehaviorConstants.SHOOT_RIGHT);
			// return shoot;
			//
			// // ball kickable by single leg?
			// } else if (thisPlayer.isInsidePolygonXY(ballPos,
			// agentModel.getLeftLegKickRectangle())) {
			// // return behaviors.get(IBehaviorConstants.SHOOT_LEFT);
			// return shoot;
			//
			// } else if (thisPlayer.isInsidePolygonXY(ballPos,
			// agentModel.getRightLegKickRectangle())) {
			// // return behaviors.get(IBehaviorConstants.SHOOT_RIGHT);
			// return shoot;
		} else {
			// this should not happen
			logger.log(Level.WARNING,
					"Should not happen: ShootToGoal and ball is not kickable");
			return behaviors.get(IBehaviorConstants.RUN_TO_POSITION);
		}
	}

	/**
	 * Set shooting speed
	 * 
	 * @param factor Speed factor
	 */
	public void setShootSpeed(int factor)
	{
		// currently not supported
	}
}
