/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 * 
 * This file is part of magmaOffenburg.
 * 
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg.  If not, see <http://www.gnu.org/licenses/>.
 ********************************************************************************/
package magma.agent.behavior.complex;

import java.util.Collections;
import java.util.List;
import java.util.Map;

import magma.agent.behavior.IBehavior;
import magma.agent.thoughtmodel.IThoughtModel;

/**
 * Convenience class for complex behaviors which decide only for a single next
 * behavior.
 * 
 * @see ComplexBehavior
 * @author Stefan Glaser
 */
public abstract class SingleComplexBehavior extends ComplexBehavior
{
	/** */
	private static final long serialVersionUID = -4561834347758268093L;

	/**
	 * Default constructor for single complex behaviors
	 * 
	 * @param name name of behavior
	 * @param thoughtModel Reference to the thought model object
	 * @param behaviors map of all available behaviors
	 * @param defaultBehavior the default behavior to start with
	 */
	public SingleComplexBehavior(String name, IThoughtModel thoughtModel,
			Map<String, IBehavior> behaviors, IBehavior defaultBehavior)
	{
		super(name, thoughtModel, behaviors, defaultBehavior);
	}

	/**
	 * Default constructor for single complex behaviors
	 * 
	 * @param name name of behavior
	 * @param thoughtModel Reference to the thought model object
	 * @param behaviors map of all available behaviors
	 */
	public SingleComplexBehavior(String name, IThoughtModel thoughtModel,
			Map<String, IBehavior> behaviors)
	{
		super(name, thoughtModel, behaviors);
	}

	@Override
	protected List<IBehavior> decideNextBasicBehaviors()
	{
		return Collections.singletonList(decideNextBasicBehavior());
	}

	/**
	 * Decide for a single next behavior. <br>
	 */
	protected abstract IBehavior decideNextBasicBehavior();
}
