/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 */

package magma.agent.behavior.motor;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

import magma.util.function.IFunction;

/**
 * 
 * @author kdorer
 */
public class FunctionBehaviorMirror
{

	/**
	 * @param args
	 */
	public static void main(String[] args)
	{
		getMirroredVersion(
				"config/behaviors/nao/FunctionBehaviors/UsedBehaviors/",
				"A_Goalie_Right_30cm.txt", "A_Goalie_Left_30cm");
	}

	public static void getMirroredVersion(String path, String sourceFile,
			String destinationName)
	{
		System.out.println("Mirror " + path + sourceFile + "\nto "
				+ destinationName + ".txt");
		try {
			File file = new File(path + sourceFile);
			FunctionBehaviorParameter behavior = FunctionBehaviorParameter
					.readBehaviorFile(null, file);

			FunctionBehaviorParameter convertedBehavior = convert(behavior,
					destinationName);

			File outFile = new File(path + destinationName + ".txt");
			FunctionBehaviorParameter
					.writeBehaviorFile(outFile, convertedBehavior);

		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

	/**
	 * @param behavior
	 * @return
	 */
	private static FunctionBehaviorParameter convert(
			FunctionBehaviorParameter behavior, String name)
	{
		Map<String, IFunction> newJoints = new HashMap<String, IFunction>();
		Map<String, IFunction> oldJoints = behavior.getJoints();

		for (String oldName : oldJoints.keySet()) {
			IFunction oldFunction = oldJoints.get(oldName);
			if (oldName.startsWith("R")) {
				mirror("L", oldName, oldFunction, newJoints);

			} else if (oldName.startsWith("L")) {
				mirror("R", oldName, oldFunction, newJoints);

			} else {
				// joint without side, no mirror
				newJoints.put(oldName, oldFunction);
			}
		}

		return new FunctionBehaviorParameter(null, name, behavior.getVersion(),
				behavior.getPeriod(), newJoints);
	}

	/**
	 * @param string
	 * @param oldName
	 * @param oldFunction
	 * @param newJoints
	 */
	private static void mirror(String replacer, String oldName,
			IFunction oldFunction, Map<String, IFunction> newJoints)
	{
		String newName = replacer + oldName.substring(1, oldName.length());
		IFunction newFunction = oldFunction;
		if ((oldName.contains("Roll") || oldName.contains("Yaw"))
				&& !oldName.contains("ArmRoll")) {
			// roll support points have to be negated in y values
			// exception for arm roll which is missnamed and is a pitch joint!
			newFunction.mirrorYFunction();
		}
		newJoints.put(newName, newFunction);
	}
}
