/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package magma.agent.behavior.movement;

import magma.agent.behavior.basic.Behavior;
import magma.agent.thoughtmodel.IThoughtModel;
import magma.robots.nao.INaoConstants;

/**
 * 
 * @author dorer
 */
public abstract class MovementBehavior extends Behavior
{
	/**  */
	private static final long serialVersionUID = 1L;

	/** true if this behavior is over (candidate for Behavior class?) */
	protected boolean isFinished;

	/** the current movement of this behavior */
	protected Movement currentMovement;

	/** get into position to start walking */
	protected Movement getReady;

	/**
	 * @param name
	 * @param thoughtModel
	 */
	public MovementBehavior(String name, IThoughtModel thoughtModel)
	{
		super(name, thoughtModel);
		isFinished = false;

		getReady = new Movement("getReady");
		getReady.add(new MovementPhase("getReady", 20) //
				.add(INaoConstants.LShoulderPitch, -80, 3f) //
				.add(INaoConstants.RShoulderPitch, -80, 3f) //
				.add(INaoConstants.LHipPitch, 35, 2f) //
				.add(INaoConstants.LKneePitch, -70, 4f) //
				.add(INaoConstants.LFootPitch, 35, 2f) //
				.add(INaoConstants.RHipPitch, 35, 2f) //
				.add(INaoConstants.RKneePitch, -70, 4f) //
				.add(INaoConstants.RFootPitch, 35, 2f) //
				.add(INaoConstants.LHipRoll, 0, 1f) //
				.add(INaoConstants.LFootRoll, 0, 1f) //
				.add(INaoConstants.RHipRoll, 0, 1f) //
				.add(INaoConstants.RFootRoll, 0, 1f) //
				);
	}

	/**
	 * Copy constructor
	 * @param source
	 */
	public MovementBehavior(MovementBehavior source)
	{
		super(source);
		this.isFinished = source.isFinished;
	}

	/**
	 * @param newMovement
	 */
	protected void switchTo(Movement newMovement)
	{
		currentMovement = newMovement;
		currentMovement.init();
	}

	@Override
	public void perform()
	{
		if (currentMovement == null) {
			currentMovement = getInitialMovement();
		}
		isFinished = false;
		currentMovement.perform(agentModel);
		if (currentMovement.isFinished()) {
			Movement nextMovement = getNextMovement();
			if (nextMovement == null) {
				isFinished = true;
				nextMovement = getInitialMovement();
			}
			switchTo(nextMovement);
		}
	}

	protected abstract Movement getInitialMovement();

	protected Movement getNextMovement()
	{
		return null;
	}

	@Override
	public boolean isFinished()
	{
		return isFinished;
	}

	@Override
	public void init()
	{
		super.init();
		isFinished = false;
		switchTo(getInitialMovement());
	}
}
