/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.supportPoint;

import magma.agent.behavior.supportPoint.BMBStateFactory.BehaviorStateEnum;
import magma.agent.behavior.supportPoint.BasicMotorBehavior.BehaviorEvent;
import magma.util.statemachine.IStateFactory;
import magma.util.statemachine.ObjectState;

/**
 * Base class for the cleaner's state machine
 * 
 * @author Klaus Dorer
 */
abstract class BMBState extends ObjectState<BehaviorStateEnum, BehaviorEvent>
{
	/**
	 * Default constructor
	 * @param factory the state factory that contains this state
	 */
	BMBState(IStateFactory<BehaviorStateEnum, BehaviorEvent> factory)
	{
		super(factory);
	}

	/**
	 * Called to perform the behavior
	 * 
	 * @param behavior Behavior to perform
	 */
	public abstract void perform(BasicMotorBehavior behavior);

	/**
	 * Calculate behavior speed
	 * 
	 * @param behavior Behavior
	 * @param delta Delta value
	 * @return Speed
	 */
	public abstract float calculateSpeed(BasicMotorBehavior behavior, float delta);

	@Override
	protected BMBState switchTo(BehaviorStateEnum newStateID, Object context)
	{
		return (BMBState) super.switchTo(newStateID, context);
	}
}
