/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.belief.impl;

import java.awt.geom.Line2D;

import magma.agent.belief.IBeliefConstants;
import magma.agent.thoughtmodel.IThoughtModel;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * Belief to decide if the Ball could possibly end in goal for the goal keeping
 * behavior
 * @author Rajit Shahi
 * 
 */
public class BallEndsUpInOwnGoal extends Belief
{

	/**
	 * the shift of the goal line to make the goal line look closer than it
	 * actually is
	 */
	private static final double X_EXTENSION = 0.3;

	/**
	 * the extension of the goal line in y direction, to make the goal wider than
	 * it actually is
	 */
	private static final double Y_EXTENSION = 0.4;

	/**
	 * Number of times to estimate the position of the ball
	 */
	private static final int GOAL_PREDICTION_TIME = 60;

	/**
	 * Constructor
	 * 
	 * @param agentModel Reference to the thought model object
	 */
	public BallEndsUpInOwnGoal(IThoughtModel thoughtModel)
	{
		super(IBeliefConstants.BALL_ENDS_UP_IN_GOAL, thoughtModel);
	}

	@Override
	public float getTruthValue()
	{
		Vector3D futureBallPosition = worldModel.getBall().getFuturePosition(
				GOAL_PREDICTION_TIME);
		Vector3D ballPosition = worldModel.getBall().getPosition();

		Line2D ballLine = new Line2D.Double(futureBallPosition.getX(),
				futureBallPosition.getY(), ballPosition.getX(), ballPosition.getY());

		double xextension = X_EXTENSION;
		double x1 = -worldModel.fieldHalfLength();
		double y1 = worldModel.goalHalfWith();

		double x2 = -worldModel.fieldHalfLength();
		double y2 = -worldModel.goalHalfWith();

		Line2D goalLine = new Line2D.Double(x1 + xextension, y1 + Y_EXTENSION, x2
				+ xextension, y2 - Y_EXTENSION);

		if (goalLine.intersectsLine(ballLine)) {
			return 1;
		}

		return 0;
	}

}
