/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.belief.impl;

import magma.agent.belief.IBeliefConstants;
import magma.agent.thoughtmodel.IThoughtModel;
import magma.agent.worldmodel.IVisibleObject;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * Checks if the ball is in a "critical" area, indicating that the goalie should
 * run to the ball
 */
public class BallInCriticalArea extends Belief
{
	/**
	 * Constructor
	 * 
	 * @param agentModel Reference to the thought model object
	 */
	public BallInCriticalArea(IThoughtModel thoughtModel)
	{
		super(IBeliefConstants.BALL_IN_CRITICAL_AREA, thoughtModel);
	}

	@Override
	public float getTruthValue()
	{
		Vector3D ownGoal = worldModel.getOwnGoalPosition();
		IVisibleObject ball = worldModel.getBall();

		if (ball.getDistanceToXY(ownGoal) < 1.8) {
			return 1.0f;
		}
		return 0.0f;
	}
}
