/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.belief.impl;

import java.util.logging.Level;

import magma.agent.belief.IBeliefConstants;
import magma.agent.thoughtmodel.IThoughtModel;
import magma.agent.worldmodel.IThisPlayer;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * Checks if the ball is close enough to be kicked
 * @author Klaus Dorer
 */
public class BallKickable extends Belief
{
	/**
	 * Default constructor
	 * 
	 * @param agentModel Reference to the thought model object
	 */
	public BallKickable(IThoughtModel thoughtModel)
	{
		super(IBeliefConstants.BALL_KICKABLE, thoughtModel);
	}

	@Override
	public float getTruthValue()
	{
		IThisPlayer thisPlayer = worldModel.getThisPlayer();
		Vector3D ballPos = worldModel.getBall().getPosition();
		/**
		 * just for testing i have changed the return of each situation(1.0-3.0
		 * usually every return is 1.0f
		 */
		// we are aligned to goal
		if (thisPlayer
				.isInsidePolygonXY(ballPos, agent.getBothLegKickRectangle())) {
			// ball is kickable by both feet
			logger.log(Level.FINEST, "BothLegs kickable");
			return 1.0f;

			// ball kickable by single leg?
		} else if (thisPlayer.isInsidePolygonXY(ballPos,
				agent.getLeftLegKickRectangle())) {
			logger.log(Level.FINEST, "Left leg kickable");
			return 2.0f;

		} else if (thisPlayer.isInsidePolygonXY(ballPos,
				agent.getRightLegKickRectangle())) {
			logger.log(Level.FINEST, "Right leg kickable");
			return 3.0f;
		}

		return 0.0f;
	}
}
