/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.belief.impl;

import java.util.logging.Logger;

import magma.agent.agentmodel.IAgentModel;
import magma.agent.belief.IBelief;
import magma.agent.thoughtmodel.IThoughtModel;
import magma.agent.worldmodel.IGlobalMap;

/**
 * Base class for all Believes
 */
public abstract class Belief implements IBelief
{
	/** handle for logging */
	protected static final Logger logger = Logger.getLogger("");

	/** the name of the believe used to display */
	protected final String name;

	/** link to the agent model */
	protected final transient IAgentModel agent;

	/** link to the world model */
	protected final transient IGlobalMap worldModel;

	/** link to the thought model */
	protected final transient IThoughtModel thoughtModel;

	/**
	 * Constructor
	 * 
	 * @param name Belief name
	 * @param thoughtModel Reference to the thought model object
	 */
	public Belief(String name, IThoughtModel thoughtModel)
	{
		this.name = name;
		this.thoughtModel = thoughtModel;
		if (thoughtModel != null) {
			this.agent = thoughtModel.getAgentModel();
			this.worldModel = thoughtModel.getWorldModel();
		} else {
			this.agent = null;
			this.worldModel = null;
		}
	}

	@Override
	public abstract float getTruthValue();

	@Override
	public String getName()
	{
		return name;
	}
}
