/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.belief.impl;

import magma.agent.belief.IBeliefConstants;
import magma.agent.thoughtmodel.IThoughtModel;
import magma.agent.worldmodel.IMoveableObject;
import magma.agent.worldmodel.IThisPlayer;
import magma.util.geometry.Angle;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * Checks if the goalie would kick in the wrong direction (own goal)
 * @author Maximilian Kroeg
 */
public class GoalieShouldKick extends Belief
{
	/**  */
	static final float BEHIND_BALL_DISTANCE = 0.15f;

	/**
	 * Default constructor
	 * 
	 * @param agentModel Reference to the thought model object
	 */
	public GoalieShouldKick(IThoughtModel thoughtModel)
	{
		super(IBeliefConstants.GOALIE_SHOULD_KICK, thoughtModel);
	}

	@Override
	public float getTruthValue()
	{
		IMoveableObject ball = worldModel.getBall();
		// Vector3D ballPosition = ball.getPosition();
		IThisPlayer thisPlayer = worldModel.getThisPlayer();

		// Vector3D otherGoalPosition = worldModel.getOtherGoalPosition();
		// Vector3D shootVector = otherGoalPosition.subtract(ballPosition);
		// FEATURE: uncomment these lines to use the dynamic shoot direction
		// provided by the worldModel
		// Vector3D shootVector = new Vector3D(worldModel
		// .getPreferredKickDirection().radians(), 0);

		// Vector3D weBall = ballPosition.subtract(thisPlayer.getPosition());
		// Vector3D scorePosition = ballPosition.add(-BEHIND_BALL_DISTANCE,
		// shootVector.normalize());

		// we run to some point that is opposite of ball-goal direction
		// Vector3D shoot2D = new Vector3D(shootVector.getX(), shootVector.getY(),
		// 0);
		// Vector3D meBall2D = new Vector3D(weBall.getX(), weBall.getY(), 0);
		// Angle delta1 = Angle.rad(Vector3D.angle(shoot2D, meBall2D));
		// double delta = Math.abs(delta1.degrees());

		final double safetyDistance = 1.0;
		Vector3D goal = worldModel.getOwnGoalPosition();
		Vector3D goalLeft = goal.add(new Vector3D(0, -worldModel.goalHalfWith()
				- safetyDistance, 0));
		Vector3D goalRight = goal.add(new Vector3D(0, worldModel.goalHalfWith()
				+ safetyDistance, 0));

		Angle playerBall = thisPlayer.getDirectionTo(ball);
		Angle playerGoalLeft = thisPlayer.getDirectionTo(goalLeft);
		Angle playerGoalRight = thisPlayer.getDirectionTo(goalRight);

		if (playerBall.isRightOf(playerGoalLeft)
				&& playerBall.isLeftOf(playerGoalRight)) {
			return 0.0f;
		}
		return 1.0f;
	}

}
