/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.belief.impl;

import java.util.Map;

import magma.agent.belief.IBeliefConstants;
import magma.agent.thoughtmodel.IThoughtModel;
import magma.agent.worldmodel.IPlayer;
import magma.agent.worldmodel.IVisibleObject;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * Checks if the ball is in a "critical" area, indicating that the goalie should
 * run to the ball
 */
public class OpponentWillKick extends Belief
{
	/**
	 * Constructor
	 * 
	 * @param agentModel Reference to the thought model object
	 */
	public OpponentWillKick(IThoughtModel thoughtModel)
	{
		super(IBeliefConstants.OPPONENT_WILL_KICK, thoughtModel);
	}

	@Override
	public float getTruthValue()
	{
		IVisibleObject ball = worldModel.getBall();

		IPlayer opponentAtBall = thoughtModel.getOpponentAtBall();
		if (opponentAtBall != null) {
			Map<String, Vector3D> bodyParts = opponentAtBall.getBodyParts();
			Vector3D lfoot = bodyParts.get("lfoot");
			Vector3D rfoot = bodyParts.get("rfoot");
			if (lfoot != null && rfoot != null) {
				double distance = opponentAtBall.getDistanceToXY(ball);
				if (distance < 0.4) {
					double footZDistance = Math.abs(lfoot.getZ() - rfoot.getZ());
					System.out.println("footZDistance: " + footZDistance);
					if (footZDistance > 0.1) {
						return 1.0f;
					}
				}
			}
		}

		return 0.0f;
	}

}
