/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.belief.impl;

import magma.agent.belief.IBeliefConstants;
import magma.agent.thoughtmodel.IThoughtModel;
import magma.agent.worldmodel.IMoveableObject;

/**
 * Checks if the ball was seen in the last x seconds.
 * @author Maximilian Krög
 */
public class SeeBall extends Belief
{
	/** Maximum time we believe we know where the ball is. In seconds */
	private static final float LAST_SEEN_THRESHHOLD = 3.0f;

	/**
	 * Default constructor
	 * 
	 * @param agentModel Reference to the thought model object
	 */
	public SeeBall(IThoughtModel thoughtModel)
	{
		super(IBeliefConstants.SEE_BALL, thoughtModel);
	}

	@Override
	public float getTruthValue()
	{
		IMoveableObject ball = worldModel.getBall();
		float lastSeen = ball.getAge(worldModel.getGlobalTime());
		if (lastSeen < LAST_SEEN_THRESHHOLD) {
			return 1.0f;
		}
		return 0.0f;
	}

}
