/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 */

package magma.agent.belief.impl;

import magma.agent.belief.IBelief;

/**
 * Decorates a belief allowing to specify, how many cycles a belief has to be
 * true, so that it really returns true and vice versa.
 * 
 * @author kdorer
 */
public class StableBeliefDecorator implements IBelief
{
	/** the decorated belief */
	private IBelief decoratee;

	private long trueCount;

	private long falseCount;

	private int trueMin;

	private int falseMin;

	public StableBeliefDecorator(IBelief decoratee, int trueMin, int falseMin)
	{
		this.decoratee = decoratee;
		this.trueMin = trueMin;
		this.falseMin = falseMin;
		trueCount = 0;
		falseCount = 0;
	}

	@Override
	public float getTruthValue()
	{
		float baseBeliefe = decoratee.getTruthValue();
		if (baseBeliefe < 0.5) {
			falseCount++;
			if (falseCount > falseMin) {
				trueCount = 0;
				return baseBeliefe;
			}
			if (falseCount > trueCount) {
				return baseBeliefe;
			}
			return 1.0f;
		} else {
			trueCount++;
			if (trueCount > trueMin) {
				falseCount = 0;
				return baseBeliefe;
			}
			if (trueCount > falseCount) {
				return baseBeliefe;
			}
			return 0.0f;
		}
	}

	@Override
	public String getName()
	{
		return decoratee.getName();
	}

}
