/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.belief.impl;

import magma.agent.belief.IBeliefConstants;
import magma.agent.thoughtmodel.IThoughtModel;

/**
 * @author Klaus Dorer
 * 
 */
public class TemperatureHot extends Belief
{
	private double warm;

	private double hot;

	/**
	 * Default constructor
	 * 
	 * @param agentModel Reference to the thought model object
	 * @param warm temperature above which we consider the temperature to be too
	 *        warm to play
	 * @param hot temperature above which we shut off motors completely
	 */
	public TemperatureHot(IThoughtModel thoughtModel, double warm, double hot)
	{
		super(IBeliefConstants.TEMPERATURE_HOT, thoughtModel);
		this.warm = warm;
		this.hot = hot;
	}

	@Override
	public float getTruthValue()
	{
		double maxCoilTemperature = agent.getMaxCoilTemperature();
		if (maxCoilTemperature > hot) {
			return 1.0f;
		}

		if (maxCoilTemperature > warm) {
			return 0.5f;
		}

		return 0.0f;
	}
}
