/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 */

package magma.agent.communication;

import java.util.Map;

import magma.agent.action.IActionPerformer;
import magma.agent.perception.IPerceptor;

/**
 * 
 * @author kdorer
 */
public interface IChannelManager extends IActionPerformer
{
	public enum ChannelManagerStatus {
		CREATED, STARTED, STOPPED, LOST_MAIN_CONNECTION
	};

	void addPerceptors(Map<String, IPerceptor> newPerceptors);

	/**
	 * @param channel
	 */
	void addInputChannel(IInputChannel channel, boolean isMainChannel);

	/**
	 * @param channel
	 */
	void addOutputChannel(IOutputChannel channel);

	/**
	 * @return
	 */
	boolean start();

	/**
	 * 
	 */
	void stop();

	/**
	 * @return
	 */
	boolean isConnected();

	/**
	 * @return the next map of perceptors to process, null if there is none
	 */
	Map<String, IPerceptor> getNextPerceptorMap();

	/**
	 * Called if a connection of an input channel is lost
	 */
	void lostConnection(IInputChannel channel);

	ChannelManagerStatus getStatus();
}
