/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.communication.base;

/**
 * Stores all necessary plaser parameters (Server connection, decision maker
 * etc.)#
 * 
 * @author Klaus Dorer
 */
public class ChannelParameters
{
	private final String teamname;

	private final byte teamID;

	private final int playerNumber;

	private final String host;

	private final int port;

	/**
	 * Instantiates and initializes a new PlayerParameters object
	 * 
	 * @param teamname Team name
	 * @param playerNumber Player number
	 * @param host Server host
	 * @param port Server port
	 * @param behaviorParams Behavior parameters
	 * @param level Logging level
	 * @param serverVersion Server version
	 * @param factory Reference to the component factory
	 * @param decisionMakerID Index of the decision maker
	 */
	public ChannelParameters(String teamname, byte teamID, int playerNumber,
			String host, int port)
	{
		this.teamname = teamname;
		this.teamID = teamID;
		this.playerNumber = playerNumber;
		this.host = host;
		this.port = port;
	}

	/**
	 * Retrieve the team name
	 * 
	 * @return Team name
	 */
	public String getTeamname()
	{
		return teamname;
	}

	/**
	 * Retrieve the player number
	 * 
	 * @return Player number
	 */
	public int getPlayerNumber()
	{
		return playerNumber;
	}

	/**
	 * Retrieve the server host
	 * 
	 * @return Server host string
	 */
	public String getHost()
	{
		return host;
	}

	/**
	 * Retrieve the server port
	 * 
	 * @return Server port
	 */
	public int getPort()
	{
		return port;
	}

	/**
	 * @return
	 */
	public byte getTeamID()
	{
		return teamID;
	}
}