/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 * 
 * This file is part of magmaOffenburg.
 * 
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg.  If not, see <http://www.gnu.org/licenses/>.
 ********************************************************************************/
package magma.agent.communication.base;

import magma.agent.communication.IChannelState;

/**
 * 
 * @author rschilli
 * 
 */
public class ChannelState implements IChannelState
{

	private ConnectionState connectionState;

	private DataState dataState;

	/** the last problem we had with this channel */
	private String lastErrorMessage;

	public ChannelState()
	{
		connectionState = ConnectionState.NOT_CONNECTED;
		dataState = DataState.CORRECT_DATA;
		lastErrorMessage = null;
	}

	@Override
	public ConnectionState getConnectionState()
	{
		return connectionState;
	}

	@Override
	public DataState getDataState()
	{
		return dataState;
	}

	public String getLastErrorMessage()
	{
		return lastErrorMessage;
	}

	@Override
	public void setLastErrorMessage(String lastErrorMessage)
	{
		this.lastErrorMessage = lastErrorMessage;
	}

	@Override
	public void setConnectionState(ConnectionState connectionState)
	{
		this.connectionState = connectionState;
	}

	@Override
	public void setDataState(DataState dataState)
	{
		this.dataState = dataState;
	}

	@Override
	public boolean isConnected()
	{
		if (connectionState == ConnectionState.CONNECTED) {
			return true;
		}
		if (connectionState == ConnectionState.TRYING_TO_CONNECT) {
			// it may happen that we receive the first message before the state of
			// the connection is set to connected
			return true;
		}
		return false;
	}

	@Override
	public String toString()
	{
		return "magma.util.connection.ConnectionException: Error when reading from socket, closing down...\n"
				+ "No longer connected thinks AgentRuntime: magma.agent.communication.base.ChannelState@18399f62 ";
	}
}
