/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 */

package magma.agent.communication.base;

import java.util.Arrays;
import java.util.Map;
import java.util.logging.Level;

import magma.agent.action.IEffector;
import magma.agent.action.IServerMessageEncoder;
import magma.agent.communication.IChannelManager;
import magma.agent.communication.IChannelState.DataState;
import magma.agent.communication.IOutputChannel;
import magma.agent.perception.IPerceptor;
import magma.agent.perception.IServerMessageParser;
import magma.agent.perception.PerceptorConversionException;
import magma.util.connection.ConnectionException;
import magma.util.connection.IServerConnection;

/**
 * 
 * @author kdorer
 */
public abstract class InputOutputChannel extends ConnectionChannel implements
		IOutputChannel
{
	/** message decoder */
	private final IServerMessageParser parser;

	/** message encoder */
	private final IServerMessageEncoder encoder;

	public InputOutputChannel(IChannelManager manager,
			IServerConnection connection, IServerMessageParser parser,
			IServerMessageEncoder encoder)
	{
		super(manager, connection);
		this.parser = parser;
		this.encoder = encoder;
	}

	@Override
	public void sendMessage(Map<String, IEffector> effectors)
	{
		byte[] message = encoder.encodeMessage(effectors);
		sendMessage(message);
	}

	/**
	 * Notification for each message was received on this channel
	 * @param message
	 */
	@Override
	protected void onEachMessage(byte[] message) throws ConnectionException
	{
		try {
			Map<String, IPerceptor> rawPerceptors = parser.parseMessage(message);
			publishPerceptors(rawPerceptors);

		} catch (PerceptorConversionException e) {
			// TODO: we should be able to recognize. At least we should explicitly
			// specify which exceptions we ignore on purpose
			logger.log(Level.INFO, "not able to Parse: {0}", e);
			System.out.println("Error parsing message: "
					+ Arrays.toString(message));
			state.setDataState(DataState.INVALID_DATA);

		} catch (RuntimeException e) {
			System.out.println("Error parsing message: "
					+ Arrays.toString(message));
			// System.out.println(new String(message));
			state.setDataState(DataState.INVALID_DATA);
		}
	}

	/**
	 * @param rawPerceptors
	 */
	protected void publishPerceptors(Map<String, IPerceptor> rawPerceptors)
	{
		getManager().addPerceptors(rawPerceptors);
	}

	/**
	 * Notification when the first message was received on this channel, before
	 * processing it
	 * @param message
	 */
	@Override
	protected void onFirstMessage(byte[] message) throws ConnectionException
	{
	}
}
