/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 */

package magma.agent.communication.base;

import magma.agent.communication.IChannelManager;
import magma.agent.communication.IChannelState.ConnectionState;
import magma.agent.meta.agent.IAgentMetaModel;
import magma.agent.perception.impl.CommandParser;
import magma.util.connection.ConnectionException;
import magma.util.connection.impl.ServerConnection;

/**
 * 
 * @author kdorer
 */
public class RemoteControllChannel extends InputOutputChannel
{
	public RemoteControllChannel(IChannelManager manager, String ip)
	{
		super(manager, new ServerConnection(ip, 5790), new CommandParser(), null);
	}

	@Override
	protected boolean startReceiveLoop()
	{
		Thread ourThread = new Thread(new Runnable() {
			@Override
			public void run()
			{
				try {
					System.out.println("starting remote connection");
					connection.startReceiveLoop();
					state.setConnectionState(ConnectionState.NOT_CONNECTED);
				} catch (ConnectionException e) {
					state.setConnectionState(ConnectionState.DISCONNECTED);
					System.out.println(e);
					// e.printStackTrace();
				} catch (RuntimeException e) {
					state.setConnectionState(ConnectionState.DISCONNECTED);
					e.printStackTrace();
				}
				getManager().lostConnection(RemoteControllChannel.this);
			}
		});
		ourThread.start();
		return true;
	}

	@Override
	public void init(IAgentMetaModel instance)
	{
	}
}
