/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.decision.simple;

import java.util.Map;

import magma.agent.IServerConfigFilesConstants;
import magma.agent.behavior.IBehavior;
import magma.agent.behavior.IBehaviorConstants;
import magma.agent.belief.IBelief;
import magma.agent.thoughtmodel.IThoughtModel;

/**
 * Basic decision making class used for testing mainly that just beams and then
 * stands still
 * 
 * @author Klaus Dorer
 */
public class DoNothingDecisionMaker extends SoccerDecisionMaker
{
	/**  */
	private static final long serialVersionUID = 1L;

	/**
	 * Constructor
	 * 
	 * @param believes List of believes
	 * @param behaviors List of applicable behaviors
	 */
	public DoNothingDecisionMaker(Map<String, IBelief> believes,
			Map<String, IBehavior> behaviors, IThoughtModel thoughtModel)
	{
		super(believes, behaviors, thoughtModel,
				IServerConfigFilesConstants.DEFAULT_SERVER_VERSION);
	}

	/**
	 * Called to decide if we should wait for game start or not. Default
	 * implementation waits.
	 * @return the behavior to execute, null if this part of decision does not
	 *         trigger a behavior currently
	 */
	@Override
	protected IBehavior waitForGameStart()
	{
		// this makes sure that after beaming we do nothing
		return behaviors.get(IBehaviorConstants.NONE);
	}

	@Override
	protected void performFocusBall()
	{
	}

	@Override
	protected void performSay()
	{
	}
}
