/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.decision.simple;

import java.util.Map;

import magma.agent.behavior.IBehavior;
import magma.agent.behavior.IBehaviorConstants;
import magma.agent.belief.IBelief;
import magma.agent.belief.IBeliefConstants;
import magma.agent.thoughtmodel.IThoughtModel;
import magma.robots.nao.behavior.complex.Walk;

/**
 * Simple decision maker for primitive field player
 * @author Klaus Dorer
 */
public class GoalieDecisionMaker extends SoccerDecisionMaker
{
	/**  */
	private static final long serialVersionUID = 1L;

	/**
	 * Constructor
	 * 
	 * @param believes List of believes
	 * @param behaviors List of applicable behaviors
	 * @param serverVersion Server version number
	 */
	public GoalieDecisionMaker(Map<String, IBelief> believes,
			Map<String, IBehavior> behaviors, IThoughtModel thoughtModel,
			int serverVersion)
	{
		super(believes, behaviors, thoughtModel, serverVersion);
	}

	/**
	 * @return
	 */
	@Override
	protected IBehavior ownKickOffActions()
	{
		return null;
	}

	/**
	 * Called to decide if we should kick the ball
	 * @return the behavior to execute, null if this part of decision does not
	 *         trigger a behavior currently
	 */
	@Override
	protected IBehavior doKickBehavior()
	{
		if (isBalliInCriticalArea()) {
			IBelief shouldDribble = believes
					.get(IBeliefConstants.SHOULD_WE_DRIBBLE);
			if (shouldDribble.getTruthValue() > 0.5) {
				Walk behavior = (Walk) behaviors.get(IBehaviorConstants.WALK);
				behavior.walk(100, 0, 0);
				return behavior;
			}
		}
		IBelief ballKickable = believes.get(IBeliefConstants.BALL_KICKABLE);
		if (ballKickable.getTruthValue() > 0.5) {
			IBelief goalDirection = believes
					.get(IBeliefConstants.GOALIE_SHOULD_KICK);

			if (goalDirection.getTruthValue() > 0.5) {
				return behaviors.get(IBehaviorConstants.SHOOT_STRAIGHT);
			}
		}
		return null;
	}

	/**
	 * @return Walk behavior if no team mate is closer to ball side step behavior
	 *         to ball
	 */
	@Override
	protected IBehavior movement()
	{
		boolean possibleGoal = believes
				.get(IBeliefConstants.BALL_ENDS_UP_IN_GOAL).getTruthValue() > 0.5;
		boolean ballKeepable = believes.get(IBeliefConstants.BALL_IS_KEEPABLE)
				.getTruthValue() > 0.5;

		// System.out.println("Possible Goal: " + possibleGoal +
		// " Ball keepable: "
		// + ballKeepable + " Critical Area: " + criticalArea);

		if (possibleGoal && ballKeepable) {
			currentBehavior.abort();
			return behaviors.get(IBehaviorConstants.KEEP);
		}

		if (!isBalliInCriticalArea()) {
			return criticalAreaBehavior();
		}

		return behaviors.get(IBehaviorConstants.GET_IN_SCORE_POSITION);
	}

	protected IBehavior criticalAreaBehavior()
	{
		return behaviors.get(IBehaviorConstants.GOALIE_POSITIONING);
	}

	protected boolean isBalliInCriticalArea()
	{
		boolean criticalArea = believes.get(
				IBeliefConstants.BALL_IN_CRITICAL_AREA).getTruthValue() > 0.5;
		return criticalArea;
	}
}
