/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.decision.simple;

import java.util.Map;

import magma.agent.behavior.IBehavior;
import magma.agent.behavior.IBehaviorConstants;
import magma.agent.belief.IBelief;
import magma.agent.belief.IBeliefConstants;
import magma.agent.thoughtmodel.IThoughtModel;

/**
 * Decision maker for penalty goalie
 * @author Klaus Dorer
 */
public class GoaliePenaltyDecisionMaker extends GoalieDecisionMaker
{
	/**  */
	private static final long serialVersionUID = 1L;

	/**
	 * Constructor
	 * 
	 * @param believes List of believes
	 * @param behaviors List of applicable behaviors
	 * @param serverVersion Server version number
	 */
	public GoaliePenaltyDecisionMaker(Map<String, IBelief> believes,
			Map<String, IBehavior> behaviors, IThoughtModel thoughtModel,
			int serverVersion)
	{
		super(believes, behaviors, thoughtModel, serverVersion);
	}

	@Override
	protected boolean isBalliInCriticalArea()
	{
		boolean criticalArea = believes
				.get(IBeliefConstants.BALL_IN_PENALTY_AREA).getTruthValue() > 0.5;
		return criticalArea;
	}

	@Override
	protected IBehavior criticalAreaBehavior()
	{
		// TODO: create memory for keeper to stay on one side of the goal
		// for some seconds, when the opponent wants to kick
		boolean willKick = believes.get(IBeliefConstants.OPPONENT_WILL_KICK)
				.getTruthValue() > 0.5;
		if (willKick) {
			return behaviors.get(IBehaviorConstants.GOALIE_POSITIONING);
		}
		return behaviors.get(IBehaviorConstants.GOALIE_POSITIONING);
	}
}
