/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.decision.simple;

import java.util.Map;

import magma.agent.behavior.IBeam;
import magma.agent.behavior.IBehavior;
import magma.agent.behavior.IBehaviorConstants;
import magma.agent.belief.IBelief;
import magma.agent.belief.IBeliefConstants;
import magma.agent.thoughtmodel.IThoughtModel;

/**
 * Simple decision maker for penalty
 * 
 * @author Klaus Dorer
 */
public class PenaltyDecisionMaker extends SoccerDecisionMaker
{
	/**  */
	private static final long serialVersionUID = 1L;

	/**
	 * Default constructor
	 * @param believes map of believes we can decide on
	 * @param behaviors map of behaviors we can decide for
	 * @param serverVersion the version of the soccer server used
	 */
	public PenaltyDecisionMaker(Map<String, IBelief> believes,
			Map<String, IBehavior> behaviors, IThoughtModel thoughtModel,
			int serverVersion)
	{
		super(believes, behaviors, thoughtModel, serverVersion);
	}

	/**
	 * Called to decide if we should kick the ball
	 * @return the behavior to execute, null if this part of decision does not
	 *         trigger a behavior currently
	 */
	@Override
	protected IBehavior doKickBehavior()
	{
		return null;
	}

	@Override
	protected IBehavior beamHome()
	{
		IBelief beamTime = believes.get(IBeliefConstants.BEAM_TIME);
		if (beamTime.getTruthValue() > 0.5) {

			IBeam iBehavior = (IBeam) behaviors
					.get(IBehaviorConstants.BEAM_TO_POSITION);

			iBehavior.setPos(-0.17f, 0.03f, 0f);
			return iBehavior;
		}
		return null;
	}

	@Override
	protected IBehavior movement()
	{
		return behaviors.get(IBehaviorConstants.ATTACK_PENALTY);
	}
}
