/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.decision.simple;

import java.util.Map;

import magma.agent.behavior.IBehavior;
import magma.agent.behavior.IBehaviorConstants;
import magma.agent.behavior.IWalk;
import magma.agent.belief.IBelief;
import magma.agent.thoughtmodel.IThoughtModel;

/**
 * Decision maker used to trigger training behaviors. Feel free to change it for
 * your own convenience.
 * 
 * @author Klaus Dorer
 */
public class RunChallengeDecisionMaker extends SoccerDecisionMaker
{
	/**  */
	private static final long serialVersionUID = 1L;

	/**
	 * Constructor
	 * 
	 * @param believes List of believes
	 * @param behaviors List of applicable behaviors
	 * @param serverVersion Server version number
	 */
	public RunChallengeDecisionMaker(Map<String, IBelief> believes,
			Map<String, IBehavior> behaviors, IThoughtModel thoughtModel,
			int serverVersion)
	{
		super(believes, behaviors, thoughtModel, serverVersion);
	}

	/**
	 * Called to decide if we should beam us to our home position
	 * @return the behavior to execute, null if this part of decision does not
	 *         trigger a behavior currently
	 */
	@Override
	protected IBehavior beamHome()
	{
		// run challenge does not beam
		return null;
	}

	/**
	 * Called to decide if we should wait for game start or not. Default
	 * implementation waits.
	 * @return the behavior to execute, null if this part of decision does not
	 *         trigger a behavior currently
	 */
	@Override
	protected IBehavior waitForGameStart()
	{
		return super.waitForGameStart();
		// return null;
	}

	/**
	 * Called to decide if we should kick the ball
	 * @return the behavior to execute, null if this part of decision does not
	 *         trigger a behavior currently
	 */
	@Override
	protected IBehavior doKickBehavior()
	{
		return null;
	}

	/**
	 * Called to decide if movement is necessary
	 * @return walk behavior if no team mate is closer to ball
	 */
	@Override
	protected IBehavior movement()
	{
		if (numberOfDecisions < 50) {
			// we have to wait the first 50 cycles
			return null;
		}

		IWalk behavior = (IWalk) behaviors.get(IBehaviorConstants.WALK);
		behavior.walk(100, 0, 0);
		return behavior;
	}
}
