/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.decision.simple;

import java.util.Map;

import magma.agent.behavior.IBeam;
import magma.agent.behavior.IBehavior;
import magma.agent.behavior.IBehaviorConstants;
import magma.agent.belief.IBelief;
import magma.agent.thoughtmodel.IThoughtModel;

/**
 * Decision maker used to trigger training behaviors. Feel free to change it for
 * your own convenience.
 * 
 * @author Klaus Dorer
 */
public class TrainingDecisionMaker extends SoccerDecisionMaker
{
	/**  */
	private static final long serialVersionUID = 1L;

	protected boolean haveBeamed;

	// private boolean moveZeroDone;
	//
	// private int doCount;
	//
	// private boolean doneGetReady;

	/**
	 * Constructor
	 * 
	 * @param believes List of believes
	 * @param behaviors List of applicable behaviors
	 * @param serverVersion Server version number
	 */
	public TrainingDecisionMaker(Map<String, IBelief> believes,
			Map<String, IBehavior> behaviors, IThoughtModel thoughtModel,
			int serverVersion)
	{
		super(believes, behaviors, thoughtModel, serverVersion);
		haveBeamed = false;
	}

	@Override
	protected void performFocusBall()
	{
		// super.performFocusBall();
	}

	@Override
	protected void performSay()
	{
		// super.performSay();
	}

	/**
	 * Called to decide if we should beam us to our home position
	 * @return the behavior to execute, null if this part of decision does not
	 *         trigger a behavior currently
	 */
	@Override
	protected IBehavior beamHome()
	{
		if (!haveBeamed) {
			haveBeamed = true;
			IBehavior result = behaviors.get(IBehaviorConstants.BEAM_TO_POSITION);
			// ((IBeam) result).setPos(-0.27f, 0.10f, 0.0f);
			((IBeam) result).setPos(-2f, 0.0f, 0.0f);
			// ((IBeam) result).setPos(-3.6f, 0.0f, 90.0f);
			return result;
		}
		return null;
	}

	@Override
	protected IBehavior gameEndedAction()
	{
		return null;
	}

	/**
	 * Called to decide if we should wait for game start or not. Default
	 * implementation waits.
	 * @return the behavior to execute, null if this part of decision does not
	 *         trigger a behavior currently
	 */
	@Override
	protected IBehavior waitForGameStart()
	{
		// return super.waitForGameStart();
		return null;
	}

	@Override
	protected IBehavior doSearchBall()
	{
		return null;
	}

	/**
	 * Called to decide if we should kick the ball
	 * @return the behavior to execute, null if this part of decision does not
	 *         trigger a behavior currently
	 */
	@Override
	protected IBehavior doKickBehavior()
	{
		// IBehavior behavior = behaviors
		// .get(IBehaviorConstants.DYNAMIC_STATIC_KICK_RIGHT);
		// return behavior;
		return null;
	}

	@Override
	protected IBehavior getReady()
	{
		// if (!moveZeroDone) {
		// moveZeroDone = true;
		// System.out.println("Move zero");
		// return behaviors.get(IBehaviorConstants.MOVE_ZERO);
		// }
		// return super.getReady();
		// IBelief soccerPosition =
		// believes.get(IBeliefConstants.SOCCER_POSITION);
		// if (soccerPosition.getTruthValue() < 0.5) {

		// if (currentBehavior.getName().equals("IKMovementBehavior")) {
		// doneGetReady = true;
		// }
		// if (!doneGetReady) {
		// System.out.println("getReady");
		// return behaviors.get("IKMovementBehavior");
		// }
		return null;

		// if (doCount > 60) {
		// return null;
		// }
		// doCount++;
		// return behaviors.get("GetOnOneLegSweaty");
	}

	@Override
	protected IBehavior ownKickOffActions()
	{
		return null;
	}

	/**
	 * Called to decide if movement is necessary
	 * @return walk behavior if no team mate is closer to ball
	 */
	@Override
	protected IBehavior movement()
	{
		// if (numberOfDecisions < 200) {
		// return null;
		// }
		// if (numberOfDecisions / 50 % 2 == 0) {
		// behavior.walk(0, 0, 0);
		// } else {
		// // behavior.walk(0, -50 + numberOfDecisions % 100, 50);
		// behavior.walk(0, 100, 10);
		// }

		// IBehavior behavior = behaviors.get("verbeugung");
		// IBehavior behavior = behaviors.get("winken");
		// IBehavior behavior = behaviors.get("kneebend");
		// IBehavior behavior = behaviors.get("advertise");
		// IBehavior behavior = behaviors.get(IBehaviorConstants.MOVE_ZERO);
		// IBehavior behavior = behaviors.get(IBehaviorConstants.POINT_TO_BALL);
		// IBehavior behavior = behaviors.get("ShakeHands");

		// IBehavior behavior = behaviors.get("ShakeHandsBack");
		// IBehavior behavior = behaviors.get("KickSweaty2");
		// IBehavior behavior = behaviors.get("A_SidestepRight_Rev2");
		// IBehavior behavior = behaviors.get(IBehaviorConstants.REMOTE_CONTROLL);

		// IWalk behavior = (IWalk) behaviors.get(IBehaviorConstants.WALK);
		// behavior.walk(0, 0, 0);
		// IBehavior behavior = behaviors.get("KickSweaty");
		// IBehavior behavior = null;
		// return behavior;
		return behaviors.get(IBehaviorConstants.NONE);

		// IKStepWalkBehavior behavior = (IKStepWalkBehavior) behaviors
		// .get(IBehaviorConstants.IK2013_STEP);
		//
		// behavior.setStepTarget(null, null);

		//
		// RunToPosition behavior = (RunToPosition) behaviors
		// .get(IBehaviorConstants.RUN_TO_POSITION);
		//
		// if (numberOfDecisions / 400 % 2 == 0) {
		// behavior.setPosition(new Vector3D(-2, 1, 0), 30, 0, 0, 100);
		// } else {
		// behavior.setPosition(new Vector3D(-2, -1, 0), -30, 0, 0, 100);
		// }
		//
		// DynamicWalk behavior = (DynamicWalk) behaviors
		// .get(IBehaviorConstants.DYNAMIC_WALK);
		// if (numberOfDecisions / 40 % 3 == 0) {
		// behavior.setMovement(100, 0, 0, 100);
		// } else if (numberOfDecisions / 40 % 3 == 1) {
		// behavior.setMovement(100, -40, -40, 100);
		// } else if (numberOfDecisions / 40 % 3 == 2) {
		// behavior.setMovement(100, 40, 40, 100);
		// }

		// // } else if (numberOfDecisions / 150 % 5 == 2) {
		// // behavior.walk(100, 0, 0);
		// // } else if (numberOfDecisions / 150 % 5 == 3) {
		// // behavior.walk(0, 0, -100);
		// // } else if (numberOfDecisions / 150 % 5 == 4) {
		// // behavior.walk(100, 0, 0);
		// // }
		//
		// // behavior.setIntensity(1.0f);
		// IBehavior behavior = behaviors.get(IBehaviorConstants.FALL_BACKWARD);
		// // IBehavior behavior =
		// behaviors.get(IBehaviorConstants.SHOOT_SIDE_LEFT);
		// // IBehavior behavior = behaviors.get("MotionConverterBehavior");
		// // RunToPosition behavior = (RunToPosition) behaviors
		// // .get(IBehaviorConstants.RUN_TO_POSITION);
		// // behavior.setPosition(new Vector3D(0, 0, 0), 0, 100, 50, 100);

		// StabilizeOnLeg stabilizeOnLeftLeg = (StabilizeOnLeg) behaviors
		// .get(IBehaviorConstants.STABILIZE_ON_LEFT_LEG);
		// StabilizeOnLeg stabilizeOnRightLeg = (StabilizeOnLeg) behaviors
		// .get(IBehaviorConstants.STABILIZE_ON_RIGHT_LEG);
		//
		// DynamicWalk dynamicWalk = (DynamicWalk) behaviors
		// .get(IBehaviorConstants.DYNAMIC_WALK);
		// IBehavior behavior = dynamicWalk;
		// dynamicWalk.setMovement(100, 0, -5, 0);

		// IBehavior behavior = behaviors.get(IBehaviorConstants.SHOOT_STRAIGHT);
	}

	@Override
	protected IBehavior getPausedBehavior()
	{
		// doneGetReady = false;
		return behaviors.get(IBehaviorConstants.MOVE_ZERO);
	}
}
