/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.meta.agent;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

public interface IHingeJointConfiguration extends ISensorConfiguration
{
	/**
	 * Returns a vector, which defines the rotation axis of the joint.
	 * 
	 * @return the rotation axis
	 */
	public Vector3D getJointAxis();

	/**
	 * Returns the minimum possible position-angle of the joint.
	 * 
	 * @return the minimum position angle (deg)
	 */
	public int getMinAngle();

	/**
	 * Returns the maximum possible position-angle of the joint.
	 * 
	 * @return the maximum position angle (deg)
	 */
	public int getMaxAngle();

	/**
	 * Returns the maximum possible speed to the joint.
	 * 
	 * @return the maximum possible speed (deg/cycle)
	 */
	public float getMaxSpeed();

	/**
	 * Returns the maximum possible acceleration.
	 * 
	 * @return the maximum possible speed (deg/cycle//cycle)
	 */
	public float getMaxAcceleration();

	/**
	 * @return the name of this effector
	 */
	public String getEffectorName();

	/**
	 * @return the stiffness or gain of the joint motor
	 */
	public float getGain();

}
