/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 */

package magma.agent.meta.agent;

/**
 * Maps joint angles to motor angles and vice versa. Implementations will be
 * specific for a certain joint.
 * 
 * @author kdorer
 */
public interface IJointToMotorMapper
{
	/**
	 * Maps joint to motor angles. The length and order of the parameter and
	 * result array depends on the specific joint that is mapped.
	 * 
	 * @param jointAngles the joint angles in degrees.
	 * @return the corresponding motor angles in degrees.
	 */
	double[] jointToMotorAngle(double[] jointAngles);

	/**
	 * Maps motor to joint angles. The length and order of the parameter and
	 * result array depends on the specific joint that is mapped.
	 * 
	 * @param motorAngles the motor angles in degrees.
	 * @return the corresponding joint angles in degrees.
	 */
	double[] motorToJointAngle(double[] motorAngles);
}