/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.meta.agent.impl;

import magma.agent.meta.agent.IBodyPartConfiguration;
import magma.agent.meta.agent.ISensorConfiguration;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

public class BodyPartConfiguration implements IBodyPartConfiguration
{
	private static final long serialVersionUID = 7275148422500704940L;

	private final String name;

	private final String parent;

	private final Vector3D translation;

	private final float mass;

	private final Vector3D geometry;

	private final ISensorConfiguration jointConfig;

	private final Vector3D jointAnchor;

	private final ISensorConfiguration gyroRateConfig;

	private final ISensorConfiguration accelerometerConfig;

	private final ISensorConfiguration forceResistanceConfig;

	private final ISensorConfiguration compassConfig;

	public BodyPartConfiguration(String name, String parent,
			Vector3D translation, float mass, Vector3D geometry,
			ISensorConfiguration jointConfig, Vector3D jointAnchor,
			ISensorConfiguration gyroRateConfig,
			ISensorConfiguration accelerometerConfig,
			ISensorConfiguration forceResistanceConfig,
			ISensorConfiguration compassConfig)
	{
		this.name = name;
		this.parent = parent;
		this.translation = translation;
		this.mass = mass;
		this.geometry = geometry;
		this.jointConfig = jointConfig;
		this.jointAnchor = jointAnchor;
		this.gyroRateConfig = gyroRateConfig;
		this.accelerometerConfig = accelerometerConfig;
		this.forceResistanceConfig = forceResistanceConfig;
		this.compassConfig = compassConfig;
	}

	@Override
	public String getName()
	{
		return name;
	}

	@Override
	public String getParent()
	{
		return parent;
	}

	@Override
	public Vector3D getTranslation()
	{
		return translation;
	}

	@Override
	public float getMass()
	{
		return mass;
	}

	@Override
	public Vector3D getGeometry()
	{
		return geometry;
	}

	@Override
	public ISensorConfiguration getJointConfiguration()
	{
		return jointConfig;
	}

	@Override
	public Vector3D getJointAnchor()
	{
		return jointAnchor;
	}

	@Override
	public ISensorConfiguration getGyroRateConfiguration()
	{
		return gyroRateConfig;
	}

	@Override
	public ISensorConfiguration getAccelerometerConfiguration()
	{
		return accelerometerConfig;
	}

	@Override
	public ISensorConfiguration getForceResistanceConfiguration()
	{
		return forceResistanceConfig;
	}

	@Override
	public ISensorConfiguration getCompassConfig()
	{
		return compassConfig;
	}
}
