/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.meta.agent.impl;

import magma.agent.meta.agent.ICompositeJointConfiguration;
import magma.agent.meta.agent.IHingeJointConfiguration;
import magma.agent.meta.agent.IJointToMotorMapper;

/**
 * Composite of hinge joints configuration
 * 
 * @author Stefan Glaser
 */
public class CompositeJointConfiguration implements
		ICompositeJointConfiguration
{
	private static final long serialVersionUID = 5755957235741394236L;

	private final String name;

	private final IHingeJointConfiguration[] hjConfigurations;

	private final transient IJointToMotorMapper mapper;

	/**
	 * 
	 * @param name the name of the universal joint
	 * @param mapper joint to motor mapper, null if not needed
	 * @param hjConfs the joint configurations
	 */
	public CompositeJointConfiguration(String name, IJointToMotorMapper mapper,
			IHingeJointConfiguration[] hjConfs)
	{
		this.name = name;
		this.mapper = mapper;
		this.hjConfigurations = hjConfs;
	}

	@Override
	public String getName()
	{
		return name;
	}

	/**
	 * @return the hjConfigurations
	 */
	@Override
	public IHingeJointConfiguration[] getHjConfigurations()
	{
		return hjConfigurations;
	}

	@Override
	public String getPerceptorName()
	{
		return name;
	}

	@Override
	public IJointToMotorMapper getJointToMotorMapper()
	{
		return mapper;
	}
}
