/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.meta.agent.impl;

import magma.agent.meta.agent.IHingeJointConfiguration;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

public class HingeJointConfiguration implements IHingeJointConfiguration
{
	private static final long serialVersionUID = 6982676651332387297L;

	private final String name;

	private final String perceptorName;

	private final String effectorName;

	private final Vector3D jointAxis;

	private final int minAngle;

	private final int maxAngle;

	private final float maxSpeed;

	private float maxAcceleration;

	private float gain;

	public HingeJointConfiguration(String name, String perceptorName,
			String effectorName, Vector3D jointAxis, int jointMinAngle,
			int jointMaxAngle, float jointMaxSpeed, float maxAcceleration,
			float gain)
	{
		this.name = name;
		this.perceptorName = perceptorName;
		this.effectorName = effectorName;
		this.jointAxis = jointAxis;
		this.minAngle = jointMinAngle;
		this.maxAngle = jointMaxAngle;
		this.maxSpeed = jointMaxSpeed;
		this.maxAcceleration = maxAcceleration;
		this.gain = gain;
	}

	public HingeJointConfiguration(String name, String perceptorName,
			String effectorName, Vector3D jointAxis, int jointMinAngle,
			int jointMaxAngle, float jointMaxSpeed)
	{
		this(name, perceptorName, effectorName, jointAxis, jointMinAngle,
				jointMaxAngle, jointMaxSpeed, Float.MAX_VALUE, 0);
	}

	@Override
	public String getName()
	{
		return name;
	}

	@Override
	public String getPerceptorName()
	{
		return perceptorName;
	}

	@Override
	public String getEffectorName()
	{
		return effectorName;
	}

	@Override
	public Vector3D getJointAxis()
	{
		return jointAxis;
	}

	@Override
	public int getMinAngle()
	{
		return minAngle;
	}

	@Override
	public int getMaxAngle()
	{
		return maxAngle;
	}

	@Override
	public float getMaxSpeed()
	{
		return maxSpeed;
	}

	@Override
	public float getMaxAcceleration()
	{
		return maxAcceleration;
	}

	@Override
	public float getGain()
	{
		return gain;
	}
}
