/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 */

package magma.agent.meta.agent.impl;

import magma.agent.meta.agent.IJointToMotorMapper;

/**
 * 
 * @author kdorer
 */
public class OffsetJointMapper implements IJointToMotorMapper
{
	private double offset;

	private double scaling;

	/**
	 * @param offset
	 * @param scaling
	 */
	public OffsetJointMapper(double offset)
	{
		this(offset, 1);
	}

	/**
	 * @param offset
	 * @param scaling
	 */
	public OffsetJointMapper(double offset, double scaling)
	{
		this.offset = offset;
		this.scaling = scaling;
	}

	@Override
	public double[] jointToMotorAngle(double[] jointAngles)
	{
		double[] result = new double[jointAngles.length];
		for (int i = 0; i < jointAngles.length; i++) {
			result[i] = jointAngles[i] * scaling + offset;
		}
		// System.out.println("joint angle: " + jointAngles[0] + " maps to: "
		// + result[0]);
		return result;
	}

	@Override
	public double[] motorToJointAngle(double[] motorAngles)
	{
		double[] result = new double[motorAngles.length];
		for (int i = 0; i < motorAngles.length; i++) {
			result[i] = (motorAngles[i] - offset) / scaling;
		}
		return result;
	}
}
