/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.meta.agent.impl;

import magma.agent.meta.agent.IJointToMotorMapper;
import magma.agent.meta.agent.IUniversalJointConfiguration;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * Universal joint configuration
 * 
 * @author Stefan Glaser
 */
public class UniversalJointConfiguration implements
		IUniversalJointConfiguration
{
	private static final long serialVersionUID = 5755957235741394236L;

	private final String name;

	private final HingeJointConfiguration hj1Configuration;

	private final HingeJointConfiguration hj2Configuration;

	private IJointToMotorMapper mapper;

	/**
	 * 
	 * @param name the name of the universal joint
	 * @param mapper joint to motor mapper, null if not needed
	 * @param perceptorName
	 * @param effectorName1
	 * @param effectorName2
	 * @param joint1Axis
	 * @param joint2Axis
	 * @param joint1MinAngle
	 * @param joint2MinAngle
	 * @param joint1MaxAngle
	 * @param joint2MaxAngle
	 * @param joint1MaxSpeed
	 * @param joint2MaxSpeed
	 */
	public UniversalJointConfiguration(String name, IJointToMotorMapper mapper,
			String perceptorName, String effectorName1, String effectorName2,
			Vector3D joint1Axis, Vector3D joint2Axis, int joint1MinAngle,
			int joint2MinAngle, int joint1MaxAngle, int joint2MaxAngle,
			float joint1MaxSpeed, float joint2MaxSpeed)
	{
		this.name = name;
		this.mapper = mapper;
		this.hj1Configuration = new HingeJointConfiguration(name, perceptorName,
				effectorName1, joint1Axis, joint1MinAngle, joint1MaxAngle,
				joint1MaxSpeed);
		this.hj2Configuration = new HingeJointConfiguration(name, perceptorName,
				effectorName2, joint2Axis, joint2MinAngle, joint2MaxAngle,
				joint2MaxSpeed);
	}

	@Override
	public String getName()
	{
		return name;
	}

	/**
	 * @return the hj1Configuration
	 */
	public HingeJointConfiguration getHj1Configuration()
	{
		return hj1Configuration;
	}

	/**
	 * @return the hj2Configuration
	 */
	public HingeJointConfiguration getHj2Configuration()
	{
		return hj2Configuration;
	}

	@Override
	public String getPerceptorName()
	{
		return name;
	}

	@Override
	public IJointToMotorMapper getJointToMotorMapper()
	{
		return mapper;
	}
}
