/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.meta.server.impl;

import java.util.Map;

import magma.agent.meta.server.IRCServerMetaModel;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

public class RCServerMetaModel implements IRCServerMetaModel
{
	private static final long serialVersionUID = 8671232816325383091L;

	protected final int version;

	protected final float ballSize;

	protected final float ballDecay;

	protected final float[] fieldDimensions;

	protected final float[] goalDimensions;

	protected final float[] goalAreaDimensions;

	protected final float[] penaltyAreaDimensions;

	protected final float middleCircleRadii;

	protected final Map<String, Vector3D> landmarks;

	protected final Map<String, Vector3D[]> fieldLines;

	public RCServerMetaModel(int version, float ballSize, float ballDecay,
			float[] fieldDimensions, float[] goalDimensions,
			float[] goalAreaDimensions, float[] penaltyAreaDimensions,
			float middleCircleRadii, Map<String, Vector3D> landmarks,
			Map<String, Vector3D[]> fieldLines)
	{
		this.version = version;
		this.ballSize = ballSize;
		this.ballDecay = ballDecay;
		this.fieldDimensions = fieldDimensions;
		this.goalDimensions = goalDimensions;
		this.goalAreaDimensions = goalAreaDimensions;
		this.penaltyAreaDimensions = penaltyAreaDimensions;
		this.middleCircleRadii = middleCircleRadii;
		this.landmarks = landmarks;
		this.fieldLines = fieldLines;
	}

	@Override
	public int getVersion()
	{
		return version;
	}

	@Override
	public float getBallSize()
	{
		return ballSize;
	}

	@Override
	public float getBallDecay()
	{
		return ballDecay;
	}

	@Override
	public float[] getFieldDimensions()
	{
		return fieldDimensions;
	}

	@Override
	public float[] getGoalDimensions()
	{
		return goalDimensions;
	}

	@Override
	public float[] getGoalAreaDimensions()
	{
		return goalAreaDimensions;
	}

	@Override
	public float[] getPenaltyAreaDimensions()
	{
		return penaltyAreaDimensions;
	}

	@Override
	public float getMiddleCircleRadii()
	{
		return middleCircleRadii;
	}

	@Override
	public Map<String, Vector3D> getLandmarks()
	{
		return landmarks;
	}

	@Override
	public Map<String, Vector3D[]> getFieldLines()
	{
		return fieldLines;
	}
}
