/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.meta.server.impl;

import java.util.HashMap;
import java.util.Map;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

public class RCServerMetaModelV63 extends RCServerMetaModel
{
	private static final long serialVersionUID = -8845806388469893295L;

	private static final float BALL_SIZE = 0.042f;

	private static final float BALL_DECAY = 0.94f;

	private static final float FIELD_HALF_LENGTH = 9.0f;

	private static final float FIELD_HALF_WIDTH = 6.0f;

	private static final float GOAL_HALF_WIDTH = 1.05f;

	private static final float GOAL_HEIGHT = 0.8f;

	private static final float GOAL_DEPTH = 0.8f;

	private static final float PENALTY_HALF_LENGTH = 1.95f;

	private static final float PENALTY_WIDTH = 1.8f;

	private static final float MIDDLE_CIRCLE_RADIUS = 1.8f;

	/** Make sure to keep this and LANDMARK_POSITIONS in same order */
	private static final String[] LANDMARK_NAMES = { "G1L", "G2L", "G1R", "G2R",
			"F1L", "F2L", "F1R", "F2R" };

	/**
	 * The positions of the visible landmarks in order of LANDMARK_NAMES as used
	 * in version 0.6.3 of the server
	 */
	private static final float[][] LANDMARK_POSITIONS = {
			{ -FIELD_HALF_LENGTH, GOAL_HALF_WIDTH, GOAL_HEIGHT },
			{ -FIELD_HALF_LENGTH, -GOAL_HALF_WIDTH, GOAL_HEIGHT }, // left goal
			// posts
			{ FIELD_HALF_LENGTH, GOAL_HALF_WIDTH, GOAL_HEIGHT },
			{ FIELD_HALF_LENGTH, -GOAL_HALF_WIDTH, GOAL_HEIGHT }, // right goal
			// posts
			{ -FIELD_HALF_LENGTH, FIELD_HALF_WIDTH, 0.0f },
			{ -FIELD_HALF_LENGTH, -FIELD_HALF_WIDTH, 0.0f },
			{ FIELD_HALF_LENGTH, FIELD_HALF_WIDTH, 0.0f },
			{ FIELD_HALF_LENGTH, -FIELD_HALF_WIDTH, 0.0f } };

	public static final RCServerMetaModelV63 INSTANCE = new RCServerMetaModelV63();

	private RCServerMetaModelV63()
	{
		super(63, BALL_SIZE, BALL_DECAY, new float[] { FIELD_HALF_LENGTH * 2,
				FIELD_HALF_WIDTH * 2 }, new float[] { GOAL_HALF_WIDTH * 2,
				GOAL_HEIGHT }, new float[] { GOAL_HALF_WIDTH * 2, GOAL_DEPTH },
				new float[] { PENALTY_HALF_LENGTH * 2, PENALTY_WIDTH },
				MIDDLE_CIRCLE_RADIUS, createLandmarkMap(), null);
	}

	private static Map<String, Vector3D> createLandmarkMap()
	{
		Map<String, Vector3D> landmarks = new HashMap<String, Vector3D>();

		for (int i = 0; i < LANDMARK_NAMES.length; i++) {
			landmarks.put(LANDMARK_NAMES[i], new Vector3D(
					LANDMARK_POSITIONS[i][0], LANDMARK_POSITIONS[i][1],
					LANDMARK_POSITIONS[i][2]));
		}

		return landmarks;
	}
}
