/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.perception.impl;

import magma.agent.perception.IAccelerometerPerceptor;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * Acceleration perceptor
 * 
 * @author Simon Raffeiner
 */
public class AccelerometerPerceptor extends Perceptor implements
		IAccelerometerPerceptor
{
	private Vector3D vector;

	/**
	 * Default constructor, initializes the accelerometer to (0, 0, 0)
	 * 
	 * @param name Perceptor name
	 */
	public AccelerometerPerceptor(String name)
	{
		this(name, 0.0f, 0.0f, 0.0f);
	}

	/**
	 * Assignment constructor
	 * 
	 * @param name Perceptor name
	 * @param accelX X rotation
	 * @param accelY Y rotation
	 * @param accelZ Z rotation
	 */
	public AccelerometerPerceptor(String name, float accelX, float accelY,
			float accelZ)
	{
		super(name);
		this.vector = new Vector3D(accelX, accelY, accelZ);
	}

	@Override
	public Vector3D getAcceleration()
	{
		return vector;
	}
}
