/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.perception.impl;

import magma.agent.perception.IHingeJointPerceptor;

/**
 * Hinge Joint Perceptor
 * 
 * @author Simon Raffeiner
 */
public class HingeJointPerceptor extends Perceptor implements
		IHingeJointPerceptor
{
	private float axis;

	private float speed;

	private float load;

	private float voltage;

	private float temperature;

	private float calculatedTemperature;

	private float calculatedTemperatureCoil;

	private byte error;

	/**
	 * Default constructor, initializes the axis to (0.0)
	 * 
	 * @param name Perceptor name
	 */
	public HingeJointPerceptor(String name)
	{
		this(name, 0.0f);
	}

	/**
	 * Assignment constructor
	 * 
	 * @param name Perceptor name
	 * @param axis Axis value
	 */
	public HingeJointPerceptor(String name, float axis)
	{
		this(name, axis, 0, 0, 0, 0, 0, 0, (byte) 0);
	}

	/**
	 * @param name the name of this joint
	 * @param axis the angle of this joint (in degrees)
	 * @param speed the speed of this joint (in ???)
	 * @param load the torque???
	 * @param voltage the current voltage (in V???)
	 * @param temperature temperature (in degrees)
	 * @param calculatedTemperature ??? (in degrees)
	 * @param calculatedTemperatureCoil ??? (in degrees)
	 */
	public HingeJointPerceptor(String name, float axis, float speed, float load,
			float voltage, float temperature, float calculatedTemperature,
			float calculatedTemperatureCoil, byte error)
	{
		super(name);
		this.axis = axis;
		this.speed = speed;
		this.load = load;
		this.voltage = voltage;
		this.temperature = temperature;
		this.calculatedTemperature = calculatedTemperature;
		this.calculatedTemperatureCoil = calculatedTemperatureCoil;
		this.error = error;
	}

	@Override
	public float getAxis()
	{
		return this.axis;
	}

	public void setAxis(float axis)
	{
		this.axis = axis;
	}

	/**
	 * @return the speed
	 */
	public float getSpeed()
	{
		return speed;
	}

	/**
	 * @return the load
	 */
	public float getLoad()
	{
		return load;
	}

	/**
	 * @return the voltage
	 */
	public float getVoltage()
	{
		return voltage;
	}

	/**
	 * @return the temperature
	 */
	public float getTemperature()
	{
		return temperature;
	}

	/**
	 * @return the calculatedTemperature
	 */
	public float getCalculatedTemperature()
	{
		return calculatedTemperature;
	}

	public void setCalculatedTemperature(float value)
	{
		calculatedTemperature = value;
	}

	/**
	 * @return the calculatedTemperatureCoil
	 */
	public float getCalculatedTemperatureCoil()
	{
		return calculatedTemperatureCoil;
	}

	public void setCalculatedTemperatureCoil(float value)
	{
		calculatedTemperatureCoil = value;
	}

	public byte getError()
	{
		return error;
	}
}
