/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.perception.impl;

import magma.agent.perception.IHingeJointPerceptor;
import magma.agent.perception.IUniversalJointPerceptor;

/**
 * Universal Joint perceptor
 * 
 * @author Simon Raffeiner
 */
public class UniversalJointPerceptor extends Perceptor implements
		IUniversalJointPerceptor
{
	private IHingeJointPerceptor joint1;

	private IHingeJointPerceptor joint2;

	/**
	 * Default constructor, initalizes the axes to (0.0, 0.0)
	 * 
	 * @param name Perceptor name
	 */
	public UniversalJointPerceptor(String name)
	{
		this(name, 0.0f, 0.0f);
	}

	/**
	 * @param joint1
	 * @param joint2
	 */
	public UniversalJointPerceptor(String name, float axis1, float axis2)
	{
		super(name);
		joint1 = new HingeJointPerceptor(name, axis1);
		joint2 = new HingeJointPerceptor(name, axis2);
	}

	@Override
	public IHingeJointPerceptor getJoint1()
	{
		return joint1;
	}

	@Override
	public IHingeJointPerceptor getJoint2()
	{
		return joint2;
	}
}
