/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.perception.impl;

import magma.agent.perception.IVisibleObjectPerceptor;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * Visible Object
 * 
 * @author Simon Raffeiner
 * 
 */
public class VisibleObjectPerceptor extends Perceptor implements
		IVisibleObjectPerceptor
{
	/** Object position in camera coordinate system */
	private Vector3D position;

	/** true if this perceptor has depth information in the position */
	private boolean hasDepth;

	/** how confident we are in the perception [0..1] */
	private double confidence;

	/**
	 * Assignment constructor
	 * @param name Object name
	 * @param position Object Position
	 */
	public VisibleObjectPerceptor(String name, Vector3D position,
			boolean hasDepth, double confidence)
	{
		super(name);
		this.position = position;
		this.hasDepth = hasDepth;
	}

	@Override
	public Vector3D getPosition()
	{
		return position;
	}

	@Override
	public void setPosition(Vector3D position)
	{
		this.position = position;
	}

	@Override
	public double getDistance()
	{
		return position.getNorm();
	}

	@Override
	public double getHorizontalAngle()
	{
		return position.getAlpha();
	}

	@Override
	public double getHorizontalAngleDeg()
	{
		return Math.toDegrees(position.getAlpha());
	}

	@Override
	public double getLatitudeAngle()
	{
		return position.getDelta();
	}

	@Override
	public double getLatitudeAngleDeg()
	{
		return Math.toDegrees(position.getDelta());
	}

	@Override
	public boolean hasDepth()
	{
		return hasDepth;
	}

	/**
	 * @return the confidence
	 */
	public double getConfidence()
	{
		return confidence;
	}
}
