/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 * 
 * This file is part of magmaOffenburg.
 * 
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg.  If not, see <http://www.gnu.org/licenses/>.
 ********************************************************************************/
package magma.agent.thoughtmodel.strategy.impl;

import magma.agent.meta.server.impl.RelativeHomePosition;
import magma.agent.thoughtmodel.strategy.IRole;
import magma.agent.thoughtmodel.strategy.impl.roles.DummyRole;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * Definition of the home positions our roles on the field. Each of our agents
 * plays a specific role in our Team (called TeamRole). Besides the goalkeeper
 * there are three different defender, two midfielder, one supporting defensive
 * ballguard, three ballguards and one wingman.
 * 
 * Here are all roles defined we could use with their relative position and
 * offset.
 * 
 * @author Stephan Kammerer
 */
public interface IRoleConstants
{
	RelativeHomePosition GOAL_KEEPER = new RelativeHomePosition(new float[] {
			-1.0f, 0 }, new Vector3D(0.5, 0, 0));

	// Defensive roles
	RelativeHomePosition LEFT_DEFENDER = new RelativeHomePosition(new float[] {
			-0.66f, 0.25f }, Vector3D.ZERO);

	RelativeHomePosition LEFT_INNER_DEFENDER = new RelativeHomePosition(
			new float[] { -0.66f, 0.13f }, Vector3D.ZERO);

	RelativeHomePosition CENTER_DEFENDER = new RelativeHomePosition(new float[] {
			-0.62f, 0 }, Vector3D.ZERO);

	RelativeHomePosition RIGHT_DEFENDER = new RelativeHomePosition(new float[] {
			-0.66f, -0.25f }, Vector3D.ZERO);

	RelativeHomePosition RIGHT_INNER_DEFENDER = new RelativeHomePosition(
			new float[] { -0.66f, -0.13f }, Vector3D.ZERO);

	// Def1-strategy: relative home position of the three defenders
	RelativeHomePosition DEF1_LEFT_DEFENDER = new RelativeHomePosition(
			new float[] { -0.7f, 0.1f }, Vector3D.ZERO);

	RelativeHomePosition DEF1_RIGHT_DEFENDER = new RelativeHomePosition(
			new float[] { -0.7f, -0.1f }, Vector3D.ZERO);

	RelativeHomePosition DEF1_CENTER_DEFENDER = new RelativeHomePosition(
			new float[] { -0.65f, 0 }, Vector3D.ZERO);

	// Def1-strategy: relative home position of the left spawning ball guards
	RelativeHomePosition DEF1_SPAWNING_LEFT_BALLGUARD = new RelativeHomePosition(
			new float[] { -0.15f, 0.20f }, Vector3D.ZERO);

	// Def2-strategy.... kommt noch
	RelativeHomePosition LEFT_MIDFIELDER = new RelativeHomePosition(new float[] {
			-0.38f, 0.29f }, Vector3D.ZERO);

	RelativeHomePosition CENTER_SUPPORTGUARD = new RelativeHomePosition(
			new float[] { -0.28f, 0 }, Vector3D.ZERO);

	RelativeHomePosition RIGHT_MIDFIELDER = new RelativeHomePosition(
			new float[] { -0.38f, -0.29f }, Vector3D.ZERO);

	RelativeHomePosition CENTER_BALLGUARD = new RelativeHomePosition(
			new float[] { 0, 0 }, new Vector3D(-0.17, -0.03, 0));

	RelativeHomePosition WING_COMMANDER = new RelativeHomePosition(new float[] {
			0, 0 }, new Vector3D(-0.17, 1.2, 0));

	RelativeHomePosition LEFT_BALLGUARD = new RelativeHomePosition(new float[] {
			-0.15f, 0.20f }, Vector3D.ZERO);

	RelativeHomePosition LEFT_SUPPORTGUARD = new RelativeHomePosition(
			new float[] { -0.15f, 0.20f }, Vector3D.ZERO);

	RelativeHomePosition RIGHT_BALLGUARD = new RelativeHomePosition(new float[] {
			-0.15f, -0.20f }, Vector3D.ZERO);

	RelativeHomePosition RIGHT_SUPPORTGUARD = new RelativeHomePosition(
			new float[] { -0.15f, -0.20f }, Vector3D.ZERO);

	RelativeHomePosition BALL_ACCEPTOR = new RelativeHomePosition(new float[] {
			-0.45f, 0 }, Vector3D.ZERO);

	RelativeHomePosition BALL_DEMANDER = new RelativeHomePosition(new float[] {
			0, 0 }, new Vector3D(-0.17, 1.2, 0));

	IRole DUMMY_ROLE = new DummyRole();
}
