/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 * 
 * This file is part of magmaOffenburg.
 * 
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg.  If not, see <http://www.gnu.org/licenses/>.
 ********************************************************************************/
package magma.agent.thoughtmodel.strategy.impl.roles;

import magma.agent.meta.server.impl.RelativeHomePosition;
import magma.agent.worldmodel.GameState;
import magma.agent.worldmodel.IGlobalMap;
import magma.util.ValueUtil;
import magma.util.geometry.Angle;
import magma.util.geometry.Pose2D;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * @author Stephan Kammerer and Luisa Andre
 */
public class BallAcceptor extends Role
{
	public BallAcceptor(String name, IGlobalMap worldModel,
			RelativeHomePosition relativeHomePosition, float priority)
	{
		super(name, relativeHomePosition, priority, //
				(-worldModel.fieldHalfLength() + 1.8) / 2, // minX
				worldModel.fieldHalfLength() - 4); // maxX
	}

	@Override
	protected Pose2D determinePosition(IGlobalMap worldModel)
	{
		Vector3D ballPos = worldModel.getBall().getPosition();
		Vector3D ourPos = worldModel.getThisPlayer().getPosition();

		// Stay xm in front of the ball
		double ballX = ballPos.getX();
		double ballY = ballPos.getY();
		double targetX = ballX + 4.5;
		targetX = keepXLimits(targetX);

		double targetY = ballPos.getY();
		double yLimit = 6;

		// EXPERIMENT: move to the outer side where we will kick (from
		// KickDirectionProfiler)
		if (ballX < 4) {
			// we are in deep defense
			double newX = ballX + Math.min(Math.abs(ballY), 4);
			if (newX > targetX) {
				newX = targetX;
			}
			double newY = worldModel.fieldHalfWith() - 2;
			yLimit = 10;
			if (ballY < -0.2) {
				// kick towards the right side
				targetX = newX;
				targetY = -newY;
			} else if (ballY > 0.2) {
				// kick towards the right side
				targetX = newX;
				targetY = newY;
			}
		}

		// Don't be in our way if we want to shoot
		if (targetY < ourPos.getY()) {
			targetY += 1.3;
		} else {
			targetY -= 1.3;
		}

		// Indicates how far our agent moves in y-direction
		targetY = ValueUtil.limitAbs(targetY, yLimit);
		Vector3D target = new Vector3D(targetX, targetY, 0);

		if (worldModel.getGameState() == GameState.OPPONENT_GOAL_KICK) {
			// we should wait for the ball at the corner
			final float cornerX = worldModel.fieldHalfLength() - 4f;
			final float cornerY = 4;
			target = new Vector3D(cornerX, -cornerY, 0);
		}

		return new Pose2D(target, Angle.ZERO);
	}
}
