/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 * 
 * This file is part of magmaOffenburg.
 * 
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg.  If not, see <http://www.gnu.org/licenses/>.
 ********************************************************************************/
package magma.agent.thoughtmodel.strategy.impl.roles;

import magma.agent.meta.server.impl.RelativeHomePosition;
import magma.agent.worldmodel.GameState;
import magma.agent.worldmodel.IGlobalMap;
import magma.util.ValueUtil;
import magma.util.geometry.Angle;
import magma.util.geometry.Pose2D;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * The BallDemander is like the wing commander but he is not as offensive as the
 * Wing to be able to catch the ball.
 * 
 * @author Stephan Kammerer
 */
public class BallDemander extends Role
{
	public BallDemander(String name, IGlobalMap worldModel,
			RelativeHomePosition relativeHomePosition, float priority)
	{
		super(name, relativeHomePosition, priority, //
				-1.5, // minX
				worldModel.fieldHalfLength() - 2.5); // maxX
	}

	@Override
	protected Pose2D determinePosition(IGlobalMap worldModel)
	{
		Vector3D ballPos = worldModel.getBall().getPosition();

		double targetX = ballPos.getX() + 5.0;
		targetX = keepXLimits(targetX);

		double targetY = 0;

		// TODO: If we can shoot, THEN do this
		if (Math.abs(ballPos.getY()) < 1.0) {
			targetY = 1.5;
		}

		targetY = ValueUtil.limitAbs(targetY, 3.4);
		Vector3D target = new Vector3D(targetX, targetY, 0);

		if (worldModel.getGameState() == GameState.OPPONENT_GOAL_KICK) {
			// we should wait for the ball at the corner
			final float cornerX = worldModel.fieldHalfLength() - 3.5f;
			final float cornerY = 4;
			target = new Vector3D(cornerX, -cornerY, 0);
		}

		return new Pose2D(target, Angle.ZERO);
	}
}
