/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 * 
 * This file is part of magmaOffenburg.
 * 
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg.  If not, see <http://www.gnu.org/licenses/>.
 ********************************************************************************/
package magma.agent.thoughtmodel.strategy.impl.roles;

import magma.agent.meta.server.impl.RelativeHomePosition;
import magma.agent.worldmodel.IGlobalMap;
import magma.util.ValueUtil;
import magma.util.geometry.Angle;
import magma.util.geometry.Pose2D;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * This role primarily protects our goal. We try to be positioned relative to
 * the ball but our defensive player stays in the back.
 * 
 * @author Stephan Kammerer
 */
public class Defender extends Role
{
	public Defender(String name, IGlobalMap worldModel,
			RelativeHomePosition relativeHomePosition, float priority)
	{
		super(name, relativeHomePosition, priority, //
				-worldModel.fieldHalfLength() + 0.3, // minX
				-worldModel.fieldHalfLength() + 5); // maxX
	}

	@Override
	protected Pose2D determinePosition(IGlobalMap worldModel)
	{
		Vector3D ownGoalPos = worldModel.getOwnGoalPosition();
		Vector3D ballPos = worldModel.getBall().getPosition();

		// Vector3D homePos = worldModel.getHomePosition();
		Vector3D homePos = homePosition.getHomePosition(
				worldModel.fieldHalfLength(), worldModel.fieldHalfWith());
		double deltaBallGoalX = Math.abs(ownGoalPos.getX() - ballPos.getX());

		double targetY = homePos.getY() + ballPos.getY() / 3;
		targetY = ValueUtil.limitAbs(targetY, 3.4);

		double targetX = minX + 0.3 * deltaBallGoalX;
		float absYWeight = Math.abs(homePosition.getYWeight());

		if (absYWeight < 0.1) {
			targetX += 1; // more in front
		} else {
			targetX -= 1;
		}

		targetX = keepXLimits(targetX);

		Vector3D target = new Vector3D(targetX, targetY, 0);
		Angle ballDirection = Angle.rad(ballPos.subtract(target).getAlpha());
		return new Pose2D(target, ballDirection);
	}
}
