/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 * 
 * This file is part of magmaOffenburg.
 * 
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg.  If not, see <http://www.gnu.org/licenses/>.
 ********************************************************************************/
package magma.agent.thoughtmodel.strategy.impl.roles;

import magma.agent.meta.server.impl.RelativeHomePosition;
import magma.agent.worldmodel.IGlobalMap;
import magma.util.ValueUtil;
import magma.util.geometry.Angle;
import magma.util.geometry.Pose2D;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * The supporter role is relative behind the ball with an offset.
 * 
 * @author Stephan Kammerer
 */
public class Supporter extends Role
{
	public Supporter(String name, IGlobalMap worldModel,
			RelativeHomePosition relativeHomePosition, float priority)
	{
		super(name, relativeHomePosition, priority, //
				-worldModel.fieldHalfLength() + 2, // minX
				worldModel.fieldHalfLength() - 3); // maxX
	}

	@Override
	protected Pose2D determinePosition(IGlobalMap worldModel)
	{
		Vector3D ballPos = worldModel.getBall().getPosition();

		// we try to be positioned relative to the ball goal distance x
		double targetX = ballPos.getX() - 2.5;

		double targetY = ballPos.getY();

		Vector3D homePos = homePosition.getHomePosition(
				worldModel.fieldHalfLength(), worldModel.fieldHalfLength());
		float absYWeight = Math.abs(homePosition.getYWeight());
		int sideFactor = homePos.getY() > 0 ? 1 : -1;

		if (absYWeight < 0.1) {
			targetX -= 0.5; // more in back
			targetY += 0.5; // more left
		} else {
			// left or right Ballguard
			targetY += 1.5 * sideFactor;
		}

		targetX = keepXLimits(targetX);
		targetY = ValueUtil.limitAbs(targetY, worldModel.fieldHalfWith() - 0.5);

		return new Pose2D(targetX, targetY, Angle.ZERO);
	}
}
