/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 * 
 * This file is part of magmaOffenburg.
 * 
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg.  If not, see <http://www.gnu.org/licenses/>.
 ********************************************************************************/
package magma.agent.thoughtmodel.strategy.impl.roles;

import magma.agent.meta.server.impl.RelativeHomePosition;
import magma.agent.worldmodel.GameState;
import magma.agent.worldmodel.IGlobalMap;
import magma.util.ValueUtil;
import magma.util.geometry.Angle;
import magma.util.geometry.Pose2D;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * @author Stephan Kammerer
 */
public class Wing extends Role
{
	// how far in front of the ball
	private float xOffset;

	public Wing(String name, IGlobalMap worldModel,
			RelativeHomePosition relativeHomePosition, float xOffset,
			float priority)
	{
		super(name, relativeHomePosition, priority, //
				-1.5, // minX
				worldModel.fieldHalfLength() - 2.5); // maxX

		this.xOffset = xOffset;
	}

	@Override
	protected Pose2D determinePosition(IGlobalMap worldModel)
	{
		Vector3D ballPos = worldModel.getBall().getPosition();
		Vector3D ourPos = worldModel.getThisPlayer().getPosition();
		// Vector3D homePos = worldModel.getHomePosition();
		// Vector3D homePos = homePosition.getHomePosition(
		// worldModel.fieldHalfLength(), worldModel.fieldHalfWith());

		// we try to be positioned relative to the ball goal distance x
		double targetX = ballPos.getX() + xOffset;
		targetX = keepLimits(targetX, minX, maxX);

		double targetY = 0;
		if (Math.abs(ballPos.getY()) < 1.0) {
			if (ballPos.getY() < ourPos.getY()) {
				targetY = 1.5;
			} else {
				targetY = -1.5;
			}
		}

		targetY = ValueUtil.limitAbs(targetY, 3.4);
		Vector3D target = new Vector3D(targetX, targetY, 0);

		if (worldModel.getGameState() == GameState.OPPONENT_GOAL_KICK) {
			// we should wait for the ball at the corner
			final float cornerX = worldModel.fieldHalfLength() - 3.5f;
			final float cornerY = 4;
			target = new Vector3D(cornerX, -cornerY, 0);
		}

		return new Pose2D(target, Angle.ZERO);
	}
}
