/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 * 
 * This file is part of magmaOffenburg.
 * 
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg.  If not, see <http://www.gnu.org/licenses/>.
 ********************************************************************************/
package magma.agent.thoughtmodel.strategy.impl.strategies;

import magma.agent.thoughtmodel.strategy.impl.IRoleConstants;
import magma.agent.thoughtmodel.strategy.impl.roles.Ballguard;
import magma.agent.thoughtmodel.strategy.impl.roles.Defender;
import magma.agent.thoughtmodel.strategy.impl.roles.Goalkeeper;
import magma.agent.thoughtmodel.strategy.impl.roles.Wing;
import magma.agent.worldmodel.IGlobalMap;

/**
 * Our default strategy, primarily used when we had no dynamic role management.
 * 
 * @author Stephan Kammerer
 */
public class DefaultStrategy extends BaseStrategy
{
	public DefaultStrategy(IGlobalMap worldModel)
	{
		availableRoles.add(new Goalkeeper("goalie", IRoleConstants.GOAL_KEEPER,
				1.0f));

		// Instantiate defender with its name, home position and priority
		availableRoles.add(new Defender("LeftDefender", worldModel,
				IRoleConstants.LEFT_DEFENDER, 5.0f));
		availableRoles.add(new Defender("CenterDefender", worldModel,
				IRoleConstants.CENTER_DEFENDER, 5.0f));
		availableRoles.add(new Defender("RightDefender", worldModel,
				IRoleConstants.RIGHT_DEFENDER, 5.0f));
		// availableRoles.add(new BallAcceptor("BallAcceptor",
		// IRoleConstants.RIGHT_DEFENDER, 4.0f));

		// Instantiate guards with its name, home position, offset (in
		// x-direction) and priority
		availableRoles.add(new Ballguard("LeftSupportguard", worldModel, 5.0f,
				IRoleConstants.LEFT_SUPPORTGUARD, 2.0f));
		availableRoles.add(new Ballguard("CenterSupportguard", worldModel, 3.8f,
				IRoleConstants.CENTER_SUPPORTGUARD, 1.0f));
		availableRoles.add(new Ballguard("RightSupportguard", worldModel, 5.0f,
				IRoleConstants.RIGHT_SUPPORTGUARD, 2.0f));
		availableRoles.add(new Ballguard("LeftBallguard", worldModel, 1.0f,
				IRoleConstants.LEFT_BALLGUARD, 3.0f));

		availableRoles.add(new Wing("Wing", worldModel,
				IRoleConstants.WING_COMMANDER, 4.5f, 4.0f));

		availableRoles.add(new Ballguard("CenterBallguard", worldModel, 2.6f,
				IRoleConstants.CENTER_BALLGUARD, 3.0f));
		availableRoles.add(new Ballguard("RightBallguard", worldModel, 1.0f,
				IRoleConstants.RIGHT_BALLGUARD, 3.0f));
	}
}
