/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 * 
 * This file is part of magmaOffenburg.
 * 
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg.  If not, see <http://www.gnu.org/licenses/>.
 ********************************************************************************/
package magma.agent.thoughtmodel.strategy.impl.strategies;

import magma.agent.thoughtmodel.strategy.impl.IRoleConstants;
import magma.agent.thoughtmodel.strategy.impl.roles.BallAcceptor;
import magma.agent.thoughtmodel.strategy.impl.roles.BallDemander;
import magma.agent.thoughtmodel.strategy.impl.roles.Ballguard;
import magma.agent.thoughtmodel.strategy.impl.roles.Goalkeeper;
import magma.agent.thoughtmodel.strategy.impl.roles.OffensiveDefender;
import magma.agent.worldmodel.IGlobalMap;

/**
 * This strategy plays with a ball acceptor and a ball demander, thus two
 * players in front of the actual ball position. Also there are two defenders,
 * which can be more offensive if the ball is far in the enemy territory.
 * 
 * Priority of ballguards are not as high as of supporting guards
 * 
 * @author Stephan Kammerer
 */
public class OffensiveStrategy extends BaseStrategy
{
	public OffensiveStrategy(IGlobalMap worldModel)
	{
		availableRoles.add(new Goalkeeper("goalie", IRoleConstants.GOAL_KEEPER,
				1.0f));

		// Defenders
		availableRoles.add(new OffensiveDefender("LeftDefender", worldModel,
				IRoleConstants.LEFT_INNER_DEFENDER, 5.0f));
		availableRoles.add(new OffensiveDefender("RightDefender", worldModel,
				IRoleConstants.RIGHT_INNER_DEFENDER, 5.0f));

		// Guards
		availableRoles.add(new Ballguard("LeftSupportguard", worldModel, 5.0f,
				IRoleConstants.LEFT_SUPPORTGUARD, 2.0f));
		availableRoles.add(new Ballguard("CenterSupportguard", worldModel, 3.8f,
				IRoleConstants.CENTER_SUPPORTGUARD, 2.0f));
		availableRoles.add(new Ballguard("RightSupportguard", worldModel, 5.0f,
				IRoleConstants.RIGHT_SUPPORTGUARD, 2.0f));

		availableRoles.add(new Ballguard("LeftBallguard", worldModel, 1.0f,
				IRoleConstants.LEFT_BALLGUARD, 2.0f));
		availableRoles.add(new Ballguard("CenterBallguard", worldModel, 1.6f,
				IRoleConstants.CENTER_BALLGUARD, 3.0f));
		availableRoles.add(new Ballguard("RightBallguard", worldModel, 1.0f,
				IRoleConstants.RIGHT_BALLGUARD, 2.0f));

		// Offensive roles
		availableRoles.add(new BallAcceptor("BallAcceptor", worldModel,
				IRoleConstants.BALL_ACCEPTOR, 4.0f));
		availableRoles.add(new BallDemander("BallDemander", worldModel,
				IRoleConstants.BALL_DEMANDER, 4.0f));
	}

}
