/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.worldmodel.impl;

import magma.util.geometry.Geometry;
import magma.util.geometry.positionFilter.IPositionFilter;
import magma.util.geometry.positionFilter.LowFrequencyPositionFilter;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * Represents the ball of the game
 */
public class Ball extends MovableObject
{
	/**  */
	private static final long serialVersionUID = 9252371297804616L;

	/** The radius of the ball in m */
	private final float radius;

	/** The decay of the ball speed */
	private final float ballDecay;

	/** The filter used to smoothen the position estimation */
	// protected final transient PositionSpeedKalmanFilter posFilter = new
	// PositionSpeedKalmanFilter();

	protected final transient IPositionFilter posFilter;

	/**
	 * Constructor
	 */
	public Ball(float radius, float ballDecay)
	{
		super("Ball");
		this.radius = radius;
		this.ballDecay = ballDecay;
		// posFilter = new NoFilter();
		posFilter = new LowFrequencyPositionFilter(5);
		// for Sweaty we had this one
		// this.posFilter = new PositionFilter();
	}

	@Override
	protected Vector3D[] calculateFuturePositions(int howMany)
	{
		return Geometry.getFuturePositions(position, speed, ballDecay, howMany);
	}

	@Override
	public double getPossibleSpeed()
	{
		return 6.0;
	}

	@Override
	public void updateFromVision(Vector3D localPosition,
			Vector3D globalPosition, float time)
	{
		if (getAge(time) > 5.0f) {
			// If our last update is older than 5 seconds, reset the position
			// filter
			posFilter.reset();
		}
		// for Kalman we need the speed in m/s
		// Vector3D observedSpeed = calculateSpeed(globalPosition, time,
		// getPosition(), lastSeenTime).scalarMultiply(50);
		// Vector3D filterPosition = posFilter.filterPosition(globalPosition,
		// observedSpeed);
		Vector3D filterPosition = posFilter.filterPosition(globalPosition);
		super.updateFromVision(localPosition, filterPosition, time);
	}

	@Override
	public double getCollisionDistance()
	{
		return 0.28;
	}

	/**
	 * @return the radius in m
	 */
	public float getRadius()
	{
		return radius;
	}

	/**
	 * @param globalTime
	 */
	@Override
	public void updateNoVision(float globalTime)
	{
		super.updateNoVision(globalTime);
		oldSpeed = speed;
		speed = speed.scalarMultiply(ballDecay);
	}
}