/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.worldmodel.localizer.impl;

import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;

import magma.agent.worldmodel.localizer.IEnvironmentModel;
import magma.agent.worldmodel.localizer.ILocalizationLine;
import magma.agent.worldmodel.localizer.IReferenceLine;
import magma.agent.worldmodel.localizer.IReferencePoint;
import magma.util.geometry.Pose3D;

import org.apache.commons.math3.geometry.euclidean.threed.Rotation;

/**
 * Implements a 3-dimensional localizer based on reference points and the
 * estimated orientation.
 * 
 * @author Stefan Glaser
 */
public class LocalizerGyro extends LocalizerBase
{
	/** handle for logging */
	private static final Logger logger = Logger.getLogger("");

	@Override
	public Pose3D localize(IEnvironmentModel environment,
			List<ILocalizationLine> lines, Rotation estimatedOrientation)
	{
		if (estimatedOrientation == null) {
			// there is no gyro information available
			logger.log(Level.FINER,
					"Gyro Localization not possible, there is no gyro information available!");
			return null;
		}

		// fetch reference points and -lines
		List<IReferencePoint> refPoints = getVisibleReferencePoints(environment);
		List<IReferenceLine> refLines = getVisibleReferenceLines(environment);

		if (refPoints.size() == 0) {
			// there is no visible flag
			logger.log(Level.FINER,
					"Gyro Localization not possible, there is no visible reference point!");
			return null;
		}

		return new Pose3D(LocalizerUtil.calculatePosition(refPoints, refLines,
				estimatedOrientation), estimatedOrientation);
	}
}
