/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 */

package magma.robots.nao.agent.communication.base;

import magma.agent.action.impl.ServerMessageEncoder;
import magma.agent.communication.IChannelManager;
import magma.agent.communication.IChannelState.ConnectionState;
import magma.agent.communication.base.ChannelParameters;
import magma.agent.communication.base.InputOutputChannel;
import magma.agent.meta.agent.IAgentMetaModel;
import magma.agent.perception.impl.ServerMessageParser;
import magma.util.connection.ConnectionException;
import magma.util.connection.impl.ServerConnection;

/**
 * 
 * @author kdorer
 */
public class SimsparkChannel extends InputOutputChannel
{
	/** the scene string to send as first command */
	private String scene;

	/** the init message to be sent as second message */
	private String initMessage;

	public SimsparkChannel(IChannelManager manager, ChannelParameters info)
	{
		super(manager, new ServerConnection(info.getHost(), info.getPort()),
				new ServerMessageParser(), new ServerMessageEncoder());

		initMessage = "(init (unum " + info.getPlayerNumber() + ")(teamname "
				+ info.getTeamname() + "))";
	}

	@Override
	public void init(IAgentMetaModel instance)
	{
		this.scene = "(scene " + instance.getSceneString() + ")";
	}

	@Override
	protected boolean startReceiveLoop()
	{
		Thread ourThread = new Thread(new Runnable() {
			@Override
			public void run()
			{
				try {
					connection.sendMessage(scene.getBytes());
					connection.startReceiveLoop();
					state.setConnectionState(ConnectionState.NOT_CONNECTED);
				} catch (ConnectionException e) {
					state.setConnectionState(ConnectionState.DISCONNECTED);
					System.out.println(e);
					// e.printStackTrace();
				} catch (RuntimeException e) {
					state.setConnectionState(ConnectionState.DISCONNECTED);
					e.printStackTrace();
				}
				getManager().lostConnection(SimsparkChannel.this);
			}
		});
		ourThread.start();
		return true;
	}

	/**
	 * Notification when the first message was received on this channel, before
	 * processing it
	 * @param message
	 * @throws ConnectionException
	 */
	@Override
	protected void onFirstMessage(byte[] message) throws ConnectionException
	{
		// After initially sending the scene string (for choosing the
		// model), we are forced to send a further (soccer specific)
		// initialization string to the server as the reply of the very first
		// received perception-message.
		connection.sendMessage(initMessage.getBytes());
	}
}
