/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 */

package magma.robots.nao.agent.communication.base;

import java.io.File;
import java.io.FileNotFoundException;

import magma.agent.action.impl.ServerMessageEncoder;
import magma.agent.communication.IChannelManager;
import magma.agent.communication.IChannelState.ConnectionState;
import magma.agent.communication.base.ChannelParameters;
import magma.agent.communication.base.InputOutputChannel;
import magma.agent.meta.agent.IAgentMetaModel;
import magma.agent.perception.impl.ServerMessageParser;
import magma.util.connection.ConnectionException;
import magma.util.connection.impl.TimedConnection;
import magma.util.file.LogfileReader;
import magma.util.file.LogfileWriter;

/**
 * Behaves like a simspark connection, but reads the sensor information from a
 * logfile.
 * @author kdorer
 */
public class SimsparkLogfileReaderChannel extends InputOutputChannel
{
	/** file to read perceptions from */
	private LogfileReader logPercept;

	/** file to write actions to */
	private LogfileWriter logAct;

	public SimsparkLogfileReaderChannel(IChannelManager manager,
			ChannelParameters info, File perceptionfile, File actionFile)
	{
		super(manager, new TimedConnection(20), new ServerMessageParser(),
				new ServerMessageEncoder());

		this.logPercept = new LogfileReader(perceptionfile);

		if (actionFile != null) {
			logAct = new LogfileWriter(actionFile);
			logAct.open();
		}
	}

	@Override
	protected boolean startReceiveLoop()
	{
		Thread ourThread = new Thread(new Runnable() {
			@Override
			public void run()
			{
				try {
					logPercept.open();
					connection.startReceiveLoop();
					state.setConnectionState(ConnectionState.NOT_CONNECTED);
				} catch (ConnectionException e) {
					state.setConnectionState(ConnectionState.DISCONNECTED);
					System.out.println(e);
					// e.printStackTrace();
				} catch (RuntimeException e) {
					state.setConnectionState(ConnectionState.DISCONNECTED);
					e.printStackTrace();
				} catch (FileNotFoundException e) {
					state.setConnectionState(ConnectionState.DISCONNECTED);
					e.printStackTrace();
				}
				getManager().lostConnection(SimsparkLogfileReaderChannel.this);
			}
		});
		ourThread.start();
		return true;
	}

	@Override
	public void init(IAgentMetaModel instance)
	{
	}

	@Override
	protected void sendMessage(byte[] message)
	{
		if (logAct != null) {
			logAct.write(new String(message));
		}
		// this connection does not send back messages
	}

	/**
	 * Notification for each message was received on this channel
	 * @param message
	 */
	@Override
	protected void onEachMessage(byte[] message) throws ConnectionException
	{
		String msg = logPercept.next();
		if (msg == null) {
			stopChannel();
		}
		super.onEachMessage(msg.getBytes());
	}

	@Override
	public void stopChannel()
	{
		logPercept.close();
		if (logAct != null) {
			logAct.close();
		}
		super.stopChannel();
	}
}
