/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 */

package magma.robots.nao.agent.communication.base;

import java.io.File;

import magma.agent.communication.IChannelManager;
import magma.agent.communication.base.ChannelParameters;
import magma.util.connection.ConnectionException;
import magma.util.file.LogfileWriter;

/**
 * Adds that each message received is logged to a file and/or each message sent
 * as well. I would have preferred to do this as a decorator, but there is no
 * interface to decorate the onEachMessage(). And since I only needed it now for
 * Simspark...
 * @author kdorer
 */
public class SimsparkLogfileWriterChannel extends SimsparkChannel
{
	private LogfileWriter logPercept;

	private LogfileWriter logAct;

	/**
	 * 
	 * @param manager the channel manager to report to
	 * @param info configuration information for the channel
	 * @param perceptionFile the file to write perceptions to, null if no
	 *        perceptions should be logged
	 * @param actionFile the file to write actions to, null if no actions should
	 *        be logged
	 */
	public SimsparkLogfileWriterChannel(IChannelManager manager,
			ChannelParameters info, File perceptionFile, File actionFile)
	{
		super(manager, info);

		if (perceptionFile != null) {
			logPercept = new LogfileWriter(perceptionFile);
			logPercept.open();
		}

		if (actionFile != null) {
			logAct = new LogfileWriter(actionFile);
			logAct.open();
		}
	}

	@Override
	protected void onEachMessage(byte[] message) throws ConnectionException
	{
		if (logPercept != null) {
			logPercept.write(new String(message));
		}
		super.onEachMessage(message);
	}

	@Override
	protected void sendMessage(byte[] message)
	{
		if (logAct != null) {
			logAct.write(new String(message));
		}
		super.sendMessage(message);
	}

	@Override
	public void stopChannel()
	{
		if (logPercept != null) {
			logPercept.close();
		}

		if (logAct != null) {
			logAct.close();
		}

		super.stopChannel();
	}
}
