/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.robots.nao.behavior.movement;

import magma.agent.behavior.IBehaviorConstants;
import magma.agent.thoughtmodel.IThoughtModel;
import magma.util.geometry.Angle;
import magma.util.geometry.Pose2D;
import magma.util.parameter.ParameterMap;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * Kick ball straight forward. This Behavior assumes that stabilizing on one leg
 * was done already
 * 
 * @author Stefan Glaser
 */
public class KickChipLeft extends KickChipRight
{
	/**  */
	private static final long serialVersionUID = 1L;

	private static final double MAX_KICK_DISTANCE = 5;

	/**
	 * Default constructor
	 * 
	 * @param thoughtModel Reference to the thought model object
	 */
	public KickChipLeft(String name, IThoughtModel thoughtModel,
			ParameterMap params, Pose2D relativeRunToPose, double maxKickDistance,
			Vector3D[] shootPoly)
	{
		super(name, thoughtModel, params, relativeRunToPose, maxKickDistance,
				shootPoly);

		kickFast = kickFast.getLeftVersion();
		currentMovement = kickFast;
	}

	/**
	 * Default constructor
	 * 
	 * @param thoughtModel Reference to the thought model object
	 */
	public KickChipLeft(IThoughtModel thoughtModel, ParameterMap params)
	{
		this(IBehaviorConstants.KICK_CHIP_LEFT, thoughtModel, params, new Pose2D(
				-0.12, 0, Angle.ZERO), MAX_KICK_DISTANCE, SHOOT_POLY);
	}
}