/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.robots.nao.behavior.movement;

import magma.util.parameter.Parameter;
import magma.util.parameter.ParameterList;

/**
 * Represents the parameter set necessary for kicking with KickStraightModel
 * 
 * @author Klaus Dorer
 */
public class KickFastBehaviorParameter extends ParameterList
{

	private static final long serialVersionUID = -2324636896847512436L;

	public enum Param {
		TIME1, TIME2, TIME3, LHP1, RHP1, RKP1, RFP1, //
		LHP2, RHYP2, RHP2, RKP2, RFP2, RKPS1, RHPS2, RHYPS2, //
		RFPS2, RROLL, LROLL, POSX, POSY, BEAMX, BEAMY
	};

	/**
	 * @param params
	 */
	protected KickFastBehaviorParameter(Parameter[] params)
	{
		super(params);
	}

	/**
	 * 
	 */
	protected void setValues()
	{
		setValue(Param.TIME1, 4.0f);
		setValue(Param.TIME2, 5.0f);
		setValue(Param.TIME3, 0.0f);
		setValue(Param.LHP1, 3.0f);
		setValue(Param.RHP1, -20.0f);
		setValue(Param.RKP1, -72.0f);
		setValue(Param.RFP1, 40.0f);
		setValue(Param.LHP2, -16.0f);
		setValue(Param.RHYP2, -58.0f);
		setValue(Param.RHP2, 61.0f);
		setValue(Param.RKP2, 6.0f);
		setValue(Param.RFP2, -27.0f);
		setValue(Param.RKPS1, 5.0f);
		setValue(Param.RHPS2, 3.0f);
		setValue(Param.RHYPS2, 0.0f);
		setValue(Param.RFPS2, 4.2f);
		setValue(Param.RROLL, -10.0f);
		setValue(Param.LROLL, 12.0f);
		setValue(Param.POSX, 0.13f);
		setValue(Param.POSY, -0.10f);
		setValue(Param.BEAMX, -1.5f);
		setValue(Param.BEAMY, -1.6f);
	}

	public static KickFastBehaviorParameter getInstance()
	{
		KickFastBehaviorParameter result = new KickFastBehaviorParameter(
				createParams());
		result.setValues();
		return result;
	}

	/**
	 * @return
	 */
	protected static Parameter[] createParams()
	{
		Parameter[] params = new Parameter[Param.values().length];
		int i = 0;
		for (Param param : Param.values()) {
			params[i++] = new Parameter(param.name());
		}
		return params;
	}

	/**
	 * @param accelerationForwards
	 * @param value
	 */
	protected void setValue(Param which, float value)
	{
		setValue(which.ordinal(), value);
	}

	/**
	 * @param index the 0 based index of the parameter.
	 * @return the value of the parameter specified by index
	 */
	final public float getValue(Param which)
	{
		return getValue(which.ordinal());
	}

	final public int getTime1()
	{
		return (int) getValue(Param.TIME1);
	}

	final public int getTime2()
	{
		return (int) getValue(Param.TIME2);
	}

	final public int getTime3()
	{
		return (int) getValue(Param.TIME3);
	}

	final public float getLHP1()
	{
		return getValue(Param.LHP1);
	}

	final public float getRHP1()
	{
		return getValue(Param.RHP1);
	}

	final public float getRKP1()
	{
		return getValue(Param.RKP1);
	}

	final public float getRFP1()
	{
		return getValue(Param.RFP1);
	}

	final public float getLHP2()
	{
		return getValue(Param.LHP2);
	}

	final public float getRHYP2()
	{
		return getValue(Param.RHYP2);
	}

	final public float getRHP2()
	{
		return getValue(Param.RHP2);
	}

	final public float getRKP2()
	{
		return getValue(Param.RKP2);
	}

	final public float getRFP2()
	{
		return getValue(Param.RFP2);
	}

	final public float getRKPS1()
	{
		return getValue(Param.RKPS1);
	}

	final public float getRHPS2()
	{
		return getValue(Param.RHPS2);
	}

	final public float getRHYPS2()
	{
		return getValue(Param.RHYPS2);
	}

	final public float getRFPS2()
	{
		return getValue(Param.RFPS2);
	}

	final public float getRRoll()
	{
		return getValue(Param.RROLL);
	}

	final public float getLRoll()
	{
		return getValue(Param.LROLL);
	}

	final public float getPosX()
	{
		return getValue(Param.POSX);
	}

	final public float getPosY()
	{
		return getValue(Param.POSY);
	}

	final public float getBeamX()
	{
		return getValue(Param.BEAMX);
	}

	final public float getBeamY()
	{
		return getValue(Param.BEAMY);
	}
}
