/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.robots.nao.behavior.movement;

import magma.agent.behavior.IBehavior;
import magma.agent.behavior.IBehaviorConstants;
import magma.agent.behavior.movement.Movement;
import magma.agent.behavior.movement.MovementBehavior;
import magma.agent.behavior.movement.MovementPhase;
import magma.agent.thoughtmodel.IThoughtModel;
import magma.robots.nao.INaoConstants;

/**
 * Moving the arms to fall from side to back
 * 
 * @author Maximilian Kroeg
 * 
 */
public class MoveArmsToFall extends MovementBehavior
{
	/**  */
	private static final long serialVersionUID = 1L;

	/** movement to move arms */
	protected Movement moveArms;

	/** movement to stretch legs */
	protected Movement moveLegs;

	/**
	 * Default constructor
	 * 
	 * @param thoughtModel Reference to the thought model object
	 */
	public MoveArmsToFall(IThoughtModel thoughtModel)
	{
		super(IBehaviorConstants.MOVE_ARM_TO_FALL_BACK, thoughtModel);

		moveArms = new Movement("moveArmsToFall");
		moveArms.add(new MovementPhase("phase1", 10) //
				.add(INaoConstants.LShoulderYaw, 90, 7f) //
				.add(INaoConstants.RShoulderYaw, -90, 7f) //
				.add(INaoConstants.LShoulderPitch, 0, 7f) //
				.add(INaoConstants.RShoulderPitch, 0, 7f) //
				.add(INaoConstants.LArmRoll, 0, 7f) //
				.add(INaoConstants.RArmRoll, 0, 7f) //
				.add(INaoConstants.LArmYaw, 0, 7f) //
				.add(INaoConstants.RArmYaw, 0, 7f) //
				);
		moveArms.add(new MovementPhase("phase2", 10) //
				.add(INaoConstants.LShoulderYaw, 0, 7f) //
				.add(INaoConstants.RShoulderYaw, 0, 7f) //
				.add(INaoConstants.LShoulderPitch, 0, 7f) //
				.add(INaoConstants.RShoulderPitch, 0, 7f) //
				.add(INaoConstants.LArmRoll, 0, 7f) //
				.add(INaoConstants.RArmRoll, 0, 7f) //
				.add(INaoConstants.LArmYaw, 0, 7f) //
				.add(INaoConstants.RArmYaw, 0, 7f) //
				);

		moveLegs = new Movement("stretchLegs");
		moveLegs.add(new MovementPhase("phase1", 10) //
				.add(INaoConstants.LHipPitch, 0, 7f) //
				.add(INaoConstants.LHipYawPitch, 0, 7f) //
				.add(INaoConstants.LKneePitch, 0, 7f) //
				.add(INaoConstants.LFootPitch, 0, 7f) //
				.add(INaoConstants.LHipRoll, 0, 7f) //
				.add(INaoConstants.LFootRoll, 0, 7f) //
				.add(INaoConstants.RHipPitch, 0, 7f) //
				.add(INaoConstants.RHipYawPitch, 0, 7f) //
				.add(INaoConstants.RKneePitch, 0, 7f) //
				.add(INaoConstants.RFootPitch, 0, 7f) //
				.add(INaoConstants.RHipRoll, 0, 7f) //
				.add(INaoConstants.RFootRoll, 0, 7f) //
				);
		currentMovement = moveArms;
	}

	@Override
	protected Movement getNextMovement()
	{
		if (currentMovement == moveArms) {
			if (getConsecutivePerforms() > 5) {
				return moveLegs;
			}
		}
		return null;
	}

	@Override
	protected Movement getInitialMovement()
	{
		return moveArms;
	}

	@Override
	public IBehavior switchFrom(IBehavior actualBehavior)
	{
		IBehavior realBehavior = actualBehavior.getRootBehavior();

		if (realBehavior instanceof KeeperRight) {
			// don't switch directly from keep and other get up behaviors
			return super.switchFrom(actualBehavior);
		}

		// by default allow switching to this behavior immediately
		if (actualBehavior.isFinished()) {
			actualBehavior.onLeavingBehavior(this);
		} else {
			actualBehavior.abort();
		}

		return this;
	}
}
