/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package magma.robots.nao.behavior.movement;

import magma.agent.behavior.IBehaviorConstants;
import magma.agent.behavior.movement.Movement;
import magma.agent.behavior.movement.MovementBehavior;
import magma.agent.behavior.movement.MovementPhase;
import magma.agent.thoughtmodel.IThoughtModel;
import magma.robots.nao.INaoConstants;

/**
 * @author Rajit Shahi, Ingo Schindler
 */
public class Push extends MovementBehavior
{
	/**  */
	private static final long serialVersionUID = 1L;

	/** movement to push the arms forward */
	protected Movement push;

	/**
	 * Default constructor
	 * 
	 * @param thoughtModel Reference to the thought model object
	 */
	public Push(IThoughtModel thoughtModel)
	{
		super(IBehaviorConstants.PUSH, thoughtModel);

		int knee = -53;

		push = new Movement("push");
		push.add(new MovementPhase("armsForward", 13) //
				.add(INaoConstants.LShoulderPitch, 0, 7f) //
				.add(INaoConstants.LShoulderYaw, 0, 7f) //
				.add(INaoConstants.LArmYaw, 0, 7f) //
				.add(INaoConstants.LArmRoll, 0, 7f) //
				.add(INaoConstants.LKneePitch, knee, 2f) //
				// .add(INaoConstants.LHipPitch, hip, 7f) //

				.add(INaoConstants.RShoulderPitch, 0, 7f) //
				.add(INaoConstants.RShoulderYaw, 0, 7f) //
				.add(INaoConstants.RArmYaw, 0, 7f) //
				.add(INaoConstants.RArmRoll, 0, 7f) //
				.add(INaoConstants.RKneePitch, knee, 2f) //
		// .add(INaoConstants.RHipPitch, hip, 7f) //
		);

		push.add(new MovementPhase("armsBackward", 150) //
				.add(INaoConstants.LShoulderPitch, 0, 7f) //
				.add(INaoConstants.LShoulderYaw, 0, 7f) //
				.add(INaoConstants.LArmYaw, -90, 7f) //
				.add(INaoConstants.LArmRoll, 0, 7f) //
				.add(INaoConstants.LKneePitch, knee, 2f) //
				// .add(INaoConstants.LHipPitch, 40, 1f) //

				.add(INaoConstants.RShoulderPitch, 0, 7f) //
				.add(INaoConstants.RShoulderYaw, 0, 7f) //
				.add(INaoConstants.RArmYaw, 90, 7f) //
				.add(INaoConstants.RArmRoll, 0, 7f) //
				.add(INaoConstants.RKneePitch, knee, 2f) //
		// .add(INaoConstants.RHipPitch, 40, 1f) //
		);
		currentMovement = push;
	}

	@Override
	protected Movement getInitialMovement()
	{
		return push;
	}
}
