/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.robots.nao.behavior.movement;

import magma.agent.behavior.IBehaviorConstants;
import magma.agent.thoughtmodel.IThoughtModel;
import magma.util.geometry.Angle;
import magma.util.geometry.Geometry;
import magma.util.geometry.Pose2D;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * This behavior kicks somehow to the right with the left foot.
 * 
 * @author Stefan Glaser
 * 
 */
public class SideKickLeft extends SideKickRight
{
	/**  */
	private static final long serialVersionUID = 1L;

	/** length of the kickable area */
	private static final double MAX_X_KICK = 0.18;

	/** width of the kickable area */
	private static final double MAX_Y_KICK = 0.04;

	private static final Vector3D[] SHOOT_POLY = Geometry
			.getPolygon(new double[][] { { 0, MAX_Y_KICK },
					{ MAX_X_KICK, MAX_Y_KICK }, { MAX_X_KICK, -MAX_Y_KICK },
					{ 0, -MAX_Y_KICK } });

	/**
	 * Default constructor.
	 * 
	 * @param thoughtModel Reference to the thought model object
	 */
	public SideKickLeft(IThoughtModel thoughtModel)
	{
		super(IBehaviorConstants.SHOOT_SIDE_LEFT, thoughtModel, new Pose2D(0,
				-0.15, Angle.ANGLE_90), MAX_KICK_DISTANCE, SHOOT_POLY);

		getOnLeftLeg = getOnLeftLeg.getLeftVersion();
		kickSide = kickSide.getLeftVersion();
	}
}
