/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.robots.nao.belief.impl;

import magma.agent.belief.IBeliefConstants;
import magma.agent.belief.impl.Belief;
import magma.agent.thoughtmodel.IThoughtModel;
import magma.robots.nao.INaoConstants;
import magma.util.FuzzyCompare;

/**
 * Checks if the robot is ready to walk or kick
 * 
 * @author Klaus Dorer
 */
public class SoccerPosition extends Belief
{
	/** cached truth value that changes only in certain positions */
	private float truthValue;

	private float desiredKneeAngle;

	/** desired hip angle in degrees, <-180 means hip angle is not checked */
	private float desiredHipAngle;

	/**
	 * @param name
	 * @param thoughtModel
	 * @param desiredKneeAngle the desired angle of the knees in degrees
	 */
	public SoccerPosition(IThoughtModel thoughtModel, float desiredKneeAngle,
			float desiredHipAngle)
	{
		super(IBeliefConstants.SOCCER_POSITION, thoughtModel);
		this.desiredKneeAngle = desiredKneeAngle;
		this.desiredHipAngle = desiredHipAngle;
		truthValue = 0.0f;
	}

	@Override
	public float getTruthValue()
	{
		double angleRight = agent.getHJ(INaoConstants.RKneePitch).getAxis();
		double angleLeft = agent.getHJ(INaoConstants.LKneePitch).getAxis();

		if (FuzzyCompare.eq((float) angleRight, desiredKneeAngle, 5f)
				&& FuzzyCompare.eq((float) angleLeft, desiredKneeAngle, 5f)) {
			if (desiredHipAngle >= -180) {
				double angleHipRight = agent.getHJ(INaoConstants.RHipRoll)
						.getAxis();
				double angleHipLeft = agent.getHJ(INaoConstants.LHipRoll).getAxis();
				if (FuzzyCompare.eq((float) angleHipRight, desiredHipAngle, 3f)
						&& FuzzyCompare.eq((float) angleHipLeft, desiredHipAngle, 3f)) {
					// switch to ready for soccer playing
					truthValue = 1.0f;
				}
			} else {
				truthValue = 1.0f;
			}
		} else if (FuzzyCompare.eq((float) angleRight, (float) Math.toDegrees(0),
				15f)
				&& FuzzyCompare.eq((float) angleLeft, (float) Math.toDegrees(0),
						15f)) {
			// switch to standing upright
			truthValue = 0.0f;
		}

		return truthValue;
	}
}
