/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.util.connection.impl;

import java.util.logging.Logger;

import magma.util.connection.IServerConnection;
import magma.util.observer.IObserver;
import magma.util.observer.IPublishSubscribe;
import magma.util.observer.Subject;

/**
 * Base for connection implementations
 * 
 * @author Klaus Dorer
 */
public abstract class ConnectionBase implements IServerConnection
{
	// handle for logging
	protected static final Logger logger = Logger.getLogger("");

	// Observer
	protected final IPublishSubscribe<byte[]> observer;

	// True if connection is closed (after disconnection/error)
	protected boolean shutDown;

	// true if we are currently connected to the server
	protected boolean connected;

	/**
	 * Default
	 */
	public ConnectionBase()
	{
		shutDown = false;
		connected = false;
		observer = new Subject<byte[]>();
	}

	/**
	 * Stops the loop of receiving messages and notifying observers after
	 * receiving the next message
	 */
	@Override
	public void stopReceiveLoop()
	{
		shutDown = true;
	}

	/**
	 * Attaches a new observer to this connection
	 * 
	 * @param newObserver the observer that is interested in new messages
	 */
	@Override
	public void attach(IObserver<byte[]> newObserver)
	{
		observer.attach(newObserver);
	}

	/**
	 * @return true if we are currently connected to the server
	 */
	@Override
	public boolean isConnected()
	{
		return connected;
	}
}
