/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 * 
 * This file is part of magmaOffenburg.
 * 
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg.  If not, see <http://www.gnu.org/licenses/>.
 ********************************************************************************/
package magma.util.connection.impl;

import java.io.File;
import java.io.FileNotFoundException;

import magma.util.connection.ConnectionException;
import magma.util.connection.IServerConnection;
import magma.util.file.LogfileReader;

/**
 * @author Stefan Glaser
 */
public class RCSSLogFileConnection extends ConnectionBase implements
		IServerConnection
{
	LogfileReader logfile;

	public RCSSLogFileConnection(File file)
	{
		logfile = new LogfileReader(file);
	}

	public String next()
	{
		String currentMessage;
		if (connected) {
			currentMessage = logfile.next();

			if (currentMessage != null) {
				observer.onStateChange(currentMessage.getBytes());
				return currentMessage;
			} else {
				stopReceiveLoop();
				return null;
			}
		}

		return null;
	}

	@Override
	public void establishConnection() throws ConnectionException
	{
		try {
			logfile.open();
			connected = true;
		} catch (FileNotFoundException e) {
			throw new ConnectionException(e.getMessage(), e);
		}
	}

	@Override
	public void sendMessage(byte[] msg) throws ConnectionException
	{
	}

	@Override
	public void startReceiveLoop() throws ConnectionException
	{
		// nothing to do
	}

	@Override
	public void stopReceiveLoop()
	{
		logfile.close();
		super.stopReceiveLoop();
	}
}
