/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 */

package magma.util.function;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * Represents a Bezier function in 3D.
 * @author kdorer
 */
public class BezierFunction
{
	/** start point of the curve */
	Vector3D p0;

	/** point defining the tangent at the start point */
	Vector3D p1;

	/** point defining the tangent at the end point */
	Vector3D p2;

	/** end point of the cuve */
	Vector3D p3;

	/**
	 * @param p0 start point of the curve
	 * @param p1 point defining the tangent at the start point
	 * @param p2 point defining the tangent at the end point
	 * @param p3 end point of the curve
	 */
	public BezierFunction(Vector3D p0, Vector3D p1, Vector3D p2, Vector3D p3)
	{
		this.p0 = p0;
		this.p1 = p1;
		this.p2 = p2;
		this.p3 = p3;
	}

	/**
	 * Calculates a point in 3D space that resembles a point on a 3D Bezier
	 * curve.
	 * 
	 * @param t the interpolation parameter (0..1)
	 * @return point on Bezier curve.
	 */
	public Vector3D calculateBezierPoint(float t)
	{
		return FunctionUtil.bezierPoint(p0, p1, p2, p3, t);
	}

	/**
	 * Calculates and prints the specified number of Bezier points
	 * @param segments the number of points to calculate
	 */
	public void calculateCurve(int segments)
	{
		for (int i = 0; i <= segments; i++) {
			float t = i / (float) segments;
			Vector3D point = calculateBezierPoint(t);
			System.out.println(point);
		}
	}
}
