/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 */

package magma.util.function;

import java.util.List;

/**
 * 
 * @author kdorer
 */
public class PiecewiseSinusSquare extends SupportPointFunction
{
	/** serial ID for serialization */
	private static final long serialVersionUID = 1L;

	/** name identifying a this kind of function */
	public static final String SIN_SQUARE_NAME = "sinsquare";

	/**
	 * 
	 */
	public PiecewiseSinusSquare()
	{
		super(1);
	}

	/**
	 * 
	 */
	public PiecewiseSinusSquare(List<SupportPoint> supportPoints, float stiffness)
	{
		super(supportPoints, stiffness);
	}

	/**
	 * 
	 */
	public PiecewiseSinusSquare(PiecewiseSinusSquare source)
	{
		super(source);
	}

	@Override
	protected int getMinimumSupportPointSize()
	{
		return 0;
	}

	@Override
	protected int getMaximumSupportPointSize()
	{
		return Integer.MAX_VALUE;
	}

	@Override
	public String getName()
	{
		return SIN_SQUARE_NAME;
	}

	@Override
	public double value(double x)
	{

		// Special condition for logging use
		if (supportPoints.size() == 0) {
			return 0;
		}

		// Catch border conditions
		if (x <= getMinX()) {
			return supportPoints.get(0).y;
		} else if (x >= getMaxX()) {
			return supportPoints.get(supportPoints.size() - 1).y;
		}

		int index = 1;

		// Find index after the SupportPoint that is closest, but smaller or equal
		// to t
		while (index < supportPoints.size() && x >= supportPoints.get(index).x) {
			index++;
		}

		SupportPoint sPointBefore = supportPoints.get(index - 1);
		SupportPoint sPointAfter = supportPoints.get(index);

		// sinus sqare interpolation
		double deltay = sPointAfter.y - sPointBefore.y;
		double deltax = sPointAfter.x - sPointBefore.x;
		double sinsquare = Math
				.sin((x - sPointBefore.x) / deltax * (Math.PI / 2));

		return sPointBefore.y + deltay * sinsquare * sinsquare;
	}

	@Override
	public IFunction copy()
	{
		return new PiecewiseSinusSquare(this);
	}
}
