/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 */

package magma.util.geometry;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * Represents a circle in 3D space.
 * @author kdorer
 */
public class Circle3D
{
	/** center of the circle */
	private Vector3D center;

	/** normal to the plane in which the circle is */
	private Vector3D normal;

	/** radius of the circle */
	private double radius;

	/**
	 * For now we assume that the circle is parallel to the x-plane. So normal
	 * vector is ignored.
	 */
	public Circle3D(Vector3D center, double radius)
	{
		this.center = center;
		this.radius = radius;
		this.normal = Vector3D.PLUS_I;
	}

	/**
	 * @return the center
	 */
	public Vector3D getCenter()
	{
		return center;
	}

	/**
	 * @return the normal of the plane in which the circle is
	 */
	public Vector3D getNormal()
	{
		return normal;
	}

	/**
	 * @return the radius
	 */
	public double getRadius()
	{
		return radius;
	}

	@Override
	public String toString()
	{
		return center + " : " + radius;
	}
}
