/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 * 
 * This file is part of magmaOffenburg.
 * 
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg.  If not, see <http://www.gnu.org/licenses/>.
 ********************************************************************************/
package magma.util.geometry;

import java.io.Serializable;

import org.apache.commons.math3.geometry.euclidean.threed.Rotation;
import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * Interface for a 3D pose.
 * 
 * @author Stefan Glaser
 */
public interface IPose3D extends Serializable
{
	/**
	 * Retrieve the x-position value.
	 * 
	 * @return the x-position value
	 */
	public double getX();

	/**
	 * Retrieve the y-position value.
	 * 
	 * @return the y-position value
	 */
	public double getY();

	/**
	 * Retrieve the z-position value.
	 * 
	 * @return the z-position value
	 */
	public double getZ();

	/**
	 * Retrieve the position.
	 * 
	 * @return the position
	 */
	public Vector3D getPosition();

	/**
	 * Retrieve the orientation.
	 * 
	 * @return the orientation
	 */
	public Rotation getOrientation();

	/**
	 * Apply this pose as a rigid transformation to another pose. The resulting
	 * pose is stored in a new object.
	 * 
	 * @param other the pose to transform
	 * @return a new pose object holding the resulting pose
	 */
	public IPose3D applyTo(IPose3D other);

	/**
	 * Apply this pose inversely as a rigid transformation to another pose. The
	 * resulting pose is stored in a new object.
	 * 
	 * @param other the pose to transform
	 * @return a new pose object holding the resulting pose
	 */
	public IPose3D applyInverseTo(IPose3D other);

	/**
	 * Apply this pose as a rigid transformation to the given position vector.
	 * 
	 * @param position the position vector to transform
	 * @return the transformed vector
	 */
	public Vector3D applyTo(Vector3D position);

	/**
	 * Apply this pose inversely as a rigid transformation to the given position
	 * vector.
	 * 
	 * @param position the position vector to transform
	 * @return the inversely transformed vector
	 */
	public Vector3D applyInverseTo(Vector3D position);
}
