/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 * 
 * This file is part of magmaOffenburg.
 * 
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg.  If not, see <http://www.gnu.org/licenses/>.
 ********************************************************************************/
package magma.util.geometry.interpolation.pose;

import magma.util.geometry.Pose6D;
import magma.util.geometry.interpolation.IPoseInterpolator;
import magma.util.geometry.interpolation.IValueInterpolator;
import magma.util.geometry.interpolation.value.LinearValueInterpolator;

/**
 * @author Stefan Glaser
 */
public class PoseInterpolator implements IPoseInterpolator
{
	/** */
	private static final long serialVersionUID = -5114110363805339014L;

	/** Value interpolator for the x-position */
	public IValueInterpolator xInterpolator;

	/** Value interpolator for the y-position */
	public IValueInterpolator yInterpolator;

	/** Value interpolator for the z-position */
	public IValueInterpolator zInterpolator;

	/** Value interpolator for the x-rotation */
	public IValueInterpolator xRotInterpolator;

	/** Value interpolator for the y-rotation */
	public IValueInterpolator yRotInterpolator;

	/** Value interpolator for the z-rotation */
	public IValueInterpolator zRotInterpolator;

	/**
	 * Default constructor to create a new PoseTrajectoryInterpolator instance
	 * with linear interpolators for all dimensions.
	 */
	public PoseInterpolator()
	{
		this(new LinearValueInterpolator(), new LinearValueInterpolator(),
				new LinearValueInterpolator(), new LinearValueInterpolator(),
				new LinearValueInterpolator(), new LinearValueInterpolator());
	}

	/**
	 * Create a new PoseTrajectoryInterpolator instance using the given
	 * interpolators.
	 * 
	 * @param xInterpolator - the interpolator for x-position
	 * @param yInterpolator - the interpolator for y-position
	 * @param zInterpolator - the interpolator for z-position
	 * @param xRotInterpolator - the interpolator for x-rotation
	 * @param yRotInterpolator - the interpolator for y-rotation
	 * @param zRotInterpolator - the interpolator for z-rotation
	 */
	public PoseInterpolator(IValueInterpolator xInterpolator,
			IValueInterpolator yInterpolator, IValueInterpolator zInterpolator,
			IValueInterpolator xRotInterpolator,
			IValueInterpolator yRotInterpolator,
			IValueInterpolator zRotInterpolator)
	{
		this.xInterpolator = xInterpolator;
		this.yInterpolator = yInterpolator;
		this.zInterpolator = zInterpolator;
		this.xRotInterpolator = xRotInterpolator;
		this.yRotInterpolator = yRotInterpolator;
		this.zRotInterpolator = zRotInterpolator;
	}

	@Override
	public Pose6D interpolate(Pose6D initialPose, Pose6D targetPose, float t)
	{
		Pose6D res = new Pose6D();

		res.x = xInterpolator.interpolate(initialPose.x, targetPose.x, t);
		res.y = yInterpolator.interpolate(initialPose.y, targetPose.y, t);
		res.z = zInterpolator.interpolate(initialPose.z, targetPose.z, t);

		res.xAngle = xRotInterpolator.interpolate(initialPose.xAngle,
				targetPose.xAngle, t);
		res.yAngle = yRotInterpolator.interpolate(initialPose.yAngle,
				targetPose.yAngle, t);
		res.zAngle = zRotInterpolator.interpolate(initialPose.zAngle,
				targetPose.zAngle, t);

		return res;
	}
}
