/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 * 
 * This file is part of magmaOffenburg.
 * 
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg.  If not, see <http://www.gnu.org/licenses/>.
 ********************************************************************************/
package magma.util.geometry.interpolation.progress;

import java.io.Serializable;

/**
 * Represents a interpolation progress function. Progress functions can be used
 * to change the interpolation rate dynamically for other interpolators and
 * thereby alter their interpolation behavior.
 * 
 * @author Stefan Glaser
 */
public abstract class ProgressFunction implements Serializable
{
	/** */
	private static final long serialVersionUID = -5661963372959745201L;

	/**
	 * @param t: the interpolation progress (0...1)
	 * @return the transformed interpolation progress (0...1)
	 */
	public float getProgress(float t)
	{
		float progress = calculateProgress(t);

		if (progress < 0) {
			progress = 0;
		} else if (progress > 1) {
			progress = 1;
		}

		return progress;
	}

	/**
	 * @param t: the interpolation progress (0...1)
	 * @return the transformed interpolation progress (0...1)
	 */
	protected abstract float calculateProgress(float t);
}
