/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 * 
 * This file is part of magmaOffenburg.
 * 
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg.  If not, see <http://www.gnu.org/licenses/>.
 ********************************************************************************/
package magma.util.geometry.interpolation.value;

import magma.util.geometry.interpolation.IValueInterpolator;
import magma.util.geometry.interpolation.progress.ProgressFunction;

/**
 * @author Stefan Glaser
 */
public abstract class ValueInterpolatorBase implements IValueInterpolator
{
	/** */
	private static final long serialVersionUID = 7438600745958116850L;

	/** interpolation progress function */
	public ProgressFunction progress;

	public ValueInterpolatorBase(ProgressFunction progress)
	{
		this.progress = progress;
	}

	@Override
	public double interpolate(double initial, double target, float t)
	{
		float p = progress.getProgress(t);

		if (p >= 1) {
			return target;
		} else if (p <= 0) {
			return initial;
		}

		return calculateInterpolationValue(initial, target, p);
	}

	/**
	 * @param initial
	 * @param target
	 * @param t
	 * @return
	 */
	protected abstract double calculateInterpolationValue(double initial,
			double target, float t);
}
