/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.util.geometry.positionFilter;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

/**
 * Interpolate a more reliable position value for an object from a list of past,
 * less reliable values
 * 
 * @author sturmflut
 */
public class MaxAccelerationPositionFilter extends PositionFilterBase
{
	double oldSpeed;

	/**
	 * Default constructor
	 */
	public MaxAccelerationPositionFilter()
	{
		super();
		oldSpeed = 0;
	}

	/**
	 * Constructor
	 * 
	 * @param i Internal buffer size for past position values
	 */
	public MaxAccelerationPositionFilter(int i)
	{
		super(i);
		oldSpeed = 0;
	}

	@Override
	protected Vector3D calculateNewPosition()
	{
		Vector3D sum = new Vector3D(0, 0, 0);
		for (Vector3D v : filterbuffer) {
			sum = sum.add(v);
		}

		Vector3D newPos = sum.scalarMultiply(1f / filterbuffer.size());
		Vector3D prevPos = filterbuffer.peek();
		if (prevPos == null) {
			return newPos;
		}

		// check if we have an implausible acceleration
		Vector3D speed = newPos.subtract(prevPos);
		double newSpeed = speed.getNorm();
		if (Math.abs(newSpeed - oldSpeed) > 0.02) {
			newPos = prevPos.add(speed.scalarMultiply(0.8));
		}
		oldSpeed = newSpeed;
		return newPos;
	}
}
