/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.util.geometry.positionFilter;

import java.util.LinkedList;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;

public abstract class PositionFilterBase implements IPositionFilter
{
	protected static final int DEFAULT_BUFFER_SIZE = 5;

	protected final LinkedList<Vector3D> filterbuffer = new LinkedList<Vector3D>();

	protected int bufferSize = DEFAULT_BUFFER_SIZE;

	/**
	 * Default constructor
	 */
	public PositionFilterBase()
	{
	}

	/**
	 * Constructor
	 * 
	 * @param i Internal buffer size for past position values
	 */
	public PositionFilterBase(int i)
	{
		bufferSize = i;
	}

	/**
	 * Execute a filter pass: takes the current position of an object, adds it to
	 * the internal buffer, and interpolates a (hopefully) more reliable
	 * estimate.
	 * 
	 * @param position Current position
	 * @return Filtered position
	 */
	@Override
	public Vector3D filterPosition(Vector3D position)
	{
		if (position == null)
			return null;

		filterbuffer.push(position);
		if (filterbuffer.size() > bufferSize)
			filterbuffer.pollLast();

		return calculateNewPosition();
	}

	protected abstract Vector3D calculateNewPosition();

	/**
	 * Clears the history of the position filter.
	 */
	@Override
	public void reset()
	{
		filterbuffer.clear();
	}
}
