/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 */

package magma.util.timing;

/**
 * 
 * @author kdorer
 */
public class TimeTrigger implements Runnable
{
	private long timeout;

	private ITriggerReceiver receiver;

	private String name;

	private boolean stopped;

	/**
	 * 
	 * @param receiver
	 * @param timeout the timeout in ms
	 */
	public TimeTrigger(String name, ITriggerReceiver receiver, long timeout)
	{
		this.name = name;
		this.receiver = receiver;
		this.timeout = timeout;
		Thread t = new Thread(this, name);
		t.setDaemon(true);
		t.start();
	}

	/** stops the thread with the next cycle */
	public void stop()
	{
		stopped = true;
	}

	public void run()
	{
		start();
	}

	/**
	 * Like with a thread you can only start this once.
	 */
	public void start()
	{
		while (!stopped) {
			try {
				// the current implementation does not account for how long the
				// trigger() needs
				Thread.sleep(timeout);
				if (!stopped) {
					// inform the caller
					receiver.trigger();
				}
			} catch (InterruptedException e) {
			}
		}
	}

	@Override
	public String toString()
	{
		return "Timer: " + name + " timeout: " + timeout;
	}
}