/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 */

package magma.agent.agentmodel.impl;

import static org.easymock.EasyMock.createMock;
import static org.easymock.EasyMock.expect;
import static org.easymock.EasyMock.replay;
import static org.junit.Assert.assertEquals;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import magma.agent.agentmodel.IHingeJoint;
import magma.agent.agentmodel.IJoint;
import magma.agent.meta.agent.ICompositeJointConfiguration;
import magma.agent.meta.agent.IHingeJointConfiguration;
import magma.agent.meta.agent.IJointToMotorMapper;
import magma.agent.meta.agent.impl.CompositeJointConfiguration;
import magma.agent.meta.agent.impl.HingeJointConfiguration;
import magma.agent.perception.ICompositeJointPerceptor;
import magma.agent.perception.IHingeJointPerceptor;
import magma.agent.perception.IPerception;
import magma.agent.perception.impl.CompositeJointPerceptor;
import magma.agent.perception.impl.HingeJointPerceptor;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;
import org.junit.Before;
import org.junit.Ignore;
import org.junit.Test;

/**
 * 
 * @author kdorer
 */
public class CompositeJointTest
{
	private CompositeJoint testee;

	private IPerception perceptionMock;

	/**
	 * @throws java.lang.Exception
	 */
	@Before
	public void setUp() throws Exception
	{
		perceptionMock = createMock(IPerception.class);

		IJointToMotorMapper mapper = new IJointToMotorMapper() {

			@Override
			public double[] motorToJointAngle(double[] motorAngles)
			{
				double[] result = new double[motorAngles.length];
				for (int i = 0; i < motorAngles.length; i++) {
					result[i] = -motorAngles[i];
				}
				return result;
			}

			@Override
			public double[] jointToMotorAngle(double[] jointAngles)
			{
				return motorToJointAngle(jointAngles);
			}
		};
		HingeJointConfiguration hip1 = new HingeJointConfiguration("joint1",
				"p1", "e1", Vector3D.PLUS_J, -20, 20, 7, 8, 11);
		HingeJointConfiguration hip2 = new HingeJointConfiguration("joint2",
				"p2", "e2", Vector3D.PLUS_J, -20, 20, 7, 8, 12);
		IHingeJointConfiguration[] hjConfs = { hip1, hip2 };
		ICompositeJointConfiguration jointConfig = new CompositeJointConfiguration(
				"test", mapper, hjConfs);

		testee = new CompositeJoint(jointConfig);
	}

	/**
	 * Test method for
	 * {@link magma.agent.agentmodel.impl.CompositeJoint#updateFromPerception(magma.agent.perception.IPerception)}
	 * .
	 */
	@Test
	public void testUpdateFromPerception()
	{
		HingeJointPerceptor h1 = new HingeJointPerceptor("h1", 10, 1, 2, 3, 4, 5,
				6, (byte) 7);
		HingeJointPerceptor h2 = new HingeJointPerceptor("h2", 20, 1, 2, 3, 4, 5,
				6, (byte) 7);
		IHingeJointPerceptor[] perceptors = { h1, h2 };
		ICompositeJointPerceptor perceptor = new CompositeJointPerceptor(
				"testPercept", perceptors);
		expect(perceptionMock.getCompositeJointPerceptor("test")).andReturn(
				perceptor);
		replay(perceptionMock);

		testee.updateFromPerception(perceptionMock);

		List<IJoint> allJoints = testee.getAllSubJoints();
		assertEquals(2, allJoints.size());
		assertEquals(-10, ((IHingeJoint) allJoints.get(0)).getAxis(), 0.0001);
		assertEquals(-20, ((IHingeJoint) allJoints.get(1)).getAxis(), 0.0001);
	}

	@Test
	@Ignore
	public void testGenerateJointAction()
	{
		Map<String, float[]> actions = new HashMap<String, float[]>();

		testee.performAxisPosition(0, 4);
		testee.performAxisPosition(1, 5);
		testee.generateJointAction(actions);
		assertEquals(1, actions.size());
		float[] values = actions.get("test");
		assertEquals(6, values.length);
		assertEquals(-4, values[0], 0.0001);
		assertEquals(11, values[2], 0.0001);
		assertEquals(-5, values[3], 0.0001);
		assertEquals(12, values[5], 0.0001);
	}
}
