/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 */

package magma.agent.agentmodel.impl;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;
import org.junit.Before;
import org.junit.Test;

import static org.junit.Assert.assertEquals;

/**
 * 
 * @author kdorer
 */
public class HingeJointTest
{
	private HingeJoint testee;

	/**
	 * @throws java.lang.Exception
	 */
	@Before
	public void setUp() throws Exception
	{
		testee = new HingeJoint("Test", "percept", "effect", Vector3D.PLUS_I,
				-10, 10, 7, 2, 20);
	}

	/**
	 * Test method for
	 * {@link magma.agent.agentmodel.impl.HingeJoint#performAxisSpeed(float)}.
	 */
	@Test
	public void testPerformAxisSpeedNoLimit()
	{
		testee.performAxisSpeed(1);
		assertEquals(1, testee.getAxis(), 0.001);
	}

	/**
	 * Test method for
	 * {@link magma.agent.agentmodel.impl.HingeJoint#performAxisSpeed(float)}.
	 */
	@Test
	public void testPerformAxisSpeedMaxAcceleration()
	{
		testee.performAxisSpeed(4);
		assertEquals(2, testee.getAxis(), 0.001);
	}

	/**
	 * Test method for
	 * {@link magma.agent.agentmodel.impl.HingeJoint#performAxisSpeed(float)}.
	 */
	@Test
	public void testPerformAxisSpeedMaxAccelerationNegative()
	{
		testee.performAxisSpeed(-4);
		assertEquals(-2, testee.getAxis(), 0.001);
	}

	/**
	 * Test method for
	 * {@link magma.agent.agentmodel.impl.HingeJoint#performAxisSpeed(float)}.
	 */
	@Test
	public void testPerformAxisSpeedMaxSpeed()
	{
		testee = new HingeJoint("Test", "percept", "effect", Vector3D.PLUS_I,
				-10, 10, 7, 20, 20);
		testee.performAxisSpeed(10);
		assertEquals(7, testee.getAxis(), 0.001);
	}

}
