/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.belief.impl;

import static org.easymock.EasyMock.createMock;
import static org.easymock.EasyMock.expect;
import static org.easymock.EasyMock.replay;
import static org.junit.Assert.assertEquals;
import magma.agent.thoughtmodel.IThoughtModel;
import magma.agent.worldmodel.IGlobalMap;
import magma.agent.worldmodel.IMoveableObject;
import magma.agent.worldmodel.IPlayer;
import magma.agent.worldmodel.IThisPlayer;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;
import org.junit.Before;
import org.junit.Test;

/**
 * @author Klaus Dorer
 * 
 */
public class TeammateCloserToBallTest
{
	private TeammateCloserToBall testee;

	private IThoughtModel thoughtModelMock;

	private IGlobalMap worldModelMock;

	private IThisPlayer thisPlayerMock;

	private IPlayer playerMock;

	private IPlayer player2Mock;

	private IPlayer opponentMock;

	private IMoveableObject ballMock;

	private Vector3D goalPosition;

	private Vector3D ballPosition;

	/**
	 * @throws java.lang.Exception
	 */
	@Before
	public void setUp() throws Exception
	{
		ballMock = createMock("ball", IMoveableObject.class);
		playerMock = createMock("player", IPlayer.class);
		player2Mock = createMock("player2", IPlayer.class);
		opponentMock = createMock("opponent", IPlayer.class);
		thisPlayerMock = createMock("thisPlayer", IThisPlayer.class);
		thoughtModelMock = createMock(IThoughtModel.class);
		worldModelMock = createMock(IGlobalMap.class);
		ballPosition = Vector3D.ZERO;
		goalPosition = Vector3D.ZERO;
		expect(ballMock.getPosition()).andStubReturn(ballPosition);
		expect(player2Mock.getPosition()).andStubReturn(new Vector3D(1, 0, 0));
		expect(opponentMock.getPosition()).andStubReturn(new Vector3D(2, 0, 0));
		expect(playerMock.getPosition()).andStubReturn(new Vector3D(4, 0, 0));
		expect(playerMock.getID()).andStubReturn(1);
		expect(player2Mock.getID()).andStubReturn(2);
		expect(thisPlayerMock.getID()).andStubReturn(3);
		expect(worldModelMock.getThisPlayer()).andStubReturn(thisPlayerMock);
		expect(worldModelMock.getBall()).andStubReturn(ballMock);
		expect(thoughtModelMock.getOpponentAtBall()).andStubReturn(opponentMock);
		expect(worldModelMock.getOtherGoalPosition()).andStubReturn(goalPosition);
		expect(thoughtModelMock.getAgentModel()).andStubReturn(null);
		expect(thoughtModelMock.getWorldModel()).andStubReturn(worldModelMock);
	}

	/**
	 * Test method for
	 * {@link magma.agent.belief.impl.TeammateCloserToBall#getTruthValue()}.
	 */
	@Test
	public void testGetTruthValueNoTeammates()
	{
		expect(thoughtModelMock.getClosestOwnPlayerAtBall()).andReturn(
				thisPlayerMock);
		replay(thoughtModelMock, worldModelMock);

		testee = new TeammateCloserToBall(thoughtModelMock);

		assertEquals(0.0, testee.getTruthValue(), 0.0001);
	}

	/**
	 * Test method for
	 * {@link magma.agent.belief.impl.TeammateCloserToBall#getTruthValue()}.
	 */
	@Test
	public void testGetTruthValueCloserTeammate()
	{
		expect(thoughtModelMock.getClosestOwnPlayerAtBall()).andReturn(
				player2Mock);
		replay(thoughtModelMock, worldModelMock);

		testee = new TeammateCloserToBall(thoughtModelMock);

		assertEquals(1.0, testee.getTruthValue(), 0.0001);
	}
}
