/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 * 
 * This file is part of magmaOffenburg.
 * 
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg.  If not, see <http://www.gnu.org/licenses/>.
 ********************************************************************************/
package magma.agent.worldmodel.impl;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;
import magma.agent.meta.server.impl.RCServerMetaModelV63;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;
import org.junit.Before;
import org.junit.Test;

public class SoccerPitchDescriptionTest
{
	protected SoccerPitchDescription testee;

	/**
	 * Setup method
	 */
	@Before
	public void setUp()
	{
		testee = new SoccerPitchDescription(RCServerMetaModelV63.INSTANCE);
	}

	/**
	 * Test for {@link SoccerPitchDescription#isInOwnPenaltyArea(Vector3D)}
	 */
	@Test
	public void testisInOwnPenaltyArea()
	{
		final float PENALTY_MARGIN = 0.3f;

		assertFalse(testee.isInOwnPenaltyArea(Vector3D.ZERO, PENALTY_MARGIN));
		assertTrue(testee.isInOwnPenaltyArea(new Vector3D(
				-testee.fieldHalfLength + 0.01, 0, 0), PENALTY_MARGIN));
		assertTrue(testee.isInOwnPenaltyArea(new Vector3D(
				-testee.fieldHalfLength + 0.01, -testee.penaltyHalfLength
						- testee.goalHalfWidth + PENALTY_MARGIN + 0.01, 0),
				PENALTY_MARGIN));
		assertTrue(testee.isInOwnPenaltyArea(new Vector3D(-testee.fieldHalfLength
				+ testee.penaltyWidth - PENALTY_MARGIN - 0.01,
				testee.penaltyHalfLength + testee.goalHalfWidth - PENALTY_MARGIN
						- 0.01, 0), PENALTY_MARGIN));
	}

	/**
	 * Test for {@link SoccerPitchDescription#isInOwnPenaltyArea(Vector3D)}
	 */
	@Test
	public void testisInOtherPenaltyArea()
	{
		final float PENALTY_MARGIN = 0.3f;

		assertFalse(testee.isInOtherPenaltyArea(Vector3D.ZERO, PENALTY_MARGIN));
		assertTrue(testee.isInOtherPenaltyArea(new Vector3D(
				testee.fieldHalfLength - 0.01, 0, 0), PENALTY_MARGIN));
		assertTrue(testee.isInOtherPenaltyArea(new Vector3D(
				testee.fieldHalfLength - 0.01, -testee.penaltyHalfLength
						- testee.goalHalfWidth + PENALTY_MARGIN + 0.01, 0),
				PENALTY_MARGIN));
		assertTrue(testee.isInOtherPenaltyArea(new Vector3D(
				testee.fieldHalfLength - testee.penaltyWidth + PENALTY_MARGIN
						+ 0.01, testee.penaltyHalfLength + testee.goalHalfWidth
						- PENALTY_MARGIN - 0.01, 0), PENALTY_MARGIN));
	}
}
