/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package magma.agent.worldmodel.impl;

import java.util.ArrayList;

import magma.agent.IServerConfigFilesConstants;
import magma.agent.worldmodel.IGlobalMap;
import magma.agent.worldmodel.ILandmark;
import magma.agent.worldmodel.IMoveableObject;
import magma.agent.worldmodel.IPlayer;
import magma.agent.worldmodel.IThisPlayer;

import org.junit.Before;
import org.junit.Test;

import static org.easymock.EasyMock.anyFloat;
import static org.easymock.EasyMock.expect;
import static org.easymock.EasyMock.expectLastCall;
import static org.easymock.classextension.EasyMock.createMock;

/**
 * 
 * @author Klaus Dorer
 */
public class WorldModelBaseTest
{
	protected IGlobalMap worldModelMock;

	protected IThisPlayer thisPlayerMock;

	protected IMoveableObject ballMock;

	protected IPlayer playerMock1;

	protected IPlayer playerMock2;

	protected IPlayer playerMock3;

	protected IPlayer playerMock4;

	/**
	 * Setup method
	 */
	@Before
	public void setUp()
	{
		playerMock1 = createPlayerMock(playerMock1, 1);
		playerMock2 = createPlayerMock(playerMock2, 2);
		playerMock3 = createPlayerMock(playerMock3, 3);
		playerMock4 = createPlayerMock(playerMock4, 4);
		ballMock = createMock(IMoveableObject.class);
		thisPlayerMock = createMock(IThisPlayer.class);
		expect(thisPlayerMock.getID()).andStubReturn(3);
		worldModelMock = createMock(IGlobalMap.class);
		expect(worldModelMock.getBall()).andStubReturn(ballMock);
		expect(worldModelMock.getThisPlayer()).andStubReturn(thisPlayerMock);
		expect(worldModelMock.getGlobalTime()).andStubReturn(0.0f);
		expect(worldModelMock.getServerVersion()).andStubReturn(
				IServerConfigFilesConstants.DEFAULT_SERVER_VERSION);
		expect(worldModelMock.getLandmarks()).andStubReturn(
				new ArrayList<ILandmark>());
	}

	/**
	 * Train a player mock (for unit testing only!)
	 * 
	 * @param playerMock Player mock
	 * @param id Player id
	 * @return Trained mock
	 */
	IPlayer createPlayerMock(IPlayer playerMock, int id)
	{
		playerMock = createMock(IPlayer.class);
		expect(playerMock.isOwnTeam()).andStubReturn(true);
		expect(playerMock.getID()).andStubReturn(id);
		expect(playerMock.getAge(anyFloat()));
		expectLastCall().andStubReturn(0.0f);

		if (id == 1) {
			expect(playerMock.isGoalie()).andStubReturn(true);
		} else {
			expect(playerMock.isGoalie()).andStubReturn(false);
		}

		return playerMock;
	}

	@Test
	public void emptyDummyTestToKeepJenkinsHappy() throws Exception
	{
	}
}
