/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.worldmodel.localizer.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import magma.agent.meta.server.impl.RCServerMetaModelV62;
import magma.agent.worldmodel.localizer.IEnvironmentModel;
import magma.agent.worldmodel.localizer.ILocalizer;
import magma.agent.worldmodel.localizer.IReferencePoint;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;
import org.junit.Before;
import org.junit.Test;

import static org.easymock.EasyMock.createMock;
import static org.easymock.EasyMock.expect;

/**
 * Unit test for {@link magma.agent.worldmodel.localizer.IReferencePoint}
 * 
 * @author Klaus Dorer
 */
public class LocalizerBaseTest
{
	ILocalizer testee;

	IEnvironmentModel environment;

	IReferencePoint G1L;

	IReferencePoint G2L;

	IReferencePoint G1R;

	IReferencePoint G2R;

	IReferencePoint F1L;

	IReferencePoint F2L;

	IReferencePoint F1R;

	IReferencePoint F2R;

	List<IReferencePoint> flags = null;

	/**
	 * Setup method
	 */
	@Before
	public void setUp()
	{
		Map<String, Vector3D> landmarks = RCServerMetaModelV62.INSTANCE
				.getLandmarks();

		G1L = createMock(IReferencePoint.class);
		expect(G1L.getKnownPosition()).andStubReturn(landmarks.get("G1L"));

		G2L = createMock(IReferencePoint.class);
		expect(G2L.getKnownPosition()).andStubReturn(landmarks.get("G2L"));

		G1R = createMock(IReferencePoint.class);
		expect(G1R.getKnownPosition()).andStubReturn(landmarks.get("G1R"));

		G2R = createMock(IReferencePoint.class);
		expect(G2R.getKnownPosition()).andStubReturn(landmarks.get("G2R"));

		F1L = createMock(IReferencePoint.class);
		expect(F1L.getKnownPosition()).andStubReturn(landmarks.get("F1L"));

		F2L = createMock(IReferencePoint.class);
		expect(F2L.getKnownPosition()).andStubReturn(landmarks.get("F2L"));

		F1R = createMock(IReferencePoint.class);
		expect(F1R.getKnownPosition()).andStubReturn(landmarks.get("F1R"));

		F2R = createMock(IReferencePoint.class);
		expect(F2R.getKnownPosition()).andStubReturn(landmarks.get("F2R"));
		flags = new ArrayList<IReferencePoint>();

		environment = createMock(IEnvironmentModel.class);
		expect(environment.getReferencePoints()).andStubReturn(flags);
	}

	@Test
	public void emptyDummyTestToKeepJenkinsHappy() throws Exception
	{
	}
}
