/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package magma.util;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;
import org.junit.Test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNull;

/**
 * 
 * @author dorer
 */
public class SayCoderTest
{
	/**
	 * Test method for {@link magma.util.SayCoder#encodeID(int)}.
	 */
	@Test
	public void testEncodeID()
	{
		assertEquals("a", SayCoder.encodeID(0));
		assertEquals("b", SayCoder.encodeID(1));
		assertEquals("k", SayCoder.encodeID(10));
	}

	/**
	 * Test method for {@link magma.util.SayCoder#decodeID(java.lang.String)}.
	 */
	@Test
	public void testDecodeID()
	{
		assertEquals(0, SayCoder.decodeID("a"));
		assertEquals(10, SayCoder.decodeID("k"));
	}

	@Test
	public void testEncodeDecodePosition()
	{
		String encodePosition = SayCoder.encodePosition(new Vector3D(12.34,
				-5.67, 0));
		Vector3D result = SayCoder.decodePosition(encodePosition);
		assertEquals(12.3, result.getX(), 0.00001);
		assertEquals(-5.7, result.getY(), 0.00001);

		encodePosition = SayCoder.encodePosition(new Vector3D(20.34, -19.41, 0));
		result = SayCoder.decodePosition(encodePosition);
		assertEquals(20.3, result.getX(), 0.00001);
		assertEquals(-19.5, result.getY(), 0.00001);

		assertNull(SayCoder.decodePosition("2a0200"));
		assertNull(SayCoder.decodePosition("2002000"));
	}

	@Test
	public void testEncodeName()
	{
		assertEquals("t", SayCoder.encodeName("magmaOffenburg"));
		assertEquals("e", SayCoder.encodeName("magmaOpponent"));
		assertEquals("p", SayCoder.encodeName("magma"));
		assertEquals("q", SayCoder.encodeName("magmaOpp"));
	}

	@Test
	public void testEncodeTwoDigit()
	{
		assertEquals("aa", SayCoder.encodeTwoDigit(0));
		assertEquals("az", SayCoder.encodeTwoDigit(25));
		assertEquals("ba", SayCoder.encodeTwoDigit(26));
	}

	@Test
	public void testDecodeTwoDigit()
	{
		assertEquals(0, SayCoder.decodeTwoDigit("aa"));
		assertEquals(26, SayCoder.decodeTwoDigit("ba"));
	}
}
