/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 */

package magma.util.function;

import java.io.FileNotFoundException;

import org.junit.Before;
import org.junit.Ignore;
import org.junit.Test;

import static org.junit.Assert.assertEquals;

/**
 * 
 * @author kdorer
 */
public class LookupMatrixTest
{
	private LookupMatrix testee;

	/**
	 * @throws java.lang.Exception
	 */
	@Before
	public void setUp() throws Exception
	{
		float[][] matrix = { { 0, 1 }, { 2, 3 } };
		testee = new LookupMatrix(matrix, 1, 1, 0, 0);
	}

	/**
	 * Test method for
	 * {@link magma.util.function.LookupMatrix#getValue(double, double)}.
	 */
	@Test
	public void testGetValue()
	{
		assertEquals(0, testee.getValue(0, 0), 0.0001);
		assertEquals(1, testee.getValue(0, 1), 0.0001);
		assertEquals(2, testee.getValue(1, 0), 0.0001);
		assertEquals(3, testee.getValue(1, 1), 0.0001);
		assertEquals(0.5, testee.getValue(0, 0.5), 0.0001);
		assertEquals(1.0, testee.getValue(0.5, 0), 0.0001);
		assertEquals(1.5, testee.getValue(0.5, 0.5), 0.0001);
		assertEquals(0, testee.getValue(-1, 0), 0.0001);
		assertEquals(1, testee.getValue(-1, 1), 0.0001);
		assertEquals(2, testee.getValue(1, -1), 0.0001);
	}

	// @Test
	// @Ignore
	// public void testReadFromFile()
	// {
	// testee = new LookupMatrix("motorMappings/JointToMotorLookupFootM2.csv");
	// // assertEquals(-89.368, testee.getValue(-17, -20), 0.0001);
	//
	// // test difference to analytical method
	// IJointToMotorMapper mapper = new SweatyFootJointToMotorMapper();
	//
	// for (double i = -15; i < 15; i += 0.1) {
	// for (double j = -15; j < 15; j += 0.1) {
	// double[] jointAngles = { i, j };
	// double value1 = mapper.jointToMotorAngle(jointAngles)[1];
	// double value2 = testee.getValue(i, j);
	// double delta = value2 - value1;
	// if (delta > 1.0) {
	// System.out.println("Delta: " + delta + " x:" + i + " y:" + j);
	// }
	// }
	// }
	// }

	@Test
	@Ignore
	public void testRuntime() throws FileNotFoundException
	{
		testee = new LookupMatrix("motorMappings/JointToMotorLookupFootM2.csv");
		long start = System.currentTimeMillis();
		for (double i = -15; i < 15; i += 0.01) {
			for (double j = -15; j < 15; j += 0.01) {
				testee.getValue(i, j);
			}
		}
		System.out.println("runtime: "
				+ ((System.currentTimeMillis() - start) * 2));
	}
}
