/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 */

package magma.util.geometry;

import magma.util.FuzzyCompare;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;
import org.junit.Before;
import org.junit.Test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

/**
 * 
 * @author kdorer
 */
public class SphereTest
{
	private Sphere testee;

	/**
	 * @throws java.lang.Exception
	 */
	@Before
	public void setUp() throws Exception
	{
		testee = new Sphere(new Vector3D(1, -2, -3), Math.sqrt(14));
	}

	/**
	 * Test method for
	 * {@link magma.util.geometry.Sphere#intersect(magma.util.geometry.Circle3D)}
	 * .
	 */
	@Test
	public void testIntersectTwoPointSameXZ()
	{
		testee = new Sphere(new Vector3D(0, -1, 0), 1);
		Circle3D circle = new Circle3D(new Vector3D(0, 0, 0), 1);
		Vector3D[] intersect = testee.intersect(circle);

		double cos = Math.cos(Math.toRadians(60));
		double sin = Math.sin(Math.toRadians(60));

		Vector3D expected = new Vector3D(0, -cos, sin);
		testTrue(expected, intersect[0]);
		expected = new Vector3D(0, -cos, -sin);
		testTrue(expected, intersect[1]);
	}

	@Test
	public void testIntersectOrigin()
	{
		Circle3D circle = new Circle3D(new Vector3D(0, 1, 0), 1);
		Vector3D[] intersect = testee.intersect(circle);

		Vector3D expected = Vector3D.ZERO;
		testTrue(expected, intersect[0]);
		expected = new Vector3D(0, 1, -1);
		testTrue(expected, intersect[1]);
	}

	@Test
	public void testIntersectOnePoint()
	{
		testee = new Sphere(new Vector3D(2, 2, 2), Math.sqrt(12));
		Circle3D circle = new Circle3D(new Vector3D(0, -1, -1), Math.sqrt(2));
		Vector3D[] intersect = testee.intersect(circle);

		Vector3D expected = Vector3D.ZERO;
		testTrue(expected, intersect[0]);
		expected = Vector3D.ZERO;
		testTrue(expected, intersect[1]);
	}

	@Test
	public void testNoIntersect()
	{
		Circle3D circle = new Circle3D(new Vector3D(0, 3, 0), 1);
		Vector3D[] intersect = testee.intersect(circle);
		assertEquals(0, intersect.length);
	}

	/**
	 * @param expected
	 * @param intersect
	 */
	protected void testTrue(Vector3D expected, Vector3D intersect)
	{
		assertTrue("Not equal: " + expected + "/" + intersect,
				eq(expected, intersect, 0.0001));
	}

	// TODO: call FuzzyCompare.eq() once commons math 3 has been introduced there
	// and remove this method
	public static boolean eq(Vector3D reference, Vector3D compare, double range)
	{
		if (reference == null && compare == null) {
			return true;
		}
		if (reference == null || compare == null) {
			return false;
		}

		if (!FuzzyCompare.eq((float) reference.getX(), (float) compare.getX(),
				range)) {
			return false;
		}
		if (!FuzzyCompare.eq((float) reference.getY(), (float) compare.getY(),
				range)) {
			return false;
		}
		return FuzzyCompare.eq((float) reference.getZ(), (float) compare.getZ(),
				range);
	}

}
