/********************************************************************************
 * Copyright 2008 - 2014 Hochschule Offenburg
 * All Authors are named in file Authors.txt
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.util;

import static org.junit.Assert.assertEquals;

import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;
import org.junit.Test;

/**
 * @author Ingo Schindler
 * 
 */
public class FuzzyCompareTest
{

	/**
	 * Test method for {@link magma.util.FuzzyCompare#eq(double, double, double)}
	 * .
	 */
	@Test
	public void testEq()
	{
		assertEquals("EQ 10 = 10 | Range 0", true, FuzzyCompare.eq(10, 10, 0));
		assertEquals("EQ 10 = 10 | Range 5", true, FuzzyCompare.eq(10, 10, 5));
		assertEquals("EQ 10 = 9 | Range 1", true, FuzzyCompare.eq(10, 9, 1));
		assertEquals("EQ 10 = 11 | Range 1", true, FuzzyCompare.eq(10, 11, 1));
		assertEquals("EQ 10 = 8 | Range 1", false, FuzzyCompare.eq(10, 8, 1));
		assertEquals("EQ 10 = 12 | Range 1", false, FuzzyCompare.eq(10, 12, 1));
	}

	/**
	 * Test method for {@link magma.util.FuzzyCompare#gt(double, double, double)}
	 * .
	 */
	@Test
	public void testGt()
	{
		assertEquals("GT 10 > 10 | Range 0", true, FuzzyCompare.gt(10, 10, 0));
		assertEquals("GT 10 > 10 | Range 5", true, FuzzyCompare.gt(10, 10, 5));
		assertEquals("GT 10 > 9 | Range 1", true, FuzzyCompare.gt(10, 9, 1));
		assertEquals("GT 10 > 11 | Range 1", true, FuzzyCompare.gt(10, 11, 1));
		assertEquals("GT 10 > 8 | Range 1", true, FuzzyCompare.gt(10, 8, 1));
		assertEquals("GT 10 > 12 | Range 1", false, FuzzyCompare.gt(10, 12, 1));
	}

	/**
	 * Test method for {@link magma.util.FuzzyCompare#lt(double, double, double)}
	 * .
	 */
	@Test
	public void testLt()
	{
		assertEquals("LT 10 < 10 | Range 0", true, FuzzyCompare.lt(10, 10, 0));
		assertEquals("LT 10 < 10 | Range 5", true, FuzzyCompare.lt(10, 10, 5));
		assertEquals("LT 10 < 9 | Range 1", true, FuzzyCompare.lt(10, 9, 1));
		assertEquals("LT 10 < 11 | Range 1", true, FuzzyCompare.lt(10, 11, 1));
		assertEquals("LT 10 < 8 | Range 1", false, FuzzyCompare.lt(10, 8, 1));
		assertEquals("LT 10 < 12 | Range 1", true, FuzzyCompare.lt(10, 12, 1));
	}

	/**
	 * Test method for
	 * {@link magma.util.FuzzyCompare#gte(double, double, double)}.
	 */
	@Test
	public void testGte()
	{
		assertEquals("GTE 10 > 10 | Range 0", true, FuzzyCompare.gte(10, 10, 0));
		assertEquals("GTE 10 > 10 | Range 5", true, FuzzyCompare.gte(10, 10, 5));
		assertEquals("GTE 10 > 9 | Range 1", true, FuzzyCompare.gte(10, 9, 1));
		assertEquals("GTE 10 > 11 | Range 1", true, FuzzyCompare.gte(10, 11, 1));
		assertEquals("GTE 10 > 8 | Range 1", true, FuzzyCompare.gte(10, 8, 1));
		assertEquals("GTE 10 > 12 | Range 1", false, FuzzyCompare.gte(10, 12, 1));
	}

	/**
	 * Test method for
	 * {@link magma.util.FuzzyCompare#lte(double, double, double)}.
	 */
	@Test
	public void testLte()
	{
		assertEquals("LTE 10 < 10 | Range 0", true, FuzzyCompare.lte(10, 10, 0));
		assertEquals("LTE 10 < 10 | Range 5", true, FuzzyCompare.lte(10, 10, 5));
		assertEquals("LTE 10 < 9 | Range 1", true, FuzzyCompare.lte(10, 9, 1));
		assertEquals("LTE 10 < 11 | Range 1", true, FuzzyCompare.lte(10, 11, 1));
		assertEquals("LTE 10 < 8 | Range 1", false, FuzzyCompare.lte(10, 8, 1));
		assertEquals("LTE 10 < 12 | Range 1", true, FuzzyCompare.lte(10, 12, 1));
	}

	/**
	 * Test method for
	 * {@link magma.util.FuzzyCompare#eq(Vector3D, Vector3D, double)}.
	 */
	@Test
	public void testEq3D()
	{
		// Difference on the right side
		assertEquals("EQ (1, 2, 3) == (2, 2, 3) | Range 0", false,
				FuzzyCompare.eq(new Vector3D(1.0, 2.0, 3.0), new Vector3D(2.0, 2.0,
						3.0), 0.0));
		assertEquals("EQ (1, 2, 3) == (2, 2, 3) | Range 1", true,
				FuzzyCompare.eq(new Vector3D(1.0, 2.0, 3.0), new Vector3D(2.0, 2.0,
						3.0), 1.0));

		assertEquals("EQ (1, 2, 3) == (1, 3, 3) | Range 0", false,
				FuzzyCompare.eq(new Vector3D(1.0, 2.0, 3.0), new Vector3D(1.0, 3.0,
						3.0), 0.0));
		assertEquals("EQ (1, 2, 3) == (1, 3, 3) | Range 1", true,
				FuzzyCompare.eq(new Vector3D(1.0, 2.0, 3.0), new Vector3D(1.0, 3.0,
						3.0), 1.0));

		assertEquals("EQ (1, 2, 3) == (1, 2, 4) | Range 0", false,
				FuzzyCompare.eq(new Vector3D(1.0, 2.0, 3.0), new Vector3D(1.0, 2.0,
						4.0), 0.0));
		assertEquals("EQ (1, 2, 3) == (1, 2, 4) | Range 1", true,
				FuzzyCompare.eq(new Vector3D(1.0, 2.0, 3.0), new Vector3D(1.0, 2.0,
						4.0), 1.0));

		// Difference on the left side
		assertEquals("EQ (2, 2, 3) == (1, 2, 3) | Range 0", false,
				FuzzyCompare.eq(new Vector3D(2.0, 2.0, 3.0), new Vector3D(1.0, 2.0,
						3.0), 0.0));
		assertEquals("EQ (2, 2, 3) == (1, 2, 3) | Range 1", true,
				FuzzyCompare.eq(new Vector3D(2.0, 2.0, 3.0), new Vector3D(1.0, 2.0,
						3.0), 1.0));

		assertEquals("EQ (1, 3, 3) == (1, 2, 3) | Range 0", false,
				FuzzyCompare.eq(new Vector3D(1.0, 3.0, 3.0), new Vector3D(1.0, 2.0,
						3.0), 0.0));
		assertEquals("EQ (1, 3, 3) == (1, 2, 3) | Range 1", true,
				FuzzyCompare.eq(new Vector3D(1.0, 3.0, 3.0), new Vector3D(1.0, 2.0,
						3.0), 1.0));

		assertEquals("EQ (1, 2, 4) == (1, 2, 3) | Range 0", false,
				FuzzyCompare.eq(new Vector3D(1.0, 2.0, 4.0), new Vector3D(1.0, 2.0,
						3.0), 0.0));
		assertEquals("EQ (1, 2, 4) == (1, 2, 3) | Range 1", true,
				FuzzyCompare.eq(new Vector3D(1.0, 2.0, 4.0), new Vector3D(1.0, 2.0,
						3.0), 1.0));
	}
}
